clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000

local root      ""  /* Root directory where data is stored */
local dnors     ""  /* Directory where the dnors survey data are stored */
local ouputdir  ""  /* Directory where resulting merged data will be stored */
local assessors ""  /* Directory where OPAO data are stored */
local psid      ""  /* Directory where PSID asset data are stored */

************************************
************************************
***** 1. Assessor's Data Files *****
************************************
************************************

*************************************************************************
*** 2005-2011 assessors data -- full universe of owner-occupied homes ***
*************************************************************************
use `assessors'assessments05_06_07_09_10_11_with_block_traits.dta
keep pid taxbill addid improveval05 improveval06 improveval07 improveval09 improveval10 improveval11 insample landval05 landval06 landval07 landval09 landval10 landval11 roadhome23_1 roadhome23_2 roadhome23_3 roadhome23_4 sale_date1 sale_date2 sale_date3 sale_date4 sale_price1 sale_price2 sale_price3 sale_price4 streetnum blockid00 address_phys

duplicates drop taxbill, force

keep if improveval06<.
gen postk_sale = 0
gen postk_sale_date = .
format postk_sale_date %d
gen postk_sale_price = .
gen purchase_date = .
format purchase_date %d
gen purchase_price = .
gen postk_transfer_date = .
format postk_transfer_date %d
gen transfer_date = .
format transfer_date %d
gen roadhome23 = 0 if improveval07<.
forval ii=1/4 {
replace postk_sale =           1               if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<. & sale_price`ii'>0 & sale_price`ii'<.
replace postk_sale_price =     sale_price`ii'  if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_sale_date & sale_price`ii'>0 & sale_price`ii'<.
replace roadhome23 =           roadhome23_`ii' if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_sale_date & sale_price`ii'>0 & sale_price`ii'<.
replace postk_sale_date =      sale_date`ii'   if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_sale_date & sale_price`ii'>0 & sale_price`ii'<.
replace purchase_price =       sale_price`ii'  if sale_date`ii' < mdy(8,29,2005) & sale_price`ii'>0 & ((sale_date`ii'>purchase_date)|(purchase_date==.))
replace purchase_date =        sale_date`ii'   if sale_date`ii' < mdy(8,29,2005) & sale_price`ii'>0 & ((sale_date`ii'>purchase_date)|(purchase_date==.))
replace postk_transfer_date =  sale_date`ii'   if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_transfer_date
replace transfer_date =        sale_date`ii'   if sale_date`ii' < mdy(8,29,2005) & ((sale_date`ii'>transfer_date)|(transfer_date==.))
}

**** flag observations coming from this data source
gen            sample_assessors_universe=1
label variable sample_assessors_universe "sample flag: Assessor's data -- full universe"

tempfile AssessorsUniverse
save `AssessorsUniverse'
clear

************************************************
*** 2005-2010 assessors data -- DNORS sample ***
************************************************
use `dnors'dnors_opao_wsampleid/DNORS_OPAO_merged_wsampleid.dta

keep if improveval06<.
gen postk_sale = 0
gen postk_sale_date = .
format postk_sale_date %d
gen postk_sale_price = .
gen purchase_date = .
format purchase_date %d
gen purchase_price = .
gen postk_transfer_date = .
format postk_transfer_date %d
gen transfer_date = .
format transfer_date %d
gen roadhome23 = 0 if improveval07<.
forval ii=1/4 {
replace postk_sale =           1               if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<. & sale_price`ii'>0 & sale_price`ii'<.
replace postk_sale_price =     sale_price`ii'  if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_sale_date & sale_price`ii'>0 & sale_price`ii'<.
replace roadhome23 =           roadhome23_`ii' if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_sale_date & sale_price`ii'>0 & sale_price`ii'<.
replace postk_sale_date =      sale_date`ii'   if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_sale_date & sale_price`ii'>0 & sale_price`ii'<.
replace purchase_price =       sale_price`ii'  if sale_date`ii' < mdy(8,29,2005) & sale_price`ii'>0 & ((sale_date`ii'>purchase_date)|(purchase_date==.))
replace purchase_date =        sale_date`ii'   if sale_date`ii' < mdy(8,29,2005) & sale_price`ii'>0 & ((sale_date`ii'>purchase_date)|(purchase_date==.))
replace postk_transfer_date =  sale_date`ii'   if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_transfer_date
replace transfer_date =        sale_date`ii'   if sale_date`ii' < mdy(8,29,2005) & ((sale_date`ii'>transfer_date)|(transfer_date==.))
}

**** flag observations coming from this data source
gen            sample_assessors_dnors=1
label variable sample_assessors_dnors "sample flag: Assessor's data -- DNORS sample frame"

tempfile AssessorsUniverse_DNORS
save `AssessorsUniverse_DNORS'
clear

*****************************************
*** Merge two Assessor's data samples ***
*****************************************
global joinbylist "landval05 landval06 landval07 landval09 landval10 improveval05 improveval06 improveval07 improveval09 improveval10 postk_sale_date purchase_date postk_transfer_date transfer_date "
use `AssessorsUniverse'
egen duplicates = sum(1), by($joinbylist)
su improveval*
joinby $joinbylist using `AssessorsUniverse_DNORS', unmatched(master)
tab _m
drop _m
duplicates drop taxbill, force
gen hhid = substr(sampleid,1,8)

******************************************************************************
*** Create relevant variables based on combinations of Assesor's variables ***
******************************************************************************

**** Pre-katrina home value
gen            homevalue05 = improveval05+landval05
label variable homevalue05 "Last assessed home value prior to Katrina"
gen            lnhomevalue05 = ln(homevalue05)
label variable lnhomevalue05 "Log - last assessed home value prior to Katrina"

**** Value of losses as a fraction of home's value
gen            valshare06 = min(2,improveval06/improveval05) if improveval05<. & improveval06<.
gen            valshare07 = min(2,improveval07/improveval05) if improveval05<. & improveval07<.
gen            valshare08 = min(2,improveval08/improveval05) if improveval05<. & improveval08<.
gen            valshare09 = min(2,improveval09/improveval05) if improveval05<. & improveval09<.
gen            valshare10 = min(2,improveval10/improveval05) if improveval05<. & improveval10<.
label variable valshare06 "ratio of 06 improvement value to pre-K improvement value"
label variable valshare07 "ratio of 07 improvement value to pre-K improvement value"
label variable valshare08 "ratio of 08 improvement value to pre-K improvement value"
label variable valshare09 "ratio of 09 improvement value to pre-K improvement value"
label variable valshare10 "ratio of 10 improvement value to pre-K improvement value"

**** Classify by national housevalue quintile for merging with PSID asset data
gen     housevalue05_quint = 4 if homevalue05<.
replace housevalue05_quint = 3 if homevalue05<310000 & homevalue05<.
replace housevalue05_quint = 2 if homevalue05<185000 & homevalue05<.
replace housevalue05_quint = 1 if homevalue05<125000 & homevalue05<.
replace housevalue05_quint = 0 if homevalue05< 75790 & homevalue05<.

**** purchase year
gen            purchase_year = year(purchase_date)
label variable purchase_year "year pre-K home was purchased"
gen            purchase_years_ago = 2005-purchase_year
label variable purchase_years_ago "2005 minus year pre-K home was purchased"

**** purchase date category
gen purchase_cat = 1
replace purchase_cat = 1 if inrange(purchase_date,mdy(1,1,1900),mdy(12,31,1989))==1
replace purchase_cat = 2 if inrange(purchase_date,mdy(1,1,1990),mdy(12,31,1999))==1
replace purchase_cat = 3 if inrange(purchase_date,mdy(1,1,2000),mdy(8,29,2005))==1
label define purchase_cat_lab 1 "Prior to 1990" 2 "1990-1999" 3 "2000-2005"
label values purchase_cat purchase_cat_lab

tempfile assessors
save `assessors'
clear


**************************
**************************
***** 2. DNORS files *****
**************************
**************************
use `dnors'pubfinfmt/screener_pubfin.dta
joinby sampleid using `dnors'restrictfmt/screener_resv1.dta, unmatched(both)
tab _m
drop _m
joinby sampleid using `dnors'restrictfmt/screener_resv2.dta, unmatched(both)
tab _m
drop _m
joinby sampleid using `dnors'restrictfmt/screener_resv3.dta, unmatched(both)
tab _m
drop _m
joinby sampleid using `dnors'restrictfmt/screener_resv4.dta, unmatched(both)
tab _m
drop _m
tempfile screenmodule
save `screenmodule'
clear

use `dnors'pubfinfmt/hhrost_pubfin.dta 
joinby sampleid hhid rost_id using `dnors'restrictfmt/hhrost_resv1.dta, unmatched(both)
tab _m
drop _m
joinby sampleid hhid rost_id using `dnors'restrictfmt/hhrost_resv2.dta, unmatched(both)
tab _m
drop _m
joinby sampleid hhid rost_id using `dnors'restrictfmt/hhrost_resv3.dta, unmatched(both)
tab _m
drop _m
joinby sampleid hhid rost_id using `dnors'restrictfmt/hhrost_resv4.dta, unmatched(both)
tab _m
drop _m
tempfile hhrost
save `hhrost'
clear

use `dnors'pubfinfmt/resp_iw_pubfin.dta
joinby sampleid using `dnors'restrictfmt/respiw_resv1.dta, unmatched(both)
tab _m
drop _m
joinby sampleid using `dnors'restrictfmt/respiw_resv2.dta, unmatched(both)
tab _m
drop _m
joinby sampleid using `dnors'restrictfmt/respiw_resv3.dta, unmatched(both)
tab _m
drop _m
joinby sampleid using `dnors'restrictfmt/respiw_resv4.dta, unmatched(both)
tab _m
drop _m
tempfile respiw
save `respiw'
clear

**************************************************************************
*** DNORS insurance vars and imputed household income and storm damage ***
**************************************************************************
use `respiw'
keep if hh_resp==1

gen segment=real(substr(sampleid,2,3))
ren b1 hometype
ren b2 own
ren d15 fin_diff
ren d16 damage_home
gen damage_prop = d17
ren d19 insurance
label variable damage_home "damage to home"
label variable damage_home "damage to property and possessions"
label variable insurance "insurance coverage"
keep sampleid segment hhid hometype own fin_diff damage_home damage_prop insurance m1_imp m1_impflag m2_imp m2_impflag d17_imp d17_impflag d18_imp d18_impflag hu_wgt_s

**** flag observations coming from this data source
gen            sample_dnors_hhfin=1
label variable sample_dnors_hhfin "sample flag: DNORS household variables"

tempfile dnors_inc_imps
save `dnors_inc_imps'
clear

********************************************************
*** DNORS labor data from household module responses ***
********************************************************
use `hhrost'
keep if relscrr<=3

egen best_educ = max(c37), by(hhid)

gen best_hsdrop   = inrange(best_educ,0 ,12)
gen best_hs       = inrange(best_educ,13,14)
gen best_somecoll = inrange(best_educ,15,17)
gen best_bach     = inrange(best_educ,18,21)

egen black = max(c31==2), by(hhid)

** the head (male if present) and spouse of head
gen female = gender==5
egen count       = sum(1       ), by(hhid)
egen countmale   = sum(1-female), by(hhid)
egen countfemale = sum(  female), by(hhid)
gen     head = 0
replace head = 1 if count==1
replace head = 1-female if count==2 & countmale==1
replace head = hhrpnum==personnum if count==2 & countmale!=1
label variable head "household head"

gen   male_head=(count==1)*(countmale  ==1)
gen female_head=(count==1)*(countfemale==1)
gen couple_head=(count==2)
label variable   male_head "1(hh head is a single male)"
label variable female_head "1(hh head is a single female)"
label variable couple_head "1(hh is couple-headed)"

ren c64occ occ_prek

gen occ2_prek = .
replace occ2_prek =  1 if inrange(occ_prek,001,043)==1
replace occ2_prek =  2 if inrange(occ_prek,050,073)==1
replace occ2_prek =  3 if inrange(occ_prek,080,095)==1
replace occ2_prek =  4 if inrange(occ_prek,100,124)==1
replace occ2_prek =  5 if inrange(occ_prek,130,156)==1
replace occ2_prek =  6 if inrange(occ_prek,160,196)==1
replace occ2_prek =  7 if inrange(occ_prek,200,206)==1
replace occ2_prek =  8 if inrange(occ_prek,210,210)==1
replace occ2_prek =  9 if inrange(occ_prek,211,215)==1
replace occ2_prek = 10 if inrange(occ_prek,220,255)==1
replace occ2_prek = 11 if inrange(occ_prek,260,296)==1
replace occ2_prek = 12 if inrange(occ_prek,300,354)==1
replace occ2_prek = 13 if inrange(occ_prek,360,365)==1
replace occ2_prek = 14 if inrange(occ_prek,370,395)==1
replace occ2_prek = 15 if inrange(occ_prek,400,416)==1
replace occ2_prek = 16 if inrange(occ_prek,420,425)==1
replace occ2_prek = 17 if inrange(occ_prek,430,465)==1
replace occ2_prek = 18 if inrange(occ_prek,470,496)==1
replace occ2_prek = 19 if inrange(occ_prek,500,593)==1
replace occ2_prek = 20 if inrange(occ_prek,600,613)==1
replace occ2_prek = 21 if inrange(occ_prek,620,676)==1
replace occ2_prek = 22 if inrange(occ_prek,680,694)==1
replace occ2_prek = 23 if inrange(occ_prek,700,762)==1
replace occ2_prek = 24 if inrange(occ_prek,770,896)==1
replace occ2_prek = 25 if inrange(occ_prek,900,975)==1
replace occ2_prek = 26 if inrange(occ_prek,980,992)==1

label define occ2_prek_lab  1 "Management Occupations"
label define occ2_prek_lab  2 "Business Operations Specialists", add
label define occ2_prek_lab  3 "Financial Specialists", add
label define occ2_prek_lab  4 "Computer and Mathematical Occupations", add
label define occ2_prek_lab  5 "Architecture and Engineering Occupations", add
label define occ2_prek_lab  6 "Life, Physical, and Social Science Occupations", add
label define occ2_prek_lab  7 "Community and Social Services Occupations", add
label define occ2_prek_lab  8 "Lawyers", add
label define occ2_prek_lab  9 "Other Legal Occupations", add
label define occ2_prek_lab 10 "Education, Training, and Library Occupations", add
label define occ2_prek_lab 11 "Arts, Design, Entertainment, Sports, and Media Occupations", add
label define occ2_prek_lab 12 "Healthcare Practitioners and Technical Occupations", add
label define occ2_prek_lab 13 "Healthcare Support Occupations", add
label define occ2_prek_lab 14 "Protective Service Occupations", add
label define occ2_prek_lab 15 "Food Preparation and Serving Occupations", add
label define occ2_prek_lab 16 "Building and Grounds Cleaning and Maintenance Occupations", add
label define occ2_prek_lab 17 "Personal Care and Service Occupations", add
label define occ2_prek_lab 18 "Sales Occupations", add
label define occ2_prek_lab 19 "Office and Administrative Support Occupations", add
label define occ2_prek_lab 20 "Farming, Fishing, and Forestry Occupations", add
label define occ2_prek_lab 21 "Construction Trades", add
label define occ2_prek_lab 22 "Extraction Workers", add
label define occ2_prek_lab 23 "Installation, Maintenance, and Repair Workers", add
label define occ2_prek_lab 24 "Production Occupations", add
label define occ2_prek_lab 25 "Transportation and Material Moving Occupations", add
label define occ2_prek_lab 26 "Military Specific Occupations", add
label values occ2_prek occ2_prek_lab

gen male = c2agender==1

gen     kat_age = c2aage-4
replace kat_age = c9c-4 if kat_age==997-4
replace kat_age = age-4 if kat_age>=. & age<997

gen     aux = kat_age if   male==1
replace aux = kat_age if female==1 & female_head==1
egen hh_age = mean(aux), by(hhid)
drop aux

gen employed_prek = 0
gen labforce_prek = 0
replace employed_prek = .n if c63_s1>=.  /* to flag DNORS sample members without valid responses */
replace labforce_prek = .n if c63_s1>=.  /* to flag DNORS sample members without valid responses */
forval ii=1/4 {
replace employed_prek = 1 if c63_s`ii'==1
replace labforce_prek = 1 if inlist(c63_s`ii',1,2,3)==1
}

gen wkwage_prek = .
replace wkwage_prek = c69 * c68     if c70==1
replace wkwage_prek = c69 * 5       if c70==2
replace wkwage_prek = c69           if c70==3
replace wkwage_prek = c69 / 4.34    if c70==4
replace wkwage_prek = c69 / 52      if c70==5
replace wkwage_prek = c69 / 2       if c70==6
gen yrwage_prek = wkwage_prek*52
gen lnwkwage_prek = ln(wkwage_prek)
gen lnyrwage_prek = ln(yrwage_prek)

gen     relscrr2 = .
replace relscrr2 = 0 if relscrr==0
replace relscrr2 = 1 if inrange(relscrr,1,3)==1

keep         sampleid hhid female_head male_head couple_head best_hsdrop best_hs best_somecoll best_bach hh_age black relscrr2 relscrr male kat_age employed_prek occ2_prek yrwage_prek lnyrwage_prek wherenow
reshape wide                                                                                                                   relscrr male kat_age employed_prek occ2_prek yrwage_prek lnyrwage_prek wherenow, i(sampleid hhid) j(relscrr2)
label values relscrr0 t6f
label values relscrr1 t6f

**** flag observations coming from this data source
gen            sample_dnors_ind=1
label variable sample_dnors_ind "sample flag: DNORS individual (adult module) variables"

tempfile labordata
save `labordata'
clear


*********************************
*********************************
***** 3. Other data sources *****
*********************************
*********************************

*******************************
*** Census block statistics ***
*******************************
use `root'4.auxilliary_data/Census2000/katrina_block_stats.dta
ren stfid blockid00
joinby blockid00 using "`root'NOLA_avg_riskscores.dta", unmatched(both)
tab _m
drop _m
ren population_200 population
ren mean_09022005 flooding
label variable flooding "depth of flooding 9-2-2005"
foreach var in white black ameri_es asian hawn_pi other mult_race hispanic males females age_under5 age_5_17 age_18_21 age_22_29 age_30_39 age_40_49 age_50_64 age_65_up {
gen bl_`var' = `var'/population
label variable bl_`var' "block percent `var'"
drop `var'
}
foreach var in owner_occupied renter_occupied vacant {
gen bl_`var' = `var'/housing_units
label variable bl_`var' "block percent `var'"
drop `var'
}
foreach var in hsehld_1_m hsehld_1_f marhh_chd marhh_no_c mhh_child fhh_child {
gen bl_`var' = `var'/households
label variable bl_`var' "block percent `var'"
drop `var'
}
foreach var in med_age ave_hh_sz ave_fam_sz population families households housing_units {
ren `var' bl_`var'
}

keep blockid00 neighborhood flooding riskscore_* bl_white bl_black bl_other bl_ameri_es bl_asian bl_hawn_pi bl_other bl_mult_race bl_hispanic bl_males bl_females bl_age_under5 bl_age_5_17 bl_age_18_21 bl_age_22_29 bl_age_30_39 bl_age_40_49 bl_age_50_64 bl_age_65_up bl_owner_occupied bl_renter_occupied bl_vacant bl_hsehld_1_m bl_hsehld_1_f bl_marhh_chd bl_marhh_no_c bl_mhh_child bl_fhh_child bl_med_age bl_ave_hh_sz bl_ave_fam_sz bl_population bl_families bl_households bl_housing_units

**** flag observations coming from this data source
gen            sample_blockdata=1
label variable sample_blockdata "sample flag: block-level Census/FEMA data"

tempfile flooding
save `flooding'
clear


**********************************
*** Census tract level poverty ***
**********************************
use `root'4.auxilliary_data/2000_NOLA_Census_Aggregates/nolatr00.dta
ren tr00 tractid00
gen pct_owner00_tr = owner00_tr / dwellings_tr
gen pct_occup00_tr = occup00_tr / dwellings_tr
keep tractid00 pcwhite00_tr pcblack00_tr pctspnsh_tr pclatino00_tr pcapi00_tr pcother00_tr pop_0_4_tr pop_0_17_tr popul18_tr adltchld_tr elderly_tr ncitizen_tr foreign_tr fb_90_tr fb_95_tr nf_hh_tr pctlang_oth_tr pctengl_tr eng_vw_tr hhwk_tr fem_h_hh_tr fi_lt15k_tr fi_1524k_tr fi_gt75k_tr fi_5074k_tr fi_lt24k_tr pct_pov_tr med99hh_tr med99fam_tr pubasst_tr unemploy_tr femunemp_tr maleunem_tr higheduc_tr m_exprof_tr f_exprof_tr execprof_tr mult_du_tr pct_owner00_tr pct_occup00_tr totpop00_tr dwellings_tr pphh_tr lndarea_tr density00_tr

**** flag observations coming from this data source
gen            sample_tractdata=1
label variable sample_tractdata "sample flag: tract-level Census/FEMA data"

tempfile tractdata
save `tractdata'
clear


***************************************
***************************************
***** 999. Merge sources together *****
***************************************
***************************************

* Assessor's universe
use `assessors'
joinby hhid using `dnors_inc_imps', unmatched(master)
tab _m
drop _m
joinby hhid using `labordata',      unmatched(master)
tab _m
drop _m
joinby blockid00 using `flooding',       unmatched(master)
tab _m
drop _m
gen tractid00 = substr(blockid00,1,11)
joinby tractid00 using `tractdata',      unmatched(master)
tab _m
drop _m
joinby female_head male_head couple_head best_hsdrop best_hs best_somecoll best_bach hh_age black housevalue05_quint using "`psid'/PSID2005_assets_imputed_distribution_for_merge.dta", unmatched(master)
tab _m
drop _m
drop asset_p1-asset_p4
drop asset_p6-asset_p14
drop asset_p16-asset_p24
drop asset_p26-asset_p34
drop asset_p36-asset_p44
drop asset_p46-asset_p54
drop asset_p56-asset_p64
drop asset_p66-asset_p74
drop asset_p76-asset_p84
drop asset_p86-asset_p94
drop asset_p96-asset_p99

drop pid insample roadhome23_1 roadhome23_2 roadhome23_3 roadhome23_4 streetnum roadhome23 duplicates sale_date1 sale_date2 sale_date3 sale_date4 sale_price1 sale_price2 sale_price3 sale_price4 sampleid lnhomevalue05

* Populate sample_flag zeros
foreach var in sample_assessors_universe sample_assessors_dnors sample_dnors_hhfin sample_dnors_ind sample_blockdata sample_tractdata {
replace `var'=0 if `var'==.
}

** Keep geocoded records on Census blocks with between 6 and 50 owner-occupied dwellings

gen sample_dnors = max(sample_dnors_ind,sample_dnors_hhfin)
label variable sample_dnors "sample flag: DNORS respondent household"

gen o________sample_flags___________=.
ren _________opao_vars__________   o________opao_vars__________
gen o________dnors_hh_vars__________=.
gen o________dnors_ind_vars_________=.
gen o________block_vars_____________=.
gen o________tract_vars_____________=.
gen o________psid_asset_imps________=.
gen o________TBD____________________=.

order o________sample_flags___________ sample_assessors_universe sample_assessors_dnors sample_dnors_hhfin sample_dnors_ind sample_dnors sample_blockdata sample_tractdata o________opao_vars__________ taxbill addid improveval05 improveval06 improveval07 improveval08 improveval09 improveval10 improveval11 landval05 landval06 landval07 landval08 landval09 landval10 landval11 homevalue05 valshare06 valshare07 valshare08 valshare09 valshare10 transfer_date purchase_date purchase_year purchase_years_ago purchase_cat purchase_price postk_transfer_date postk_sale postk_sale_date postk_sale_price o________dnors_hh_vars__________ hhid hu_wgt_s hometype own fin_diff damage_home insurance female_head male_head couple_head best_hsdrop best_hs best_somecoll best_bach hh_age black d17_imp d17_impflag d18_impflag m1_impflag m2_impflag m1_imp m2_imp d18_imp damage_prop o________dnors_ind_vars______ relscrr0 relscrr1 male0 male1 kat_age0 kat_age1 employed_prek0 employed_prek1 occ2_prek0 occ2_prek1 yrwage_prek0 yrwage_prek1 lnyrwage_prek0 lnyrwage_prek1 wherenow0 wherenow1 o________block_vars__________ blockid00 address_phys neighborhood flooding risk* bl_white bl_black bl_other bl_ameri_es bl_asian bl_hawn_pi bl_other bl_mult_race bl_hispanic bl_males bl_females bl_age_under5 bl_age_5_17 bl_age_18_21 bl_age_22_29 bl_age_30_39 bl_age_40_49 bl_age_50_64 bl_age_65_up bl_owner_occupied bl_renter_occupied bl_vacant bl_hsehld_1_m bl_hsehld_1_f bl_marhh_chd bl_marhh_no_c bl_mhh_child bl_fhh_child bl_med_age bl_ave_hh_sz bl_ave_fam_sz bl_population bl_families bl_households bl_housing_units o________tract_vars__________ tractid00 pcwhite00_tr pcblack00_tr pctspnsh_tr pclatino00_tr pcapi00_tr pcother00_tr pop_0_4_tr pop_0_17_tr popul18_tr adltchld_tr elderly_tr ncitizen_tr foreign_tr fb_90_tr fb_95_tr nf_hh_tr pctlang_oth_tr pctengl_tr eng_vw_tr hhwk_tr fem_h_hh_tr fi_lt15k_tr fi_1524k_tr fi_gt75k_tr fi_5074k_tr fi_lt24k_tr pct_pov_tr med99hh_tr med99fam_tr pubasst_tr unemploy_tr femunemp_tr maleunem_tr higheduc_tr m_exprof_tr f_exprof_tr execprof_tr mult_du_tr pct_owner00_tr pct_occup00_tr totpop00_tr dwellings_tr pphh_tr lndarea_tr density00_tr o________psid_asset_imps________ asset_p* o________TBD__________
compress

save "`ouputdir'workfile_noimputations.dta", replace



