pause off
clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000

local dnors     ""  /* Directory where the dnors survey data are stored */
local ouputdir  ""  /* Directory where resulting merged data will be stored */
local roadhome1 ""  /* Directory where 1st transfer of admin records from RH are stored */
local roadhome2 ""  /* Directory where 2nd transfer of admin records from RH are stored */
local assessors ""  /* Directory where OPAO data are stored */


*************************************************************
*** 1. Create 3 main files that will be used in the merge ***
*************************************************************
use "`assessors'NOLA_assessors_data_clean.dta"
replace taxbill = substr(taxbill,2,length(taxbill)-2)
joinby taxbill using "`assessors'assessments05_06_07_09_10_11_with_block_traits.dta", unmatched(both) update
tab _m
drop if _m==1
drop _m
keep taxbill improveval* landval* sale_date* sale_price* blockid00 tractid00
save "`assessors'assessments05_06_07_08_09_10_11_with_blockIDs.dta", replace
clear

****************************************************************
*** (1) a. Full universe of Assessor's data (ownocc and not) ***
****************************************************************
insheet using "`roadhome1'OPAO_records_Without Matching_RH_UPDATED.csv"
keep taxbill
duplicates drop taxbill, force
joinby taxbill using "`assessors'assessments05_06_07_08_09_10_11_with_blockIDs.dta", unmatched(both)
duplicates drop taxbill, force

************************************************************
*** (1) a. i.  records in Dave Bowman's non-matched file ***
************************************************************
preserve
keep if _m==3
drop _m
save "`assessors'assessments05_06_07_08_09_10_11_DAVE_BOWMAN_NONMATCHES.dta", replace
restore

******************************************************************
*** (1) a. ii. records *not* in Dave Bowman's non-matched file ***
******************************************************************
preserve
keep if _m==2
drop _m
save "`assessors'assessments05_06_07_08_09_10_11_DAVE_BOWMAN_MATCHES.dta", replace
restore
clear


****************************************************************************
*** (1) b. Road Home records (with and without Assessor's information)	 ***
****************************************************************************
insheet using "`roadhome2'/EstimateChanges_v2_TYPE1CHANGES.csv", case

duplicates report LA_ID
pause DUPLICATES IN ROAD HOME TYPE 1 "HISTORY" DATA (DUPLICATES OK)

ren TYPE1_AMT type1
foreach var in type1 {
ren `var' aux1
gen  aux2 =      subinstr(aux1,"$","",.)
gen `var' = real(subinstr(aux2,",","",.))
drop aux*
}
ren DATE T1AppraiseDate
foreach var in T1AppraiseDate {
ren `var' aux
gen loc_slash1 = 0
gen loc_slash2 = 0
forval ii = 1/13 {
replace loc_slash1=`ii' if substr(aux,`ii',1)=="/" & loc_slash1==0
replace loc_slash2=`ii' if substr(aux,`ii',1)=="/" & loc_slash1>0
}
gen month = real(substr(aux,           1,loc_slash1-1))
gen day   = real(substr(aux,loc_slash1+1,loc_slash2-loc_slash1-1))
gen year  = real(substr(aux,loc_slash2+1,99          ))
replace year = year + 2000 if year<20
replace year = year + 1900 if year<100
gen `var' = mdy(month,day,year)
format `var' %d
drop aux loc_slash1 loc_slash2 month day year
}
reshape wide type1 T1AppraiseDate, i(LA_ID) j(Change)
order LA_ID type1* T1AppraiseDate*
ren type10 type1a
ren type11 type1b
ren type12 type1c
ren type13 type1d
ren type14 type1e
ren type15 type1f
ren T1AppraiseDate0 T1AppraiseDatea
ren T1AppraiseDate1 T1AppraiseDateb
ren T1AppraiseDate2 T1AppraiseDatec
ren T1AppraiseDate3 T1AppraiseDated
ren T1AppraiseDate4 T1AppraiseDatee
ren T1AppraiseDate5 T1AppraiseDatef

duplicates report LA_ID
pause DUPLICATES IN ROAD HOME TYPE 1 "HISTORY" DATA AFTER RESHAPING (DUPLICATES NOT OK)

tempfile type1histories
save `type1histories'
clear




insheet using "`roadhome2'/EstimateChanges_v2_TYPE2CHANGES.csv", case

duplicates report LA_ID
pause DUPLICATES IN ROAD HOME TYPE 2 "HISTORY" DATA (DUPLICATES OK)

ren HETYPE2STValue type2
foreach var in type2 {
ren `var' aux1
gen  aux2 =      subinstr(aux1,"$","",.)
gen `var' = real(subinstr(aux2,",","",.))
drop aux*
}
ren HETYPE2STCreateDate T2AppraiseDate
foreach var in T2AppraiseDate {
ren `var' aux
gen loc_slash1 = 0
gen loc_slash2 = 0
forval ii = 1/13 {
replace loc_slash1=`ii' if substr(aux,`ii',1)=="/" & loc_slash1==0
replace loc_slash2=`ii' if substr(aux,`ii',1)=="/" & loc_slash1>0
}
gen month = real(substr(aux,           1,loc_slash1-1))
gen day   = real(substr(aux,loc_slash1+1,loc_slash2-loc_slash1-1))
gen year  = real(substr(aux,loc_slash2+1,99          ))
replace year = year + 2000 if year<20
replace year = year + 1900 if year<100
gen `var' = mdy(month,day,year)
format `var' %d
drop aux loc_slash1 loc_slash2 month day year
}
reshape wide type2 T2AppraiseDate, i(LA_ID) j(Change)
order LA_ID type2* T2AppraiseDate*
ren type20 type2a
ren type21 type2b
ren type22 type2c
ren type23 type2d
ren type24 type2e
ren type25 type2f
ren type26 type2g
ren T2AppraiseDate0 T2AppraiseDatea
ren T2AppraiseDate1 T2AppraiseDateb
ren T2AppraiseDate2 T2AppraiseDatec
ren T2AppraiseDate3 T2AppraiseDated
ren T2AppraiseDate4 T2AppraiseDatee
ren T2AppraiseDate5 T2AppraiseDatef
ren T2AppraiseDate6 T2AppraiseDateg

duplicates report LA_ID
pause DUPLICATES IN ROAD HOME TYPE 2 "HISTORY" DATA AFTER RESHAPING (DUPLICATES NOT OK)

tempfile type2histories
save `type2histories'
clear



insheet using "`roadhome1'/All RH w Assessor Orleans.csv", case
duplicates report LA_ID
duplicates drop
duplicates report LA_ID
pause DUPLICATES IN DAVE BOWMAN'S "MATCHED (TO ASSESSOR'S DATA) ROAD HOME ELIGIBLES" FILE

tempfile matches1
save    `matches1'
clear


insheet using "`roadhome2'/Inelig_w_HAP_and_OPAO.csv", case
duplicates report LA_ID
duplicates drop
duplicates report LA_ID
pause DUPLICATES IN DAVE BOWMAN'S "MATCHED (TO ASSESSOR'S DATA) ROAD HOME INELIGIBLES" FILE BEFORE RECODES

drop Total_RH CompensationGrantRequestedAmount ElevationRequestedAmount ACGRequestedAmount IMM_FINAL MinOfLastClosingDate MaxOfLastClosingDate 
foreach var of varlist sale_date* {
gen aux = mdy(12,31,1899) + `var'
drop `var'
gen `var' = string(month(aux))+"/"+string(day(aux))+"/"+string(year(aux)) if aux<.
drop aux
}

duplicates report LA_ID
pause DUPLICATES IN DAVE BOWMAN'S "MATCHED (TO ASSESSOR'S DATA) ROAD HOME INELIGIBLES" FILE AFTER RECODES

tempfile matches2
save    `matches2'
clear




use `matches1'
joinby LA_ID using `matches2', unmatched(both)
tab _m
drop _m

duplicates report LA_ID
pause DUPLICATES AFFTER APPENDING "ROAD HOME ELIGIBLES" AND "INELIGIBLES" FILES

joinby LA_ID using `type1histories', unmatched(both)
tab _m
drop _m

duplicates report LA_ID
pause DUPLICATES AFTER MERGING ON TYPE 1 APPRAISAL HISTORIES

joinby LA_ID using `type2histories', unmatched(both)
tab _m
drop _m

duplicates report LA_ID
pause DUPLICATES AFTER MERGING ON TYPE 2 APPRAISAL HISTORIES

duplicates drop
duplicates report LA_ID
pause DUPLICATES AFTER FORCED DROP OF DUPLICATES IN ROAD HOME DATA (WERE THERE ANY DUPLICATES?)

foreach var in Status RH_AWARD PrimaryApplicantRace PrimaryApplicantEthnicity PrimaryApplicantGender PrimaryApplicantIsElderly {
ren `var' aux
encode aux, gen(`var')
drop aux
}
foreach var in EstimatedCostofDamage PreStormValue ClosingFEMAInsuranceValue ClosingFloodInsuranceValue ClosingHomeInsuranceValue HETYPE1STType1RepairRebuildSubto HETYPE2STType2RepairRebuildSubto Total_RH CompensationGrantRequestedAmount ElevationRequestedAmount ACGRequestedAmount IMM_FINAL improveval05 improveval06 improveval07 improveval09 improveval10 improveval11 landval05 landval06 landval07 landval09 landval10 landval11 sale_price1 sale_price2 sale_price3 sale_price4 {
ren `var' aux
gen `var' = real(subinstr(aux,",","",.))
drop aux
}
foreach var in MinOfLastClosingDate MaxOfLastClosingDate sale_date1 sale_date2 sale_date3 sale_date4 {
ren `var' aux
gen loc_slash1 = 0
gen loc_slash2 = 0
forval ii = 1/13 {
replace loc_slash1=`ii' if substr(aux,`ii',1)=="/" & loc_slash1==0
replace loc_slash2=`ii' if substr(aux,`ii',1)=="/" & loc_slash1>0
}
gen month = real(substr(aux,           1,loc_slash1-1))
gen day   = real(substr(aux,loc_slash1+1,loc_slash2-loc_slash1-1))
gen year  = real(substr(aux,loc_slash2+1,99          ))
replace year = year + 2000 if year<20
replace year = year + 1900 if year<100
gen `var' = mdy(month,day,year)
format `var' %d
drop aux loc_slash1 loc_slash2 month day year
}
gen lnhomevalue05_hat = 1.391765 + .8164848*ln(PreStormValue)
gen blockid00=string(GISCensusBlockFIPSCode,"%15.0f")
gen tractid00=substr(blockid00,1,11)

save  "`roadhome1'AllRoadHomeAppended.dta", replace

preserve
keep if improveval05<.
save "`roadhome1'AllRoadHomeAppended_OPAO_MATCHES.dta", replace
restore
preserve
keep if improveval05==.
save "`roadhome1'AllRoadHomeAppended_OPAO_NONMATCHES.dta", replace
restore






***********************************************************************
*** (2) Load Assessor's data and attempt sequence of merge attempts ***
***********************************************************************

global joinbylist1 "improveval05 improveval06 improveval07 improveval09 improveval10 improveval11 landval05 landval06 landval07 landval09 landval10 landval11 sale_date1 sale_date2 sale_date3 sale_date4 sale_price1 sale_price2 sale_price3 sale_price4 blockid00"
global joinbylist2 "improveval05 improveval06 improveval07 improveval09 improveval10 improveval11 landval05 landval06 landval07 landval09 landval10 landval11 sale_date1 sale_date2 sale_date3 sale_date4 sale_price1 sale_price2 sale_price3 sale_price4 tractid00"
global joinbylist3 "improveval05 improveval06 improveval07 improveval09 improveval10 improveval11 landval05 landval06 landval07 landval09 landval10 landval11 sale_date1 sale_date2 sale_date3 sale_date4 sale_price1 sale_price2 sale_price3 sale_price4"

************************************************************************
*** (2) a. Sqequentially try to merge on Road Home data that matched ***
************************************************************************
use "`roadhome1'/AllRoadHomeAppended_OPAO_MATCHES.dta"
tempfile NextUsingFile
save `NextUsingFile', replace

use "`assessors'/DNORS_gregory/Michigan_Backup/1.data/2.assessors/Purchased_Extract/assessments05_06_07_08_09_10_11_DAVE_BOWMAN_MATCHES.dta"
gen needmerge=1
gen temptiebreak=.
gen tempsort=.
gen LA_ID = ""

forval attempt=1/3 {
global attempt = `attempt'
replace needmerge=0 if LA_ID!=""
cap drop temptiebreak
gen temptiebreak = uniform()
sort   needmerge ${joinbylist$attempt} temptiebreak
bysort needmerge ${joinbylist$attempt}: replace tempsort = _n

preserve
clear
use `NextUsingFile'
assert LA_ID!=""
gen needmerge=1
gen temptiebreak = uniform()
sort   needmerge ${joinbylist$attempt} temptiebreak
bysort needmerge ${joinbylist$attempt}: gen tempsort = _n
tempfile NextUsingFile
save `NextUsingFile', replace
restore

duplicates report ${joinbylist$attempt}
joinby ${joinbylist$attempt} tempsort using `NextUsingFile', unmatched(both) update
tab _m
count if LA_ID==""
duplicates report ${joinbylist$attempt} if _m != 2

preserve
keep if _m==2
drop needmerge temptiebreak tempsort _merge
tempfile NextUsingFile
save `NextUsingFile', replace
restore

drop if _m==2
drop _m
}

drop temptiebreak

tempfile OPAO_and_RoadHome_MATCHES
save    `OPAO_and_RoadHome_MATCHES'
clear


*************************************************************************************************************************************
*** (2) b. Merge on Road Home data that Dave Bowman could not match exactly by block and keep match with closest 2005 home value: ***
***       NOTE: many of these applicants were deemed ineligible because they were not homeowners.  Consistent with that pattern,  ***
***       many are assigned in this step to rental units on high (or even 100%) renter-occupancy blocks, and will be dropped when ***
***       we restrict to (year-2005) owner-occupied homes                                                                         ***
*************************************************************************************************************************************
use "`assessors'assessments05_06_07_08_09_10_11_DAVE_BOWMAN_NONMATCHES.dta"
gen lnhomevalue05 = ln(improveval05+landval05)

duplicates report taxbill
joinby blockid00 using "`roadhome1'AllRoadHomeAppended_OPAO_NONMATCHES.dta", unmatched(both) update
tab _m
duplicates report taxbill if _m != 2
keep if _m==3  /* Keep only matches, then reattach non-matches after breaking ties*/
drop _m
gen double tiebreaker=.000001*uniform()
gen double diff=abs(lnhomevalue05-lnhomevalue05_hat+tiebreaker)
replace diff = 99999*uniform() if diff==.

*
* Iterate: 
*    a. (For each LA_ID, find the best matching taxbill)
*    b. (Remove matched taxbill from target pool: "throwing back" LA_IDs that are not the taxbill's best matching LA_ID)
*    c. go to (a) if any taxbills were assigned multiple LA_IDs
*
gen bestmatch=0
forval ii=1/100 {
di `ii'
count if bestmatch==1
cap drop mindiff min_mindiff taxbill_alreadymatched LA_ID_alreadymatched
egen taxbill_alreadymatched     = max(bestmatch), by(taxbill)
egen   LA_ID_alreadymatched     = max(bestmatch), by(LA_ID  )

drop if taxbill_alreadymatched==1 & bestmatch==0
drop if   LA_ID_alreadymatched==1 & bestmatch==0
egen double     mindiff = min(   diff  ), by(taxbill)
egen double min_mindiff = min(mindiff  ), by(LA_ID)
replace bestmatch=1 if diff==mindiff & mindiff==min_mindiff & diff!=.
count if bestmatch==1
}

keep if diff==mindiff & diff<.
drop tiebreaker diff bestmatch taxbill_alreadymatched LA_ID_alreadymatched mindiff min_mindiff

joinby taxbill using "`assessors'assessments05_06_07_08_09_10_11_DAVE_BOWMAN_NONMATCHES.dta", unmatch(both) update
tab _m
drop _m

tempfile OPAO_and_RoadHome_NONMATCHES
save    `OPAO_and_RoadHome_NONMATCHES'
clear


*****************************
*** (2) c. Append results ***
*****************************
use          `OPAO_and_RoadHome_MATCHES'
append using `OPAO_and_RoadHome_NONMATCHES'

duplicates report taxbill


*** Perform Assessor's data recodes

gen postk_sale          = 0
gen postk_sale_price    = .
gen postk_sale_date     = .
gen purchase_date       = .
gen purchase_price      = .
gen postk_transfer_date = .
gen transfer_date       = .
format postk_sale_date     %d
format purchase_date       %d
format postk_transfer_date %d
format transfer_date       %d
*gen roadhome23 = 0 if improveval08<.
forval ii=1/4 {
replace postk_sale =           1               if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<. & sale_price`ii'>0 & sale_price`ii'<.
replace postk_sale_price    =  sale_price`ii'  if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_sale_date & sale_price`ii'>0 & sale_price`ii'<.
replace postk_sale_date     =  sale_date`ii'   if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_sale_date & sale_price`ii'>0 & sale_price`ii'<.
replace purchase_price      =  sale_price`ii'  if sale_date`ii' < mdy(8,29,2005) & sale_price`ii'>0 & ((sale_date`ii'>purchase_date)|(purchase_date==.))
replace purchase_date       =  sale_date`ii'   if sale_date`ii' < mdy(8,29,2005) & sale_price`ii'>0 & ((sale_date`ii'>purchase_date)|(purchase_date==.))
replace postk_transfer_date =  sale_date`ii'   if sale_date`ii' > mdy(8,29,2005) & sale_date`ii'<postk_transfer_date
replace transfer_date       =  sale_date`ii'   if sale_date`ii' < mdy(8,29,2005) & ((sale_date`ii'>transfer_date)|(transfer_date==.))
}

**** Pre-katrina home value
cap drop homevalue05
cap drop lnhomevalue05
gen            homevalue05 = improveval05+landval05
label variable homevalue05 "Last assessed home value prior to Katrina"
gen            lnhomevalue05 = ln(homevalue05)
label variable lnhomevalue05 "Log - last assessed home value prior to Katrina"

**** Value of losses as a fraction of home's value
gen            valshare06 = min(2,improveval06/improveval05) if improveval05<. & improveval06<.
gen            valshare07 = min(2,improveval07/improveval05) if improveval05<. & improveval07<.
gen            valshare08 = min(2,improveval08/improveval05) if improveval05<. & improveval08<.
gen            valshare09 = min(2,improveval09/improveval05) if improveval05<. & improveval09<.
gen            valshare10 = min(2,improveval10/improveval05) if improveval05<. & improveval10<.
gen            valshare11 = min(2,improveval11/improveval05) if improveval05<. & improveval11<.
label variable valshare06 "ratio of 06 improvement value to pre-K improvement value"
label variable valshare07 "ratio of 07 improvement value to pre-K improvement value"
label variable valshare08 "ratio of 08 improvement value to pre-K improvement value"
label variable valshare09 "ratio of 09 improvement value to pre-K improvement value"
label variable valshare10 "ratio of 10 improvement value to pre-K improvement value"
label variable valshare11 "ratio of 11 improvement value to pre-K improvement value"

**** Classify by national housevalue quintile for merging with PSID asset data
gen     housevalue05_quint = 4 if homevalue05<.
replace housevalue05_quint = 3 if homevalue05<310000 & homevalue05<.
replace housevalue05_quint = 2 if homevalue05<185000 & homevalue05<.
replace housevalue05_quint = 1 if homevalue05<125000 & homevalue05<.
replace housevalue05_quint = 0 if homevalue05< 75790 & homevalue05<.

**** purchase year
gen            purchase_year = year(purchase_date)
label variable purchase_year "year pre-K home was purchased"
gen            purchase_years_ago = 2005-purchase_year
label variable purchase_years_ago "2005 minus year pre-K home was purchased"

**** purchase date category
gen purchase_cat = 1
replace purchase_cat = 1 if inrange(purchase_date,mdy(1,1,1900),mdy(12,31,1989))==1
replace purchase_cat = 2 if inrange(purchase_date,mdy(1,1,1990),mdy(12,31,1999))==1
replace purchase_cat = 3 if inrange(purchase_date,mdy(1,1,2000),mdy(8,29,2005))==1
label define purchase_cat_lab 1 "Prior to 1990" 2 "1990-1999" 3 "2000-2005"
label values purchase_cat purchase_cat_lab

tempfile OPAO_and_RoadHome_FullyMerged
save    `OPAO_and_RoadHome_FullyMerged'
clear




*********************************************************************************************************************
*********************************************************************************************************************
*** 3. Do recodes                                                                                                 ***
*********************************************************************************************************************
*********************************************************************************************************************
use `OPAO_and_RoadHome_FullyMerged'

gen AssessorMatch2 = improveval05<.
gen ownocc = improveval06<.

gen rh_black=PrimaryApplicantRace==6  if PrimaryApplicantRace<.
gen rh_white=PrimaryApplicantRace==10 if PrimaryApplicantRace<.

gen     type1_APPEAL = HETYPE1STType1RepairRebuildSubto
gen     type1        = HETYPE1STType1RepairRebuildSubto
replace type1        = type1f if type1f<.
replace type1        = type1e if type1e<.
replace type1        = type1d if type1d<.
replace type1        = type1c if type1c<.
replace type1        = type1b if type1b<.
replace type1        = type1a if type1a<.

gen     type2_APPEAL = HETYPE2STType2RepairRebuildSubto
gen     type2        = HETYPE2STType2RepairRebuildSubto
replace type2        = type2g if type2g<.
replace type2        = type2f if type2f<.
replace type2        = type2e if type2e<.
replace type2        = type2d if type2d<.
replace type2        = type2c if type2c<.
replace type2        = type2b if type2b<.
replace type2        = type2a if type2a<.

gen estimated_repcost   = EstimatedCostofDamage
gen lnestimated_repcost = ln(EstimatedCostofDamage)

gen type2_miss=type2==. if type1<.

gen rh_insurance = ClosingFEMAInsuranceValue + ClosingFloodInsuranceValue + ClosingHomeInsuranceValue
gen rh_insurance_pct = min(1,rh_insurance / type2) if type2<. & rh_insurance<.

* Construct repair status
gen damaged06 = (valshare06<.7)                    if                   improveval06!=.
gen damaged07 = damaged06*(valshare07<=valshare06) if improveval07!=. & improveval06!=.
gen damaged08 = damaged06*(valshare08<=valshare06) if improveval08!=. & improveval06!=.
gen damaged09 = damaged06*(valshare09<=valshare06) if improveval09!=. & improveval06!=.
gen damaged10 = damaged06*(valshare10<=valshare06) if improveval10!=. & improveval06!=.
gen damaged11 = damaged06*(valshare11<=valshare06) if improveval11!=. & improveval06!=.

* Impose monotonicity
replace damaged06=1 if damaged06==0 & inlist(1,damaged11,damaged10,damaged09,damaged08,damaged07)==1
replace damaged07=1 if damaged07==0 & inlist(1,damaged11,damaged10,damaged09,damaged08)==1
replace damaged08=1 if damaged08==0 & inlist(1,damaged11,damaged10,damaged09)==1
replace damaged09=1 if damaged09==0 & inlist(1,damaged11,damaged10)==1
replace damaged10=1 if damaged10==0 & inlist(1,damaged11)==1


foreach yr in 06 07 08 09 10 11 {
   gen repaired`yr' = (1-damaged`yr')*(1-postk_sale)
}

duplicates report taxbill
pause VERIFY THAT TAXBILL IS STILL UNIQUE AFTER FINAL RECODES

save "`ouputdir'/Merged_RoadHome_Assessors_noimputations", replace
clear


*pause on
use "`ouputdir'workfile_noimputations.dta", replace

duplicates report taxbill
duplicates drop address_phys taxbill blockid00, force
pause CHECK FOR DUPLICATES IN NON-ROAD HOME MERGED DATA FILE

joinby taxbill using "`ouputdir'/Merged_RoadHome_Assessors_noimputations", unmatched(master)
tab _m
drop _m

*********************************************************************************************************************
*********************************************************************************************************************
*** 4. Restrict sample and save                                                                                   ***
*********************************************************************************************************************
*********************************************************************************************************************
drop housevalue05_quint AssessorMatch2 type2_miss rh_insurance_pct sale_price1 sale_price2 sale_price3 sale_price4 sale_date1 sale_date2 sale_date3 sale_date4

duplicates report taxbill
pause CHECK FOR DUPLICATES AFTER MERGING ON THE ROAD HOME DATA (CREATED BY THIS FILE)

keep if improveval06<. & blockid00!=""

duplicates report taxbill
pause CHECK FOR DUPLICATES AFTER RESTRICTING TO OWNER OCCUPIED HOMES

egen count=sum(1), by(blockid00)
keep if inrange(count,5,50)==1
drop count

duplicates report taxbill
pause CHECK FOR DUPLICATES AFTER FINAL SAMPLE RESTRICTIONS

gen o________road_home_vars_________=.

order o________sample_flags___________ sample_assessors_universe sample_assessors_dnors sample_dnors_hhfin sample_dnors_ind sample_dnors sample_blockdata sample_tractdata o________opao_vars__________ taxbill addid improveval05 improveval06 improveval07 improveval08 improveval09 improveval10 improveval11 landval05 landval06 landval07 landval08 landval09 landval10 landval11 homevalue05 lnhomevalue05 lnhomevalue05_hat valshare06 valshare07 valshare08 valshare09 valshare10 valshare11 damaged06 damaged07 damaged08 damaged09 damaged10 damaged11 repaired06 repaired07 repaired08 repaired09 repaired10 repaired11 transfer_date purchase_date purchase_year purchase_years_ago purchase_cat purchase_price postk_transfer_date postk_sale postk_sale_date postk_sale_price o________dnors_hh_vars__________ hhid hu_wgt_s segment hometype own fin_diff damage_home insurance female_head male_head couple_head best_hsdrop best_hs best_somecoll best_bach hh_age black d17_imp d17_impflag d18_impflag m1_impflag m2_impflag m1_imp m2_imp d18_imp damage_prop o________dnors_ind_vars______ relscrr0 relscrr1 male0 male1 kat_age0 kat_age1 employed_prek0 employed_prek1 occ2_prek0 occ2_prek1 yrwage_prek0 yrwage_prek1 lnyrwage_prek0 lnyrwage_prek1 wherenow0 wherenow1 o________block_vars__________ blockid00 address_phys neighborhood flooding risk* bl_white bl_black bl_other bl_ameri_es bl_asian bl_hawn_pi bl_other bl_mult_race bl_hispanic bl_males bl_females bl_age_under5 bl_age_5_17 bl_age_18_21 bl_age_22_29 bl_age_30_39 bl_age_40_49 bl_age_50_64 bl_age_65_up bl_owner_occupied bl_renter_occupied bl_vacant bl_hsehld_1_m bl_hsehld_1_f bl_marhh_chd bl_marhh_no_c bl_mhh_child bl_fhh_child bl_med_age bl_ave_hh_sz bl_ave_fam_sz bl_population bl_families bl_households bl_housing_units o________tract_vars__________ tractid00 pcwhite00_tr pcblack00_tr pctspnsh_tr pclatino00_tr pcapi00_tr pcother00_tr pop_0_4_tr pop_0_17_tr popul18_tr adltchld_tr elderly_tr ncitizen_tr foreign_tr fb_90_tr fb_95_tr nf_hh_tr pctlang_oth_tr pctengl_tr eng_vw_tr hhwk_tr fem_h_hh_tr fi_lt15k_tr fi_1524k_tr fi_gt75k_tr fi_5074k_tr fi_lt24k_tr pct_pov_tr med99hh_tr med99fam_tr pubasst_tr unemploy_tr femunemp_tr maleunem_tr higheduc_tr m_exprof_tr f_exprof_tr execprof_tr mult_du_tr pct_owner00_tr pct_occup00_tr totpop00_tr dwellings_tr pphh_tr lndarea_tr density00_tr o________psid_asset_imps________ asset_p* o________road_home_vars_________ LA_ID GISCensusBlockFIPSCode ClosingOption LMI GISOrleansNeighborhoodName GISOrleansPlanningDistrictName AssessorMatch Status RH_AWARD PrimaryApplicantRace PrimaryApplicantEthnicity PrimaryApplicantGender PrimaryApplicantIsElderly EstimatedCostofDamage PreStormValue ClosingFEMAInsuranceValue ClosingFloodInsuranceValue ClosingHomeInsuranceValue HETYPE1STType1RepairRebuildSubto HETYPE2STType2RepairRebuildSubto Total_RH CompensationGrantRequestedAmount ElevationRequestedAmount ACGRequestedAmount IMM_FINAL MinOfLastClosingDate MaxOfLastClosingDate o________TBD__________ 
compress

save "`ouputdir'/Merged_RoadHome_Assessors_noimputations", replace




