clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000

local ouputdir    ""      /* Location where processed data is stored */


use "`ouputdir'Merged_RoadHome_Assessors_noimputations.dta"

bysort blockid00: gen aux1=uniform() if _n==1
egen aux2=mean(aux1), by(blockid)
*keep if aux2<.25
drop aux*

**************************************************************
***** 0. Generate variables to be used during imputation *****
**************************************************************

* Generate copies of important variables with dummied-out missings for use in imputations
foreach yr in 06 07 08 09 10 11 {
gen     damaged_miss`yr' = (damaged`yr'>=.)
gen     damaged_nomiss`yr' = damaged`yr'
replace damaged_nomiss`yr' = 0 if damaged`yr'>=.
}

foreach var in type1 type2 type1_APPEAL type2_APPEAL rh_insurance LMI PreStormValue {
gen     `var'_miss   = (`var'>=.)
gen     `var'_nomiss =  `var'
replace `var'_nomiss =   0    if `var'>=.
}

* Obtain principal components from Census tract-level variables
qui pca bl_*
qui predict factor_bl1-factor_bl6

* Obtain principal components from Census tract-level variables
qui pca *_tr
qui predict factor_tr1-factor_tr5

************************************************
***** 1. Flag variables needing imputation *****
************************************************
label define implab 1 "1. non-imputed"
label define implab 2 "2. imputed - near bracket boundary", add
label define implab 3 "3. imputed - far from closed bracket", add
label define implab 4 "4. imputed from open bracket", add
label define implab 5 "5. imputed non-response", add
label define implab 6 "6. imputed non-dnors sample", add
label define implab 7 "6. imputed non-road home sample", add

foreach var in hometype own fin_diff damage_home insurance damage_prop asset_p5 asset_p15 asset_p25 asset_p35 asset_p45 asset_p55 asset_p65 asset_p75 asset_p85 asset_p95 {
gen     `var'_imp = `var'
gen     `var'_impflag = 1 if `var'_imp<.
replace `var'_impflag = 5 if `var'_imp>=. & sample_dnors_hhfin+sample_dnors_ind>=1
}

foreach var in type1 type2 type1_APPEAL type2_APPEAL rh_insurance LMI PreStormValue {
gen     `var'_imp = `var'
gen     `var'_impflag = 1 if `var'_imp<.
replace `var'_impflag = 6 if `var'_imp>=.
label values `var'_impflag implab
order `var'_impflag, after(o________road_home_vars_________)
order `var'_imp    , after(o________road_home_vars_________)
cap order `var'    , after(o________road_home_vars_________)
}

foreach var in d18 m2 m1 d17 damage_prop insurance damage_home fin_diff own hometype asset_p5 asset_p15 asset_p25 asset_p35 asset_p45 asset_p55 asset_p65 asset_p75 asset_p85 asset_p95 {
replace `var'_impflag = 5 if `var'_imp>=. & sample_dnors==1
replace `var'_impflag = 6 if `var'_imp>=. & sample_dnors==0
label values `var'_impflag implab
order `var'_impflag, after(o________dnors_hh_vars__________)
order `var'_imp    , after(o________dnors_hh_vars__________)
cap order `var'    , after(o________dnors_hh_vars__________)
}

foreach var in relscrr wherenow lnyrwage_prek yrwage_prek occ2_prek employed_prek male kat_age {
foreach hh in 0 1 {
gen     `var'`hh'_imp = `var'`hh'
gen     `var'`hh'_impflag = 1 if `var'`hh'_imp<.
replace `var'`hh'_impflag = 5 if `var'`hh'_imp>=. & relscrr`hh'<. & sample_dnors==1
replace `var'`hh'_impflag = 6 if `var'`hh'_imp>=. & sample_dnors==0
label values `var'`hh'_impflag implab
order `var'`hh'_impflag, after(o________dnors_ind_vars_________)
order `var'`hh'_imp    , after(o________dnors_ind_vars_________)
cap order `var'`hh'    , after(o________dnors_ind_vars_________)
}
}

foreach var in postk_transfer_date postk_sale postk_sale_date postk_sale_price {
gen     `var'_imp = `var'
gen     `var'_impflag = 6 if (improveval08==.) & (improveval09==.) & (improveval10==.) & (improveval11==.)
replace `var'_impflag = 1 if `var'_impflag==.
label values `var'_impflag implab
order `var'_impflag, after(o________opao_vars__________)
order `var'_imp    , after(o________opao_vars__________)
cap order `var'    , after(o________opao_vars__________)
}

foreach var in damaged06 damaged07 damaged08 damaged09 damaged10 damaged11 {
gen     `var'_imp = `var'
gen     `var'_impflag = 1 if `var'_imp<.
replace `var'_impflag = 5 if `var'_imp>=. & sample_dnors_hhfin+sample_dnors_ind>=1
replace `var'_impflag = 6 if `var'_imp>=. & sample_dnors_hhfin+sample_dnors_ind==0
label values `var'_impflag implab
order `var'_impflag, after(o________opao_vars__________)
order `var'_imp    , after(o________opao_vars__________)
cap order `var'    , after(o________opao_vars__________)
}
replace damaged07_imp=0 if damaged06_imp==0
replace damaged08_imp=0 if damaged07_imp==0
replace damaged09_imp=0 if damaged08_imp==0
replace damaged10_imp=0 if damaged09_imp==0
replace damaged11_imp=0 if damaged10_imp==0
replace damaged07_impflag=1 if damaged07_imp==0
replace damaged08_impflag=1 if damaged08_imp==0
replace damaged09_impflag=1 if damaged09_imp==0
replace damaged10_impflag=1 if damaged10_imp==0
replace damaged11_impflag=1 if damaged11_imp==0


*************************************************
***** 2. Create block-level damage measures *****
*************************************************
foreach var in damaged06 damaged07 damaged08 damaged09 damaged10 damaged11 {
egen    block_tot`var'  = sum(`var'  ), by(blockid00)
egen    block_N         = sum(`var'<.), by(blockid00)
gen     block_`var'     = (block_tot`var'      ) / (block_N    )
gen     block_`var'_loo = (block_tot`var'-`var') / (block_N - 1) if `var'<.
replace block_`var'_loo = (block_tot`var'      ) / (block_N    ) if `var'>=.
drop    block_tot`var' block_N
}

**********************************
***** 3. Perform Imputations *****
**********************************
global X_dam          "damaged_nomiss06 damaged_nomiss07 damaged_nomiss08 damaged_nomiss09 damaged_nomiss10 damaged_miss06 damaged_miss07 damaged_miss08 damaged_miss09 damaged_miss10"
global X_dam06        "                 damaged_nomiss07 damaged_nomiss08 damaged_nomiss09 damaged_nomiss10                damaged_miss07 damaged_miss08 damaged_miss09 damaged_miss10"
global X_dam07        "damaged_nomiss06                  damaged_nomiss08 damaged_nomiss09 damaged_nomiss10 damaged_miss06                damaged_miss08 damaged_miss09 damaged_miss10"
global X_dam08        "damaged_nomiss06 damaged_nomiss07                  damaged_nomiss09 damaged_nomiss10 damaged_miss06 damaged_miss07                damaged_miss09 damaged_miss10"
global X_dam09        "damaged_nomiss06 damaged_nomiss07 damaged_nomiss08                  damaged_nomiss10 damaged_miss06 damaged_miss07 damaged_miss08                damaged_miss10"
global X_dam10        "damaged_nomiss06 damaged_nomiss07 damaged_nomiss08 damaged_nomiss09                  damaged_miss06 damaged_miss07 damaged_miss08 damaged_miss09               "
global X_damEarly     "damaged_nomiss06 damaged_nomiss07                                                    damaged_miss06 damaged_miss07                                             "
global X_initial_dam  "damaged06 valshare06 homevalue05"
global X_blockdam07   "block_damaged06_loo                                                 block_damaged09_loo block_damaged10_loo"
global X_blockdam08   "block_damaged06_loo block_damaged07_loo_imp                         block_damaged09_loo block_damaged10_loo"
global X_blockdam     "block_damaged06_loo block_damaged07_loo_imp block_damaged08_loo_imp block_damaged09_loo block_damaged10_loo"
global X_tract        "factor_tr1 factor_tr2 factor_tr3 factor_tr4 factor_tr5"
global X_RHvars       "type1_nomiss type2_nomiss rh_insurance_nomiss LMI_nomiss PreStormValue_nomiss type1_miss type2_miss rh_insurance_miss LMI_miss PreStormValue_miss"
global X_block        "factor_bl1 factor_bl2 factor_bl3 factor_bl4 factor_bl5 factor_bl6 flooding"
global Xhead0         "male0"
global Xhead1         "male1"
global Y              "employed_prek"



save "`ouputdir'temp.dta", replace
clear

local ouputdir "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
use  "`ouputdir'temp.dta"

set seed 12345

***************************************************
*** a. Impute 2008 block-level rebuilding rate  ***
***************************************************
local  implevel = 6
gen block_damaged07_loo_imp = block_damaged07_loo
gen block_damaged08_loo_imp = block_damaged08_loo
foreach yr in 07 08 {
bysort blockid00: gen imp_needed = _n==1 & block_damaged`yr'_loo_imp>=.
by     blockid00: gen impsample  = _n==1
qui su imp_needed if imp_needed==1
if r(N) > 1 {
psmatch2 imp_needed if impsample==1 , mahalanobis(${X_blockdam`yr'} ${X_block} ${X_tract} )
sort _id
replace block_damaged`yr'_loo_imp = block_damaged`yr'_loo_imp[_n1] if imp_needed==1
egen aux = mean(block_damaged`yr'_loo_imp), by(blockid00)
replace block_damaged`yr'_loo_imp = aux
drop aux
drop _*
}
drop imp_needed impsample
}

save "`ouputdir'temp1.dta", replace
clear

local ouputdir "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
use  "`ouputdir'temp1.dta"

****************************************************
*** b. Impute employment outcomes for both heads ***
****************************************************
local  implevel = 5
foreach hh in 0 1 {
foreach var in male employed_prek occ2_prek yrwage_prek lnyrwage_prek wherenow kat_age {
di "`var'`hh'"
gen imp_needed = `var'`hh'_impflag==`implevel' & relscrr`hh'<.
qui su imp_needed if imp_needed==1
if r(N) > 1 {
psmatch2 imp_needed if sample_dnors==1 & relscrr`hh'<., mahalanobis(${X_dam} ${X_blockdam} ${Xhead`hh'} ${X_block} ${X_tract} ${X_RHvars})
sort _id
replace `var'`hh'_imp = `var'`hh'_imp[_n1] if imp_needed==1
drop _*
}
drop imp_needed
}
}

save "`ouputdir'temp2.dta", replace
clear

local ouputdir "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
use  "`ouputdir'temp2.dta"

*******************************************************************************
*** c. Impute DNORS housing/damage variables & psid imputed asset variables ***
*******************************************************************************
local  implevel = 5
foreach var in hometype own fin_diff damage_home insurance damage_prop d18 m2 m1 d17 asset_p5 asset_p15 asset_p25 asset_p35 asset_p45 asset_p55 asset_p65 asset_p75 asset_p85 asset_p95 {
di "`var'"
gen imp_needed = `var'_impflag==`implevel'
qui su imp_needed if imp_needed==1
if r(N) > 1 {
psmatch2 imp_needed if sample_dnors==1 , mahalanobis(${X_dam} ${X_blockdam} ${X_block} ${X_tract} ${X_RHvars})
sort _id
replace `var'_imp = `var'_imp[_n1] if imp_needed==1
drop _*
}
drop imp_needed
}

save "`ouputdir'temp3.dta", replace
clear

local ouputdir "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
use  "`ouputdir'temp3.dta"

*********************************************************
*** d. Impute home repair status for non-DNORS sample ***
*********************************************************
gen mindamaged_pre06 = 1
gen mindamaged_pre07 = min(1,damaged06)
gen mindamaged_pre08 = min(1,damaged06,damaged07)
gen mindamaged_pre09 = min(1,damaged06,damaged07,damaged08)
gen mindamaged_pre10 = min(1,damaged06,damaged07,damaged08,damaged09)
gen mindamaged_pre11 = min(1,damaged06,damaged07,damaged08,damaged09,damaged10)

local  implevel = 6
foreach yr in 06 07 08 09 10 11 {
gen imp_needed = damaged`yr'_impflag==`implevel'
qui su imp_needed if imp_needed==1
if r(N) > 1 {
psmatch2 imp_needed if sample_assessors_universe==1 & mindamaged_pre`yr'==1, mahalanobis(${X_dam`yr'} ${X_blockdam} ${X_block} ${X_tract} ${X_RHvars})
sort _id
replace  damaged`yr'_imp =  damaged`yr'_imp[_n1] if imp_needed==1
drop _*
}
drop imp_needed
}

* Impose monotonicity
replace damaged06_imp=1 if damaged06_imp==0 & inlist(1,damaged11_imp,damaged10_imp,damaged09_imp,damaged08_imp,damaged07_imp)==1
replace damaged07_imp=1 if damaged07_imp==0 & inlist(1,damaged11_imp,damaged10_imp,damaged09_imp,damaged08_imp)==1
replace damaged08_imp=1 if damaged08_imp==0 & inlist(1,damaged11_imp,damaged10_imp,damaged09_imp)==1
replace damaged09_imp=1 if damaged09_imp==0 & inlist(1,damaged11_imp,damaged10_imp)==1
replace damaged10_imp=1 if damaged10_imp==0 & inlist(1,damaged11_imp)==1

gen imp_needed = (improveval08==.) & (improveval09==.) & (improveval10==.) & (improveval11==.)
levelsof ClosingOption, local(ClosingOptions) miss
foreach option of local ClosingOptions {
qui su imp_needed if imp_needed==1 & ClosingOption==`option'
if r(N) > 1 {
psmatch2 imp_needed if sample_assessors_universe==1 & ClosingOption==`option', mahalanobis(${X_damEarly} ${X_blockdam} ${X_block} ${X_tract} ${X_RHvars})
sort _id
replace postk_transfer_date_imp = postk_transfer_date_imp[_n1] if imp_needed==1 & ClosingOption==`option'
replace          postk_sale_imp =          postk_sale_imp[_n1] if imp_needed==1 & ClosingOption==`option'
replace     postk_sale_date_imp =     postk_sale_date_imp[_n1] if imp_needed==1 & ClosingOption==`option'
replace    postk_sale_price_imp =    postk_sale_price_imp[_n1] if imp_needed==1 & ClosingOption==`option'
drop _*
}
}
drop imp_needed

save "`ouputdir'temp4.dta", replace
clear

local ouputdir "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
use  "`ouputdir'temp4.dta"

************************************************************************
*** e. Impute employment outcomes for both heads in non-DNORS sample ***
************************************************************************
gen imp_needed = sample_dnors==0
psmatch2 imp_needed, mahalanobis(${X_dam} ${X_blockdam} ${Xhead`hh'} ${X_block} ${X_tract} ${X_RHvars})
sort _id
replace       relscrr0_imp =       relscrr0_imp[_n1] if imp_needed==1
replace          male0_imp =          male0_imp[_n1] if imp_needed==1
replace       kat_age0_imp =       kat_age0_imp[_n1] if imp_needed==1
replace employed_prek0_imp = employed_prek0_imp[_n1] if imp_needed==1
replace     occ2_prek0_imp =     occ2_prek0_imp[_n1] if imp_needed==1 & employed_prek0_imp[_n1]==1
replace   yrwage_prek0_imp =   yrwage_prek0_imp[_n1] if imp_needed==1 & employed_prek0_imp[_n1]==1
replace lnyrwage_prek0_imp = lnyrwage_prek0_imp[_n1] if imp_needed==1 & employed_prek0_imp[_n1]==1
replace      wherenow0_imp =      wherenow0_imp[_n1] if imp_needed==1
replace       relscrr1_imp =       relscrr1_imp[_n1] if imp_needed==1
replace          male1_imp =          male1_imp[_n1] if imp_needed==1
replace       kat_age1_imp =       kat_age1_imp[_n1] if imp_needed==1
replace employed_prek1_imp = employed_prek1_imp[_n1] if imp_needed==1
replace     occ2_prek1_imp =     occ2_prek1_imp[_n1] if imp_needed==1 & employed_prek1_imp[_n1]==1
replace   yrwage_prek1_imp =   yrwage_prek1_imp[_n1] if imp_needed==1 & employed_prek1_imp[_n1]==1
replace lnyrwage_prek1_imp = lnyrwage_prek1_imp[_n1] if imp_needed==1 & employed_prek1_imp[_n1]==1
drop imp_needed _*

gen imp_needed = sample_dnors==0
psmatch2 imp_needed, mahalanobis(${X_dam} ${X_tract} ${X_RHvars})
sort _id
replace      wherenow1_imp =      wherenow1_imp[_n1] if imp_needed==1
replace       asset_p5_imp =       asset_p5_imp[_n1] if imp_needed==1
replace      asset_p15_imp =      asset_p15_imp[_n1] if imp_needed==1
replace      asset_p25_imp =      asset_p25_imp[_n1] if imp_needed==1
replace      asset_p35_imp =      asset_p35_imp[_n1] if imp_needed==1
replace      asset_p45_imp =      asset_p45_imp[_n1] if imp_needed==1
replace      asset_p55_imp =      asset_p55_imp[_n1] if imp_needed==1
replace      asset_p65_imp =      asset_p65_imp[_n1] if imp_needed==1
replace      asset_p75_imp =      asset_p75_imp[_n1] if imp_needed==1
replace      asset_p85_imp =      asset_p85_imp[_n1] if imp_needed==1
replace      asset_p95_imp =      asset_p95_imp[_n1] if imp_needed==1
drop imp_needed _*

save "`ouputdir'temp5.dta", replace
clear

local ouputdir "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
use  "`ouputdir'temp5.dta"

************************************************
*** f. Impute DNORS housing/damage variables ***
************************************************
local  implevel = 6
foreach var in hometype fin_diff damage_home insurance damage_prop d18 m2 m1 d17 {
gen imp_needed = `var'_impflag==`implevel'
*psmatch2 imp_needed , mahalanobis(${X_dam} ${X_blockdam} ${X_block} ${X_tract} ${X_RHvars})
 psmatch2 imp_needed , mahalanobis(                       ${X_block}                       )
sort _id
replace `var'_imp = `var'_imp[_n1] if imp_needed==1
drop imp_needed _*
}

*************************************************************************
*** g. Impute Road Home variables (separately by missingness pattern) ***
*************************************************************************
local  implevel = 6

gen any_RH_missing = type1_miss + type2_miss + rh_insurance_miss + LMI_miss + PreStormValue_miss > 0

gen imp_needed = any_RH_missing if (type1_miss==0) & (type2_miss==0) & (rh_insurance_miss==1) & (LMI_miss==0) & (PreStormValue_miss==0)
replace imp_needed = 0 if any_RH_missing==0
psmatch2 imp_needed , mahalanobis(${X_initial_dam} ${X_blockdam} ${X_block} ${X_tract} )
sort _id
replace         type1_imp =         type1_imp[_n1] if imp_needed==1 &         type1_imp >=.
replace         type2_imp =         type2_imp[_n1] if imp_needed==1 &         type2_imp >=.
replace         type1_APPEAL_imp =         type1_APPEAL_imp[_n1] if imp_needed==1 &         type1_APPEAL_imp >=.
replace         type2_APPEAL_imp =         type2_APPEAL_imp[_n1] if imp_needed==1 &         type2_APPEAL_imp >=.
replace  rh_insurance_imp =  rh_insurance_imp[_n1] if imp_needed==1 &  rh_insurance_imp >=.
replace           LMI_imp =           LMI_imp[_n1] if imp_needed==1 &           LMI_imp >=.
replace PreStormValue_imp = PreStormValue_imp[_n1] if imp_needed==1 & PreStormValue_imp >=.
drop imp_needed _*

gen imp_needed = any_RH_missing if (type1_miss==0) & (type2_miss==1) & (rh_insurance_miss==0) & (LMI_miss==0) & (PreStormValue_miss==0)
replace imp_needed = 0 if any_RH_missing==0
psmatch2 imp_needed , mahalanobis(${X_initial_dam} ${X_blockdam} ${X_block} ${X_tract} )
sort _id
replace         type1_imp =         type1_imp[_n1] if imp_needed==1 &         type1_imp >=.
replace         type2_imp =         type2_imp[_n1] if imp_needed==1 &         type2_imp >=.
replace         type1_APPEAL_imp =         type1_APPEAL_imp[_n1] if imp_needed==1 &         type1_APPEAL_imp >=.
replace         type2_APPEAL_imp =         type2_APPEAL_imp[_n1] if imp_needed==1 &         type2_APPEAL_imp >=.
replace  rh_insurance_imp =  rh_insurance_imp[_n1] if imp_needed==1 &  rh_insurance_imp >=.
replace           LMI_imp =           LMI_imp[_n1] if imp_needed==1 &           LMI_imp >=.
replace PreStormValue_imp = PreStormValue_imp[_n1] if imp_needed==1 & PreStormValue_imp >=.
drop imp_needed _*

gen imp_needed = any_RH_missing if (type1_miss==0) & (type2_miss==1) & (rh_insurance_miss==1) & (LMI_miss==0) & (PreStormValue_miss==0)
replace imp_needed = 0 if any_RH_missing==0
psmatch2 imp_needed , mahalanobis(${X_initial_dam} ${X_blockdam} ${X_block} ${X_tract} )
sort _id
replace         type1_imp =         type1_imp[_n1] if imp_needed==1 &         type1_imp >=.
replace         type2_imp =         type2_imp[_n1] if imp_needed==1 &         type2_imp >=.
replace         type1_APPEAL_imp =         type1_APPEAL_imp[_n1] if imp_needed==1 &         type1_APPEAL_imp >=.
replace         type2_APPEAL_imp =         type2_APPEAL_imp[_n1] if imp_needed==1 &         type2_APPEAL_imp >=.
replace  rh_insurance_imp =  rh_insurance_imp[_n1] if imp_needed==1 &  rh_insurance_imp >=.
replace           LMI_imp =           LMI_imp[_n1] if imp_needed==1 &           LMI_imp >=.
replace PreStormValue_imp = PreStormValue_imp[_n1] if imp_needed==1 & PreStormValue_imp >=.
drop imp_needed _*

gen imp_needed = any_RH_missing if (type1_miss==1) & (type2_miss==1) & (rh_insurance_miss==0) & (LMI_miss==0) & (PreStormValue_miss==0)
replace imp_needed = 0 if any_RH_missing==0
psmatch2 imp_needed , mahalanobis(${X_initial_dam} ${X_blockdam} ${X_block} ${X_tract} )
sort _id
replace         type1_imp =         type1_imp[_n1] if imp_needed==1 &         type1_imp >=.
replace         type2_imp =         type2_imp[_n1] if imp_needed==1 &         type2_imp >=.
replace         type1_APPEAL_imp =         type1_APPEAL_imp[_n1] if imp_needed==1 &         type1_APPEAL_imp >=.
replace         type2_APPEAL_imp =         type2_APPEAL_imp[_n1] if imp_needed==1 &         type2_APPEAL_imp >=.
replace  rh_insurance_imp =  rh_insurance_imp[_n1] if imp_needed==1 &  rh_insurance_imp >=.
replace           LMI_imp =           LMI_imp[_n1] if imp_needed==1 &           LMI_imp >=.
replace PreStormValue_imp = PreStormValue_imp[_n1] if imp_needed==1 & PreStormValue_imp >=.
drop imp_needed _*

gen imp_needed = any_RH_missing if (type1_miss==1) & (type2_miss==1) & (rh_insurance_miss==1) & (LMI_miss==0) & (PreStormValue_miss==0)
replace imp_needed = 0 if any_RH_missing==0
psmatch2 imp_needed , mahalanobis(${X_initial_dam} ${X_blockdam} ${X_block} ${X_tract} )
sort _id
replace         type1_imp =         type1_imp[_n1] if imp_needed==1 &         type1_imp >=.
replace         type2_imp =         type2_imp[_n1] if imp_needed==1 &         type2_imp >=.
replace         type1_APPEAL_imp =         type1_APPEAL_imp[_n1] if imp_needed==1 &         type1_APPEAL_imp >=.
replace         type2_APPEAL_imp =         type2_APPEAL_imp[_n1] if imp_needed==1 &         type2_APPEAL_imp >=.
replace  rh_insurance_imp =  rh_insurance_imp[_n1] if imp_needed==1 &  rh_insurance_imp >=.
replace           LMI_imp =           LMI_imp[_n1] if imp_needed==1 &           LMI_imp >=.
replace PreStormValue_imp = PreStormValue_imp[_n1] if imp_needed==1 & PreStormValue_imp >=.
drop imp_needed _*

gen imp_needed = any_RH_missing if (type1_miss==1) & (type2_miss==1) & (rh_insurance_miss==1) & (LMI_miss==0) & (PreStormValue_miss==1)
replace imp_needed = 0 if any_RH_missing==0
psmatch2 imp_needed , mahalanobis(${X_initial_dam} ${X_blockdam} ${X_block} ${X_tract} )
sort _id
replace         type1_imp =         type1_imp[_n1] if imp_needed==1 &         type1_imp >=.
replace         type2_imp =         type2_imp[_n1] if imp_needed==1 &         type2_imp >=.
replace         type1_APPEAL_imp =         type1_APPEAL_imp[_n1] if imp_needed==1 &         type1_APPEAL_imp >=.
replace         type2_APPEAL_imp =         type2_APPEAL_imp[_n1] if imp_needed==1 &         type2_APPEAL_imp >=.
replace  rh_insurance_imp =  rh_insurance_imp[_n1] if imp_needed==1 &  rh_insurance_imp >=.
replace           LMI_imp =           LMI_imp[_n1] if imp_needed==1 &           LMI_imp >=.
replace PreStormValue_imp = PreStormValue_imp[_n1] if imp_needed==1 & PreStormValue_imp >=.
drop imp_needed _*

gen imp_needed = any_RH_missing if (type1_miss==1) & (type2_miss==1) & (rh_insurance_miss==1) & (LMI_miss==1) & (PreStormValue_miss==1)
replace imp_needed = 0 if any_RH_missing==0
psmatch2 imp_needed , mahalanobis(${X_initial_dam} ${X_blockdam} ${X_block} ${X_tract} )
sort _id
replace         type1_imp =         type1_imp[_n1] if imp_needed==1 &         type1_imp >=.
replace         type2_imp =         type2_imp[_n1] if imp_needed==1 &         type2_imp >=.
replace         type1_APPEAL_imp =         type1_APPEAL_imp[_n1] if imp_needed==1 &         type1_APPEAL_imp >=.
replace         type2_APPEAL_imp =         type2_APPEAL_imp[_n1] if imp_needed==1 &         type2_APPEAL_imp >=.
replace  rh_insurance_imp =  rh_insurance_imp[_n1] if imp_needed==1 &  rh_insurance_imp >=.
replace           LMI_imp =           LMI_imp[_n1] if imp_needed==1 &           LMI_imp >=.
replace PreStormValue_imp = PreStormValue_imp[_n1] if imp_needed==1 & PreStormValue_imp >=.
drop imp_needed _*

save "`ouputdir'temp6.dta", replace
clear

local ouputdir "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
use  "`ouputdir'temp6.dta"

*************************************************************************
*** g. Impute Road Home variables (separately by missingness pattern) ***
*************************************************************************
** Alternative method for imputing type2 to make sure density is smooth near .51*type1 !!!
gen running = min(1,type2/type1) if type2<. & type1<.
gen lnOPAOappraisedval06 = ln(landval06 + improveval06)
nl ( running = (1 + exp( {a0} + {a1a}*flooding + {a1b}*flooding^2 + {a1c}*flooding^3 + {a2a}*lnhomevalue05 + {a2b}*lnhomevalue05^2 + {a3a}*lnOPAOappraisedval06 + {a3b}*lnOPAOappraisedval06^2 + {a4}*lnhomevalue05*lnOPAOappraisedval06 + {a5}*bl_white + {a6}*pcwhite00_tr ) )^-1 ) if flooding<. & valshare06<. & lnhomevalue05<. & bl_white<. & pcwhite00_tr<. & lnOPAOappraisedval06<. & running<=1
predict aux
histogram aux if inrange(aux,.4,.6)==1
replace type2_imp       =aux*type1_imp if type2==.
drop aux running

gen     estimated_repcost_imp = type1_imp
replace estimated_repcost_imp = type2_imp if type2_imp < .51*type1_imp

* non-applicants unaffected by appeals process
replace type1_APPEAL_imp = type1_imp if type1_APPEAL==.
replace type2_APPEAL_imp = type2_imp if type2_APPEAL==.


**************************************************
*** yy. drop variables created for imputations ***
**************************************************
drop ownocc damaged_miss06 damaged_nomiss06 damaged_miss07 damaged_nomiss07 damaged_miss08 damaged_nomiss08 damaged_miss09 damaged_nomiss09 damaged_miss10 damaged_nomiss10 damaged_miss11 damaged_nomiss11
drop type1_miss type1_nomiss type2_miss type2_nomiss rh_insurance_miss rh_insurance_nomiss LMI_miss LMI_nomiss PreStormValue_miss PreStormValue_nomiss any_RH_missing
drop factor_bl1 factor_bl2 factor_bl3 factor_bl4 factor_bl5 factor_bl6
drop factor_tr1 factor_tr2 factor_tr3 factor_tr4 factor_tr5
drop mindamaged_pre06 mindamaged_pre07 mindamaged_pre08 mindamaged_pre09 mindamaged_pre10 mindamaged_pre11
drop lnestimated_repcost
drop lnhomevalue05 lnhomevalue05_hat
drop address_phys

********************************************************
*** zz. organize original data and created variables ***
********************************************************
gen o________opao_vars_imp______=.
gen o________dnors_hh_vars_imp______=.
gen o________dnors_ind_vars_imp__=.
gen o________block_damage_var______=.

order o________sample_flags___________ sample_assessors_universe sample_assessors_dnors sample_dnors_hhfin sample_dnors_ind sample_dnors sample_blockdata sample_tractdata o________opao_vars__________ taxbill addid improveval05 improveval06 improveval07 improveval08 improveval09 improveval10 improveval11 landval05 landval06 landval07 landval08 landval09 landval10 landval11 homevalue05 valshare06 valshare07 valshare08 valshare09 valshare10 valshare11 transfer_date purchase_date purchase_year purchase_years_ago purchase_cat purchase_price postk_transfer_date postk_transfer_date_imp postk_transfer_date_impflag postk_sale postk_sale_imp postk_sale_impflag postk_sale_date postk_sale_date_imp postk_sale_date_impflag postk_sale_price postk_sale_price_imp postk_sale_price_impflag o________opao_vars_imp______ damaged06 damaged06_imp damaged06_impflag damaged07 damaged07_imp damaged07_impflag damaged08 damaged08_imp damaged08_impflag damaged09 damaged09_imp damaged09_impflag damaged10 damaged10_imp damaged10_impflag damaged11 damaged11_imp damaged11_impflag repaired06 repaired07 repaired08 repaired09 repaired10 repaired11 o________dnors_hh_vars__________ hhid segment hu_wgt_s hometype own fin_diff damage_home damage_prop insurance o________dnors_hh_vars_imp______ hometype_imp hometype_impflag own_imp own_impflag fin_diff_imp fin_diff_impflag damage_home_imp damage_home_impflag damage_prop_imp damage_prop_impflag insurance_imp insurance_impflag d17_imp d17_impflag d18_imp d18_impflag m1_imp m1_impflag m2_imp m2_impflag o________dnors_ind_vars______ relscrr0 relscrr1 male0 male1 kat_age0 kat_age1 employed_prek0 employed_prek1 occ2_prek0 occ2_prek1 yrwage_prek0 yrwage_prek1 lnyrwage_prek0 lnyrwage_prek1 wherenow0 wherenow1 o________dnors_ind_vars_imp__ relscrr0_imp relscrr0_impflag relscrr1_imp relscrr1_impflag male0_imp male0_impflag male1_imp male1_impflag kat_age0_imp kat_age0_impflag kat_age1_imp kat_age1_impflag employed_prek0_imp employed_prek0_impflag employed_prek1_imp employed_prek1_impflag occ2_prek0_imp occ2_prek0_impflag occ2_prek1_imp occ2_prek1_impflag yrwage_prek0_imp yrwage_prek0_impflag yrwage_prek1_imp yrwage_prek1_impflag lnyrwage_prek0_imp lnyrwage_prek0_impflag lnyrwage_prek1_imp lnyrwage_prek1_impflag wherenow0_imp wherenow0_impflag wherenow1_imp wherenow1_impflag o________block_damage_var______ block_damaged06 block_damaged07 block_damaged08 block_damaged09 block_damaged10 block_damaged11 block_damaged06_loo block_damaged07_loo block_damaged08_loo block_damaged09_loo block_damaged10_loo block_damaged11_loo o________block_vars__________ blockid00 neighborhood flooding bl_white bl_black bl_other bl_ameri_es bl_asian bl_hawn_pi bl_other bl_mult_race bl_hispanic bl_males bl_females bl_age_under5 bl_age_5_17 bl_age_18_21 bl_age_22_29 bl_age_30_39 bl_age_40_49 bl_age_50_64 bl_age_65_up bl_owner_occupied bl_renter_occupied bl_vacant bl_hsehld_1_m bl_hsehld_1_f bl_marhh_chd bl_marhh_no_c bl_mhh_child bl_fhh_child bl_med_age bl_ave_hh_sz bl_ave_fam_sz bl_population bl_families bl_households bl_housing_units o________tract_vars__________ tractid00 pcwhite00_tr pcblack00_tr pctspnsh_tr pclatino00_tr pcapi00_tr pcother00_tr pop_0_4_tr pop_0_17_tr popul18_tr adltchld_tr elderly_tr ncitizen_tr foreign_tr fb_90_tr fb_95_tr nf_hh_tr pctlang_oth_tr pctengl_tr eng_vw_tr hhwk_tr fem_h_hh_tr fi_lt15k_tr fi_1524k_tr fi_gt75k_tr fi_5074k_tr fi_lt24k_tr pct_pov_tr med99hh_tr med99fam_tr pubasst_tr unemploy_tr femunemp_tr maleunem_tr higheduc_tr m_exprof_tr f_exprof_tr execprof_tr mult_du_tr pct_owner00_tr pct_occup00_tr totpop00_tr dwellings_tr pphh_tr lndarea_tr density00_tr o________road_home_vars_________ PreStormValue PreStormValue_imp PreStormValue_impflag LMI LMI_imp LMI_impflag rh_insurance rh_insurance_imp rh_insurance_impflag type2 type2_imp type2_impflag type1 type1_imp type1_impflag LA_ID GISCensusBlockFIPSCode ClosingOption GISOrleansNeighborhoodName GISOrleansPlanningDistrictName AssessorMatch Status RH_AWARD PrimaryApplicantRace PrimaryApplicantEthnicity PrimaryApplicantGender PrimaryApplicantIsElderly EstimatedCostofDamage ClosingFEMAInsuranceValue ClosingFloodInsuranceValue ClosingHomeInsuranceValue HETYPE1STType1RepairRebuildSubto HETYPE2STType2RepairRebuildSubto Total_RH CompensationGrantRequestedAmount ElevationRequestedAmount ACGRequestedAmount IMM_FINAL MinOfLastClosingDate MaxOfLastClosingDate rh_black rh_white estimated_repcost estimated_repcost_imp o________TBD__________

save "`ouputdir'Merged_RoadHome_Assessors_imputed.dta", replace
clear



*************************************
*** Azz. Add on ACS wage measures ***
*************************************

use "`ouputdir'occ_wages.dta"
foreach var of varlist * {
ren `var' `var'_0
}
ren occ2_prek_0 occ2_prek0_imp
tempfile wages0
save `wages0'
clear

use "`ouputdir'occ_wages.dta"
foreach var of varlist * {
ren `var' `var'_1
}
ren occ2_prek_1 occ2_prek1_imp
tempfile wages1
save `wages1'
clear


use "`ouputdir'Merged_RoadHome_Assessors_imputed.dta"
joinby occ2_prek0_imp using `wages0', unmatched(master)
tab _m
drop _m
joinby occ2_prek1_imp using `wages1', unmatched(master)
tab _m
drop _m

* Compute relative wages
foreach yr in 2005 2006 2007 2008 2009 {
gen lnrelwage`yr'_0 = lnnola_wage`yr'_0 - lnevac_wage`yr'_0
gen lnrelwage`yr'_1 = lnnola_wage`yr'_1 - lnevac_wage`yr'_1
}

foreach yr in 2005 2006 2007 2008 2009 {
gen     nola_wage`yr' = 0 if (employed_prek0_imp==1 | employed_prek1_imp==1)
gen     evac_wage`yr' = 0 if (employed_prek0_imp==1 | employed_prek1_imp==1)
forval hh=0/1 {
replace nola_wage`yr' = nola_wage`yr' + exp(lnnola_wage`yr'_`hh') if lnnola_wage`yr'_`hh'<. & employed_prek`hh'_imp==1
replace evac_wage`yr' = evac_wage`yr' + exp(lnevac_wage`yr'_`hh') if lnevac_wage`yr'_`hh'<. & employed_prek`hh'_imp==1
}
}

gen nola_wage=0
gen evac_wage=0
forval yr = 2006/2009 {
replace nola_wage=nola_wage+nola_wage`yr'
replace evac_wage=evac_wage+evac_wage`yr'
}
gen lnrelwage = ln(nola_wage/evac_wage)

save "`ouputdir'Merged_RoadHome_Assessors_imputed.dta", replace


