clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000


local ouputdir    ""      /* Location where processed data is stored */
local geodir      ""      /* Location of geogrphic data */

run matwrite.ado

*******************************************
*** save (x,y) coordinates  for merging ***
*******************************************
use "`geodir'nola_addresse_universe_geocoded.dta" 
keep addid x y _score_
ren _score_ QualGeocode
tempfile coordinates
save `coordinates'
clear

use "`ouputdir'Merged_RoadHome_Assessors_imputed.dta"
joinby addid using `coordinates', unmatched(master)
tab _m
drop _m


*****************************
*** 0. Additional recodes ***
*****************************

***********************************************************************************
*** Infer repair year from Assessor's data (used for all of these combinations) ***
***********************************************************************************
gen     repaired_year_imp = .
replace repaired_year_imp = -99 if damaged06_imp == 0 & repaired_year_imp==.
replace repaired_year_imp =   1 if damaged07_imp == 0 & repaired_year_imp==.
replace repaired_year_imp =   2 if damaged08_imp == 0 & repaired_year_imp==.
replace repaired_year_imp =   3 if damaged09_imp == 0 & repaired_year_imp==.
replace repaired_year_imp =   4 if damaged10_imp == 0 & repaired_year_imp==.
replace repaired_year_imp =   5 if damaged11_imp == 0 & repaired_year_imp==.
replace repaired_year_imp =  99 if                      repaired_year_imp==.

****************************************************************
*** Record home sale year based on imputed transactions data ***
****************************************************************
gen     postk_priv_sale_year_imp =  .
replace postk_priv_sale_year_imp =  1 if inrange(postk_sale_date_imp,mdy(8,29,2005),mdy(8,30,2006))==1 & inlist(ClosingOption,2,3)==0
replace postk_priv_sale_year_imp =  2 if inrange(postk_sale_date_imp,mdy(8,29,2006),mdy(8,30,2007))==1 & inlist(ClosingOption,2,3)==0
replace postk_priv_sale_year_imp =  3 if inrange(postk_sale_date_imp,mdy(8,29,2007),mdy(8,30,2008))==1 & inlist(ClosingOption,2,3)==0
replace postk_priv_sale_year_imp =  4 if inrange(postk_sale_date_imp,mdy(8,29,2008),mdy(8,30,2009))==1 & inlist(ClosingOption,2,3)==0
replace postk_priv_sale_year_imp =  5 if inrange(postk_sale_date_imp,mdy(8,29,2009),mdy(8,30,2010))==1 & inlist(ClosingOption,2,3)==0
replace postk_priv_sale_year_imp = 99 if postk_priv_sale_year_imp==.

**************************************************************************************
*** Keep years of repairs occurring while pre-K owner owns the home (scenario a.i) ***
**************************************************************************************
gen     ownerrep_year     = repaired_year_imp
replace ownerrep_year     = 99 if postk_priv_sale_year   <=repaired_year_imp
replace ownerrep_year     = 99 if inlist(ClosingOption,2,3)==1

***************************************************************************************
*** Keep years of repairs occurring while pre-K owner owns the home (scenario a.ii) ***
***************************************************************************************
gen     ownerrep_year_imp = repaired_year_imp
replace ownerrep_year_imp = 99 if postk_priv_sale_year_imp<=repaired_year_imp
replace ownerrep_year_imp = 99 if inlist(ClosingOption,2,3)==1

**************************************************************************************
*** Keep years of repairs for households who didn't sell w/in 5 yrs (scenario b.i) ***
**************************************************************************************
gen     nosale_repaired_year     = repaired_year_imp
replace nosale_repaired_year     = 99 if postk_sale    ==1

***************************************************************************************
*** Keep years of repairs for households who didn't sell w/in 5 yrs (scenario b.ii) ***
***************************************************************************************
gen     nosale_imp_repaired_year = repaired_year_imp
replace nosale_imp_repaired_year = 99 if postk_sale_imp==1

gen lnsqft = ln(type1_imp/130)

forval yr = 0/5 { 
gen     Y`yr' = ownerrep_year_imp<=`yr'
replace Y`yr' = 1 if damaged06_imp==0
}



*** Quick tabs looking at when home sales took place ***
*gen postk_sale_year_imp = year(postk_sale_date_imp)
*tab postk_sale_year_imp ClosingOption if Y5==0 & ClosingOption!=1 & postk_sale_year_imp<., m col

******************************************************
*** Compute "leave-one-out" block rebuilding rates ***
******************************************************
foreach var in Y0 Y1 Y2 Y3 Y4 Y5 {
   egen    AVG_`var'     = mean(Y5 ), by(blockid00)
   egen      N_`var'     = sum(Y5<.), by(blockid00)
   gen     AVG_loo_`var' =  AVG_`var'
   replace AVG_loo_`var' = (AVG_`var'*N_`var'-`var') / (N_`var'-1) if `var'<.
   drop N_`var'
   }

***********************************************
*** Create running variable for RD analysis ***
***********************************************
replace     type2_imp = 0 if damaged06_imp==0
gen       running_imp = min(1,type2_imp/type1_imp)      if type2_imp<. & type1_imp<.
gen       running     = running_imp if type1<.
replace   running     = -999 if running==.

replace     type2_APPEAL_imp = 0 if damaged06_imp==0
gen       running_APP_imp = min(1,type2_APPEAL_imp/type1_APPEAL_imp)      if type2_APPEAL_imp<. & type1_APPEAL_imp<.
gen       running_APP     = running_APP_imp if type1_APPEAL<.
replace   running_APP     = -999 if running_APP==.

gen RHapplicant = (type1<.) | (type2<.)


*********************************************************************
*** START: Compute home price offer function outside of the model ***
*********************************************************************
gen     lnSALE_PRICE  = ln(postk_sale_price) if inlist(ClosingOption,2,3)!=1
*gen     lnSALE_PRICE2 = lnSALE_PRICE if lnSALE_PRICE>ln(10000)
gen     lnSALE_PRICE2 = lnSALE_PRICE if lnSALE_PRICE>ln(.2*homevalue05)
gen  postk_priv_sale  = lnSALE_PRICE<.
gen  postk_priv_sale2 = lnSALE_PRICE2<.

gen     sellstate = 1 if lnSALE_PRICE2<. & repaired_year_imp< postk_priv_sale_year-1
replace sellstate = 2 if lnSALE_PRICE2<. & repaired_year_imp>=postk_priv_sale_year-1
replace sellstate = 3 if lnSALE_PRICE2<. & repaired_year_imp> postk_priv_sale_year
*replace sellstate = 0 if lnSALE_PRICE2<. & Y0==1

gen majcoll  = higheduc_tr>50
gen pctcoll  = higheduc_tr/100
gen majblack = bl_black>.50
gen pctblack = bl_black

gen lntype1_imp = ln(type1_imp/1000)
gen lnHOMEVAL05 = ln(homevalue05/1000)
gen lnHHINC05   = ln( max(m2_imp,.15*max(purchase_price,homevalue05)) / 1000 )

replace  purchase_year = max(purchase_year,1975)
gen CENS_purchase_year = purchase_year==1975

gen floodcat = floor(min(6,max(1,flooding)))
tab floodcat, gen(floodcat)

global COVARS4  "MU3 MU4 MU5 lnsqft lnHOMEVAL05 CENS_purchase_year purchase_year floodcat1 floodcat3-floodcat6 majblack"
global COVARS99 "lnsqft lnHOMEVAL05 CENS_purchase_year purchase_year floodcat1 floodcat3-floodcat6 majblack"
global PRICECOVARS  "i.sellstate#c.(RUN*)"
global PRICECOVARS  "i.sellstate i.sellstate#c.(running_imp)"
/*
****************************************************
*** START: ASIDE, PLOT ADJUSTED SALE PRICE TREND ***
****************************************************
gen sale_year = (postk_sale_date-mdy(8,29,2005))/365.25
areg lnSALE_PRICE2 $PRICECOVARS $COVARS99, robust abs(tractid00)
predict lnSALE_PRICE2_resid, resid
reg lnSALE_PRICE2_resid sale_year
predict FIT
local slopetext = "Slope = " + string(round(_b[sale_year],.001)) + " log-pts/year"
twoway (scatter lnSALE_PRICE2_resid sale_year if inrange(lnSALE_PRICE2_resid,-3,3)==1, msize(.1)) (line FIT sale_year, lwidth(.5) lcolor(black) text(2 4 "`slopetext'", color(black)) legend(off) xtitle(Years b/w Katrina and Home Sale) ytitle(log-Sale Price Residual))
graph export "ZZZ-A97-AdjustedSalePriceTrend.eps", replace
!epstopdf    "ZZZ-A97-AdjustedSalePriceTrend.eps"
rm           "ZZZ-A97-AdjustedSalePriceTrend.eps"
drop FIT lnSALE_PRICE2_resid
****************************************************
***   END: ASIDE, PLOT ADJUSTED SALE PRICE TREND ***
****************************************************
*/
gen XXD0 = running_imp>.51
global SELECTCOVARS "running_imp XXD0 c.XXD0#c.(MU3 MU4 MU5)"
mkspline MU2 .4   MU3 .6   MU4 .8   MU5                            = AVG_loo_Y5
drop     MU2
qui tab  tractid00, gen(TAU)
heckman  lnSALE_PRICE2 $COVARS4 $PRICECOVARS TAU*, select($COVARS4 $SELECTCOVARS) robust
outreg2  using "ZZZ_T5.Price_Spillovers.xls", replace label dec(3) alpha(.01, .05, .10) ctitle(SPEC`spec' FE: Select)
areg     lnSALE_PRICE2 $COVARS4 $PRICECOVARS     , robust abs(tractid00)
outreg2  using "ZZZ_T5.Price_Spillovers.xls", append  label dec(3) alpha(.01, .05, .10) ctitle(SPEC`spec' FE)
global b_MU3 = _b[MU3]
global b_MU4 = _b[MU4]
global b_MU5 = _b[MU5]
local RMSE = e(rmse)
predict store_d_absorb, d
egen aux = mean(store_d_absorb), by(tractid00)
replace store_d_absorb = aux
drop aux
gen store_MU3      =MU3
gen store_MU4      =MU4
gen store_MU5      =MU5
gen store_sellstate=sellstate
replace   MU3      =0
replace   MU4      =0
replace   MU5      =0
replace   sellstate=1
predict lnSALE_PRICE_HAT_BASE, xb
replace lnSALE_PRICE_HAT_BASE = lnSALE_PRICE_HAT_BASE + store_d_absorb
replace   MU3      =store_MU3
replace   MU4      =store_MU4
replace   MU5      =store_MU5
replace   sellstate=store_sellstate
drop store_*
gen P_HAT_BASE = exp(lnSALE_PRICE_HAT_BASE + `RMSE'^2/2) / 1000
gen P_HAT_FULL = P_HAT_BASE * exp( $b_MU3*max(0,min(.2,(AVG_loo_Y5-.4))) + $b_MU4*max(0,min(.2,(AVG_loo_Y5-.6))) + $b_MU5*max(0,min(.2,(AVG_loo_Y5-.8))) )

**********************************************
*** END: Compute home price offer function ***
**********************************************


*Road Home financial incentive to rebuild (fitr)
replace ClosingOption=0 if ClosingOption==.

foreach var in improveval05 landval05 homevalue05 PreStormValue_imp type1_imp postk_sale_price {
cap gen ln`var' = ln(`var')
su  ln`var', d
gen ln`var'_wins = max(r(p5),min(r(p95),ln`var')) if ln`var'<.
}

gen     rh1_grant_imp = max( 0, min(150000 , PreStormValue_imp , type2_imp - rh_insurance_imp)) if type1_imp<. & type2_imp<. & rh_insurance_imp<. & type2_imp< .51*type1_imp & LMI_imp==1
replace rh1_grant_imp = max( 0, min(150000 , PreStormValue_imp , type1_imp - rh_insurance_imp)) if type1_imp<. & type2_imp<. & rh_insurance_imp<. & type2_imp>=.51*type1_imp & LMI_imp==1
replace rh1_grant_imp = max( 0, min(150000 ,                     type2_imp - rh_insurance_imp)) if type1_imp<. & type2_imp<. & rh_insurance_imp<. & type2_imp< .51*type1_imp & LMI_imp==0
replace rh1_grant_imp = max( 0, min(150000 ,                     type1_imp - rh_insurance_imp)) if type1_imp<. & type2_imp<. & rh_insurance_imp<. & type2_imp>=.51*type1_imp & LMI_imp==0
gen     rh2_grant_imp = max( 0, min(150000 , PreStormValue_imp , type2_imp - rh_insurance_imp)) if type1_imp<. & type2_imp<. & rh_insurance_imp<. & type2_imp< .51*type1_imp
replace rh2_grant_imp = max( 0, min(150000 , PreStormValue_imp , type1_imp - rh_insurance_imp)) if type1_imp<. & type2_imp<. & rh_insurance_imp<. & type2_imp>=.51*type1_imp

gen     rh1_grant_APPEAL_imp = max( 0, min(150000 , PreStormValue_imp , type2_APPEAL_imp - rh_insurance_imp)) if type1_APPEAL_imp<. & type2_APPEAL_imp<. & rh_insurance_imp<. & type2_APPEAL_imp< .51*type1_APPEAL_imp & LMI_imp==1
replace rh1_grant_APPEAL_imp = max( 0, min(150000 , PreStormValue_imp , type1_APPEAL_imp - rh_insurance_imp)) if type1_APPEAL_imp<. & type2_APPEAL_imp<. & rh_insurance_imp<. & type2_APPEAL_imp>=.51*type1_APPEAL_imp & LMI_imp==1
replace rh1_grant_APPEAL_imp = max( 0, min(150000 ,                     type2_APPEAL_imp - rh_insurance_imp)) if type1_APPEAL_imp<. & type2_APPEAL_imp<. & rh_insurance_imp<. & type2_APPEAL_imp< .51*type1_APPEAL_imp & LMI_imp==0
replace rh1_grant_APPEAL_imp = max( 0, min(150000 ,                     type1_APPEAL_imp - rh_insurance_imp)) if type1_APPEAL_imp<. & type2_APPEAL_imp<. & rh_insurance_imp<. & type2_APPEAL_imp>=.51*type1_APPEAL_imp & LMI_imp==0
gen     rh2_grant_APPEAL_imp = max( 0, min(150000 , PreStormValue_imp , type2_APPEAL_imp - rh_insurance_imp)) if type1_APPEAL_imp<. & type2_APPEAL_imp<. & rh_insurance_imp<. & type2_APPEAL_imp< .51*type1_APPEAL_imp
replace rh2_grant_APPEAL_imp = max( 0, min(150000 , PreStormValue_imp , type1_APPEAL_imp - rh_insurance_imp)) if type1_APPEAL_imp<. & type2_APPEAL_imp<. & rh_insurance_imp<. & type2_APPEAL_imp>=.51*type1_APPEAL_imp


*Re-compute grants for counterfactual where RH uses a "continuous" grant formula
gen     rh1_smoothgrant_imp = max( 0, min(150000 , PreStormValue_imp , type2_imp - rh_insurance_imp)) if type1_imp<. & type2_imp<. & rh_insurance_imp<. & LMI_imp==1
replace rh1_smoothgrant_imp = max( 0, min(150000 ,                     type2_imp - rh_insurance_imp)) if type1_imp<. & type2_imp<. & rh_insurance_imp<. & LMI_imp==0
su rh1_smoothgrant_imp



*compute amount owed on mortgage at time of Katrina and size of annual mortgage payments
local APR=.065
local D = 1/(1+`APR')
local downpayment=.2
replace purchase_price=0 if purchase_price==.
replace purchase_year=1975 if purchase_year==.
gen     mortgage       = purchase_price * (1-`downpayment') * `APR' * (1+`APR')^30 / [ (1+`APR')^(30) - 1]
replace mortgage       = 0 if 2005-purchase_year>30
gen mortgage_yrs_paid_before_2005 = min(30 , (2005 - purchase_year) )
gen mortgage_owed_2005            = purchase_price * (1-`downpayment') * (1 - ((1+`APR')^mortgage_yrs_paid_before_2005 - 1) / ( (1+`APR')^30 - 1 ) )

**********************************************************
*** 1. Keep appropriate variables, do recodes, reorder ***
**********************************************************

egen j            = group( blockid00     )
gen  blockgrpid00 = substr(blockid00,1,12)
egen blockn       = group( blockgrpid00  )
egen tau          = group( tractid00     )

gen     riskscore = riskscore_sma010 if riskscore_sma010_N>=10
replace riskscore = riskscore_sma025 if riskscore_sma025_N>=10 & riskscore==.
replace riskscore = riskscore_sma033 if riskscore_sma033_N>=10 & riskscore==.
replace riskscore = riskscore_tr     if riskscore_tr_N    >=10 & riskscore==.

gen riskscore_cat = floor(min(725,max(575,riskscore))/25) - 575/25 + 1
tab riskscore_cat, gen(RISKCAT)

gen RENT = .08 * homevalue05 / 1000

gen HPI = 1

gen Mbal = mortgage_owed_2005/1000
gen Mpmt = mortgage/1000
gen PaymentsLeft = 30 - mortgage_yrs_paid_before_2005

gen  k = running_imp * P_HAT_BASE
*gen  k = type2_imp / 1000

gen ins = rh_insurance_imp/1000 if k<. & rh_insurance_imp<.

gen     w0 = max(m2_imp,.2*max(purchase_price,homevalue05)) / 1000
gen     w1 = max(m2_imp,.2*max(purchase_price,homevalue05)) / 1000
replace w0 = w0 * (evac_wage/4) / nola_wage2005 if (employed_prek0_imp==1) | (employed_prek1_imp==1)
replace w1 = w1 * (nola_wage/4) / nola_wage2005 if (employed_prek0_imp==1) | (employed_prek1_imp==1)

set seed 12345
gen tempunif = uniform()
gen A0=.
forval pp = 5(10)95 {
replace A0 = asset_p`pp'_imp/1000 if tempunif<1-(`pp'-5)/100
}

gen     grant1 = rh1_grant_imp / 1000
gen     grant2 = rh2_grant_imp / 1000

gen     grantsmooth = rh1_smoothgrant_imp / 1000

gen     grant1_APPEAL = rh1_grant_APPEAL_imp / 1000
gen     grant2_APPEAL = rh2_grant_APPEAL_imp / 1000 

replace lnSALE_PRICE = -999 if lnSALE_PRICE==.

gen     NEVATRISK_opt2 = P_HAT_BASE-k>=max( 0, min(150 , type1_imp/1000 - ins))

gen check = A0+ins+P_HAT_BASE/1000-k-Mbal+w0-RENT

replace damage_home_imp = -9999 if damage_home_imp>=.
label values damage_home_imp t57f

gen ______END_OF_KEEPVARS______ = .

order blockid00 x y tractid00 j blockn tau purchase_year QualGeocode damage_home_imp damage_home_impflag type2_impflag A0 w0 w1 riskscore RISKCAT1 RISKCAT2 RISKCAT3 RISKCAT4 RISKCAT5 RISKCAT6 RISKCAT7 P_HAT_BASE RENT Mbal Mpmt PaymentsLeft k ins grant1 grant2 grantsmooth grant1_APPEAL grant2_APPEAL LMI_imp floodcat1 floodcat2 floodcat3 floodcat4 floodcat5 floodcat6 majblack pctblack majcoll pctcoll lnHOMEVAL05 lnHHINC05 RHapplicant running_APP_imp running_imp type1_imp type2_imp pct_pov_tr ClosingOption NEVATRISK_opt2 flooding lnSALE_PRICE Y0 Y1 Y2 Y3 Y4 Y5 ______END_OF_KEEPVARS______

label variable blockid00            "2000 block ID"
label variable x                    "Longitude"
label variable y                    "Latitude"
label variable tractid00            "2000 tract ID"
label variable j                    "Sequential block ID"
label variable blockn               "Sequential blockgroup ID"
label variable tau                  "Sequential tract ID"
label variable purchase_year        "Purchase year (1975 = 1975 or earlier)"
label variable QualGeocode          ""
label variable type2_impflag        ""
label variable damage_home_imp      ""
label variable damage_home_impflag  ""
label variable A0                   "Household initial asset holding draw"
label variable w0                   "Annual household income - EVAC"
label variable w1                   "Annual household income - NOLA"
label variable riskscore            "Neighbrhood average Equifax risk score"
label variable RISKCAT1             "Neighborhood risk score <600"
label variable RISKCAT2             "Neighborhood risk score 600-625"
label variable RISKCAT3             "Neighborhood risk score 625-650"
label variable RISKCAT4             "Neighborhood risk score 650-675"
label variable RISKCAT5             "Neighborhood risk score 675-700"
label variable RISKCAT6             "Neighborhood risk score 700-725"
label variable RISKCAT7             "Neighborhood risk score >725"
label variable P_HAT_BASE           "Home's value in a repaired state ($1000s)"
label variable RENT                 "Imputed annual rent"
label variable Mbal                 "Mortgage balance owed in 2005 ($1000s)"
label variable Mpmt                 "Annual mortgage payment ($1000s)"
label variable PaymentsLeft         "Years remaining on 30 year mortgage"
label variable k                    "Cost of home repairs ($1000s)"
label variable ins                  "Insurance payment ($1000s)"
label variable grant1               "Road Home option 1 grant offer ($1000s)"
label variable grant2               "Road Home option 2 grant offer ($1000s)"
label variable grant1_APPEAL        "Road Home option 1 grant offer AFTER APPEAL ($1000s)"
label variable grant2_APPEAL        "Road Home option 2 grant offer AFTER APPEAL ($1000s)"
label variable LMI_imp              "Low/moderate income indicator"
label variable floodcat1            "< 2 feet flooding"
label variable floodcat2            "2 - 3 feet flooding"
label variable floodcat3            "3 - 4 feet flooding"
label variable floodcat4            "4 - 5 feet flooding"
label variable floodcat5            "5 - 6 feet flooding"
label variable floodcat6            "> 6 feet flooding"
label variable majblack             "Block is majority black"
label variable pctblack             "% of block residents who are black"
label variable majcoll              "Tract is majority college educated"
label variable pctcoll              "% of tract residents college educated"
label variable lnHOMEVAL05          "Log of home value prior to Katrina (log $1000s)"
label variable lnHHINC05            "Log annual household income before Katrina (log $1000s)"
label variable RHapplicant          "Road Home applicant indicator"
label variable running_imp          "Running variable (type1 / type 2 Road Home estimates)"
label variable running_APP_imp   "Running variable AFTER APPEALS (type1 / type 2 Road Home estimates)"
label variable type1_imp            "Road Home repair cost estimate"
label variable type2_imp            "Road Home replacement cost estimate"
label variable pct_pov_tr           "Tract 2000 poverty rate"
label variable ClosingOption        "Road Home grant option"
label variable NEVATRISK_opt2       "High insurance flag"
label variable flooding             "Block flood depth"
label variable lnSALE_PRICE         "Log of private sale price"
label variable Y0                   "Home livable imediately after Katrina"
label variable Y1                   "Home livable 1 yr after Katrina"
label variable Y2                   "Home livable 2 yr after Katrina"
label variable Y3                   "Home livable 3 yr after Katrina"
label variable Y4                   "Home livable 4 yr after Katrina"
label variable Y5                   "Home livable 5 yr after Katrina"

gen ____END_OF_VARS____=.
order ____END_OF_VARS____, last

drop ______END_OF_KEEPVARS______-____END_OF_VARS____

foreach var of varlist * {
cap keep if `var' < .
}

*recreate unique/sequential block and tract variables
bysort j: gen i = _n
label variable i "index of households within each block"
egen   I = sum(1), by(j)
keep if inrange(I,5,50)==1
label variable I "owner-occupied homes on block"

ren j j_old
egen j = group(j_old tau)
drop j_old

ren blockn bb_old
egen bb = group(bb_old tau)
drop bb_old

egen tau2 = group(tau) if Y0==0
egen aux = mean(tau2), by(tau)
replace tau2=aux
drop aux
replace tau2=-9999 if tau2==.



*** Save a "narrower" file with geographic information for reduced form tests of heterogeneity in spillover effects ***
preserve
keep i j bb blockid00 x y purchase_year majblack QualGeocode type2_impflag NEVATRISK_opt2 running_imp Y0 Y1 Y2 Y3 Y4 Y5
gen one=1
gen tempid=_n
compress
tempfile smallkeeplist
save    `smallkeeplist'

*** Create all pair-wise combinations (keeping those with distance < 1 mile)
forval ii=1/9999 {
di `ii'
qui {
use if mod(tempid,10000)==`ii' using `smallkeeplist'
drop one tempid
foreach var of varlist * {
ren `var' neigh_`var'
}
gen one=1
joinby one using `smallkeeplist', unmatched(both)
tab _m
drop _m
sphdist , gen(distance) lat1(y) lon1(x) lat2(neigh_y) lon2(neigh_x) units(mi)
drop if (i==neigh_i & j==neigh_j) | (inrange(running_imp,.33,.67)==0) | (NEVATRISK_opt2==1) | (distance>1)
order i j bb running_imp purchase_year majblack QualGeocode type2_impflag Y0 Y5 distance neigh_i neigh_bb neigh_j neigh_Y0 neigh_Y5 neigh_purchase_year neigh_majblack neigh_QualGeocode neigh_type2_impflag
keep  i j bb running_imp purchase_year majblack QualGeocode type2_impflag Y0 Y5 distance neigh_i neigh_bb neigh_j neigh_Y0 neigh_Y5 neigh_purchase_year neigh_majblack neigh_QualGeocode neigh_type2_impflag
save "`ouputdir'workfile_simple_paired_neighbors`ii'.dta", replace
clear
}
}
forval ii=0/9999 {
di `ii'
append using "`ouputdir'workfile_simple_paired_neighbors`ii'.dta"
}
save "`ouputdir'workfile_simple_paired_neighbors.dta", replace
restore


drop blockid00 tractid00

save           "`ouputdir'workfile_simple_NEW.dta", replace
outsheet using "`ouputdir'workfile_simple_NEW.csv", replace comma

gen ii = ""
forval ii = 1/50 {
replace ii = "_0`ii'" if `ii'< 10 & i==`ii'
replace ii = "_`ii'"  if `ii'>=10 & i==`ii'
}
*drop i x y purchase_year QualGeocode type2_impflag
keep ii j tau tau2 I A0 w0 w1 riskscore RISKCAT1 RISKCAT2 RISKCAT3 RISKCAT4 RISKCAT5 RISKCAT6 RISKCAT7 P_HAT_BASE RENT Mbal Mpmt PaymentsLeft k ins grant1 grant2 grantsmooth grant1_APPEAL grant2_APPEAL LMI_imp floodcat1 floodcat2 floodcat3 floodcat4 floodcat5 floodcat6 majblack pctblack majcoll pctcoll lnHOMEVAL05 lnHHINC05 RHapplicant running_APP_imp running_imp type1_imp type2_imp pct_pov_tr ClosingOption NEVATRISK_opt2 flooding lnSALE_PRICE Y0 Y1 Y2 Y3 Y4 Y5 

reshape wide A0-Y5 , i(j) j(ii) string

global orderlist = "j tau tau2 I"
foreach var in A0 w0 w1 riskscore RISKCAT1 RISKCAT2 RISKCAT3 RISKCAT4 RISKCAT5 RISKCAT6 RISKCAT7 P_HAT_BASE RENT Mbal Mpmt PaymentsLeft k ins grant1 grant2 grantsmooth grant1_APPEAL grant2_APPEAL LMI_imp floodcat1 floodcat2 floodcat3 floodcat4 floodcat5 floodcat6 majblack pctblack majcoll pctcoll lnHOMEVAL05 lnHHINC05 RHapplicant running_APP_imp running_imp type1_imp type2_imp pct_pov_tr ClosingOption NEVATRISK_opt2 flooding lnSALE_PRICE Y0 Y1 Y2 Y3 Y4 Y5 {
*3/25/17       A0 w0 w1 riskscore RISKCAT1 RISKCAT2	RISKCAT3 RISKCAT4 RISKCAT5 RISKCAT6 RISKCAT7 P_HAT_BASE RENT Mbal Mpmt PaymentsLeft k ins grant1 grant2 grantsmooth	grant1_APPEAL grant2_APPEAL LMI_imp floodcat1 floodcat2 floodcat3 floodcat4 floodcat5 floodcat6 majblack pctblack majcoll pctcoll lnHOMEVAL05 lnHHINC05 RHapplicant running_APP_imp running_imp type1_imp type2_imp	pct_pov_tr ClosingOption NEVATRISK_opt2 flooding lnSALE_PRICE Y0 Y1 Y2 Y3 Y4 Y5

global orderlist = "$orderlist `var'_*"
}

order $orderlist

outsheet using "`ouputdir'workfile_simple_wide_NEW.csv", replace comma nonames
save           "`ouputdir'workfile_simple_wide_NEW.dta", replace




