clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000
set matsize 11000

local ouputdir    ""      /* Location where processed data is stored */

set scheme s1mono

use "`ouputdir'workfile_simple_NEW.dta", replace

****************************************************
*** XX. Set parameters for reduced form analysis ***
****************************************************
global RUNNING       "running_imp"
global CUT            .51
global LO             .33
global HI             .67
global BIGBINS         200
global SMALLBINS      1000
global DEMOVARS      "pctblack lnHOMEVAL05_dol lnins_dol AVG_loo_GT51"
global OUTCOMES      "fitr_pct fitr fitr_APPEAL_pct Y5"
global SPILLOUTCOMES "AVG_loo_Y1 AVG_loo_Y2 AVG_loo_Y3 AVG_loo_Y4 AVG_loo_Y5     AVG_loo_Y5_lt10 AVG_loo_Y5_lt20 AVG_loo_Y5_lt30 AVG_loo_Y5_lt40 AVG_loo_Y5_lt50 AVG_loo_Y5_lt60 AVG_loo_Y5_lt70 AVG_loo_Y5_lt80 AVG_loo_Y5_lt90    AVG_loo_Y5_gt10 AVG_loo_Y5_gt20 AVG_loo_Y5_gt30 AVG_loo_Y5_gt40 AVG_loo_Y5_gt50 AVG_loo_Y5_gt60 AVG_loo_Y5_gt70 AVG_loo_Y5_gt80 AVG_loo_Y5_gt90"


*****************************
*** 0. Additional Recodes ***
*****************************
gen P1_XX1    =         (${RUNNING} - ${CUT})
gen P1_XXD0   =         (${RUNNING}>= ${CUT}) if ${RUNNING}<.
gen P1_XXD1   = P1_XXD0*(${RUNNING} - ${CUT})

gen P2_XX1    =         (${RUNNING} - ${CUT})
gen P2_XX2    =         (${RUNNING} - ${CUT})^2
gen P2_XXD0   =         (${RUNNING}>= ${CUT}) if ${RUNNING}<.
gen P2_XXD1   = P2_XXD0*(${RUNNING} - ${CUT})
gen P2_XXD2   = P2_XXD0*(${RUNNING} - ${CUT})^2

gen P3_XX1    =         (${RUNNING} - ${CUT})
gen P3_XX2    =         (${RUNNING} - ${CUT})^2
gen P3_XX3    =         (${RUNNING} - ${CUT})^3
gen P3_XXD0   =         (${RUNNING}>= ${CUT}) if ${RUNNING}<.
gen P3_XXD1   = P3_XXD0*(${RUNNING} - ${CUT})
gen P3_XXD2   = P3_XXD0*(${RUNNING} - ${CUT})^2
gen P3_XXD3   = P3_XXD0*(${RUNNING} - ${CUT})^3

gen one=1

gen roadhome23 = inlist(ClosingOption,2,3)

cap gen rh_ins_pct = min(1 , 1000 * ins / type1_imp) if type1_imp<. & ins<.

gen lnHOMEVAL05_dol = lnHOMEVAL05 + ln(1000)
gen lnins_dol       = ln(ins*1000)

gen fitr     = min(P_HAT_BASE - k + grant1 - grant2 , grant1)
gen fitr_pct = fitr / P_HAT_BASE

gen fitr_APPEAL     = min(P_HAT_BASE - k + grant1_APPEAL - grant2_APPEAL , grant1_APPEAL)
gen fitr_APPEAL_pct = fitr_APPEAL / P_HAT_BASE

gen lnrelwage = ln(w1/w0)

gen homevalue05 = exp(lnHOMEVAL05)*1000

replace lnSALE_PRICE     = . if lnSALE_PRICE==-999
gen     lnSALE_PRICE2    = lnSALE_PRICE if lnSALE_PRICE>ln(.2*homevalue05)

gen       SALE_PRICE     = exp(lnSALE_PRICE)
gen  postk_priv_sale     = lnSALE_PRICE<.

gen Option1  =  ClosingOption==1
gen Option23 = (ClosingOption==2)|(ClosingOption==3)
gen NoRH     = 1 - Option1 - Option23

forval ii=1/5 {
local iim1 = `ii'-1
gen hazY`ii' = Y`ii' if Y`iim1'==0
}


*** Coarser flood categories
gen flood_COARSE_1 = floodcat1
gen flood_COARSE_2 = floodcat2+floodcat3
gen flood_COARSE_3 = floodcat4+floodcat5+floodcat6


*** Risk score grouping with 8 categories (for figure, even number of categories looks better)
gen     EFcat = 8 if riskscore < .
replace EFcat = 7 if riskscore < 725
replace EFcat = 6 if riskscore < 700
replace EFcat = 5 if riskscore < 675
replace EFcat = 4 if riskscore < 650
replace EFcat = 3 if riskscore < 625
replace EFcat = 2 if riskscore < 600
replace EFcat = 1 if riskscore < 575


foreach var of varlist running_imp rh_ins_pct RISKCAT* NoRH Option1 Option23 Y1-Y5 {
gen D0_`var' = `var' if Y0==0
}


gen GT51 = running_imp>.51

* Compute block means and "leave-one-out" means
global BLOCKMEANS "running_imp GT51 Y* lnHOMEVAL05 fitr_pct fitr postk_priv_sale "
foreach var of varlist $BLOCKMEANS {
egen AVG_`var'=mean(`var'  ), by(j)
egen   N_`var'= sum(`var'<.), by(j)
}
foreach var of varlist $BLOCKMEANS {
gen     AVG_loo_`var' =  AVG_`var'
replace AVG_loo_`var' = (AVG_`var'*N_`var'-`var') / (N_`var'-1) if `var'<.
replace       N_`var' = (N_`var'-1) if `var'<.
}


* Define binary measures
gen AVG_loo_Y5_gt10 = AVG_loo_Y5>.1 & AVG_loo_Y5<.
gen AVG_loo_Y5_gt20 = AVG_loo_Y5>.2 & AVG_loo_Y5<.
gen AVG_loo_Y5_gt30 = AVG_loo_Y5>.3 & AVG_loo_Y5<.
gen AVG_loo_Y5_gt40 = AVG_loo_Y5>.4 & AVG_loo_Y5<.
gen AVG_loo_Y5_gt50 = AVG_loo_Y5>.5 & AVG_loo_Y5<.
gen AVG_loo_Y5_gt60 = AVG_loo_Y5>.6 & AVG_loo_Y5<.
gen AVG_loo_Y5_gt70 = AVG_loo_Y5>.7 & AVG_loo_Y5<.
gen AVG_loo_Y5_gt80 = AVG_loo_Y5>.8 & AVG_loo_Y5<.
gen AVG_loo_Y5_gt90 = AVG_loo_Y5>.9 & AVG_loo_Y5<.

gen AVG_loo_Y5_lt10 = AVG_loo_Y5<.1 & AVG_loo_Y5<.
gen AVG_loo_Y5_lt20 = AVG_loo_Y5<.2 & AVG_loo_Y5<.
gen AVG_loo_Y5_lt30 = AVG_loo_Y5<.3 & AVG_loo_Y5<.
gen AVG_loo_Y5_lt40 = AVG_loo_Y5<.4 & AVG_loo_Y5<.
gen AVG_loo_Y5_lt50 = AVG_loo_Y5<.5 & AVG_loo_Y5<.
gen AVG_loo_Y5_lt60 = AVG_loo_Y5<.6 & AVG_loo_Y5<.
gen AVG_loo_Y5_lt70 = AVG_loo_Y5<.7 & AVG_loo_Y5<.
gen AVG_loo_Y5_lt80 = AVG_loo_Y5<.8 & AVG_loo_Y5<.
gen AVG_loo_Y5_lt90 = AVG_loo_Y5<.9 & AVG_loo_Y5<.

*** Create bins of the running variable for RD figures
gen smallbins = floor((${RUNNING}-${CUT})*${SMALLBINS})/${SMALLBINS} + 1/${SMALLBINS}/2 + ${CUT}
gen   bigbins = floor((${RUNNING}-${CUT})*  ${BIGBINS})/  ${BIGBINS} + 1/  ${BIGBINS}/2 + ${CUT}
qui tab bigbins, gen(DumBin)


*********************************
*** 1. Descriptive Statistics ***
*********************************
preserve
gen CloseTo51 = inrange(running_imp,.49,.53)==1
logout, save(ZZZ_T1-DescriptiveStats_HH.xls      ) excel replace: tabstat pctblack pctcoll floodcat* Y0         running_imp rh_ins_pct RISKCAT* NoRH Option1 Option23 Y1-Y5        D0_running_imp D0_rh_ins_pct D0_RISKCAT* D0_NoRH D0_Option1 D0_Option23 D0_Y1-D0_Y5    CloseTo51               , columns(statistics) stat(mean sd N)
logout, save(ZZZ_T1-DescriptiveStats_HH_D0.xls   ) excel replace: tabstat pctblack pctcoll floodcat* Y0         running_imp rh_ins_pct RISKCAT* NoRH Option1 Option23 Y1-Y5        D0_running_imp D0_rh_ins_pct D0_RISKCAT* D0_NoRH D0_Option1 D0_Option23 D0_Y1-D0_Y5    CloseTo51        if Y0<1, columns(statistics) stat(mean sd N)
gen HHs=1
collapse majblack majcoll floodcat* Y0         running_imp rh_ins_pct RISKCAT* NoRH Option1 Option23 Y1-Y5    (sum) NumCloseTo51=CloseTo51 HHs, by(j)
gen AnyCloseTo51 = NumCloseTo51>0
tab HHs
su  HHs
logout, save(ZZZ_T2-DescriptiveStats_BLOCK.xls   ) excel replace: tabstat HHs majblack majcoll floodcat* Y0         running_imp rh_ins_pct RISKCAT* NoRH Option1 Option23 Y1-Y5    AnyCloseTo51 NumCloseTo51               , columns(statistics) stat(mean sd N)
logout, save(ZZZ_T2-DescriptiveStats_BLOCK_D0.xls) excel replace: tabstat HHs majblack majcoll floodcat* Y0         running_imp rh_ins_pct RISKCAT* NoRH Option1 Option23 Y1-Y5    AnyCloseTo51 NumCloseTo51        if Y0<1, columns(statistics) stat(mean sd N)
restore


*************************************************************************
*** 2. Show construction of running variable and perform mcCrary test ***
*************************************************************************
gen type1_imp_thous = type1_imp/1000
gen type2_imp_thous = type2_imp/1000
kdensity type1_imp_thous if type1_imp_thous<500 & type2_imp_thous<500 & type2_imp_thous>0, bw(7.5) gen(type1_grid type1_fhat) nograph
kdensity type2_imp_thous if type1_imp_thous<500 & type2_imp_thous<500 & type2_imp_thous>0, bw(7.5) gen(type2_grid type2_fhat) nograph
gen TYPE1_lab = ". Replacement Cost ($130 x Sq.Ft.)"
gen TYPE2_lab = "  Repair Cost (Checklist Estimate)"
twoway (line type1_fhat type1_grid, lwidth(.5) lcolor(black) legend(off) xtitle("Road Home Damage Appraisals ($1000s)", size(medlarge)) ytitle("Density", size(medlarge)) xlabel(, labsize(medium)) ylabel(, labsize(medium))) /*
*/     (line type2_fhat type2_grid, lwidth(.5) lcolor(black)) /*
*/     (scatter type1_fhat type1_grid if inrange(type1_grid,210,220)==1, mlabel(TYPE1_lab) mlabsize(medlarge) msize(0)) /*
*/     (scatter type2_fhat type2_grid if inrange(type2_grid,130,140)==1, mlabel(TYPE2_lab) mlabsize(medlarge) msize(0))
graph export "ZZZ-F2-Damage_Fraction_Inputs.eps", replace
!epstopdf    "ZZZ-F2-Damage_Fraction_Inputs.eps"
rm           "ZZZ-F2-Damage_Fraction_Inputs.eps"

histogram running_imp if inrange(running_imp,.01,.99), bin(900) xlabel(0(.25)1, labsize(large)) ylabel(0(1)5) lcolor(gs8) addplot(pci 0 .51 5 .51, lcolor(black) lwidth(.5) lpattern(dash)) legend(off) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(large)) ytitle( ,size(large))
graph export "ZZZ-F2-Damage_Fraction_Histogram.eps", replace
!epstopdf    "ZZZ-F2-Damage_Fraction_Histogram.eps"
rm           "ZZZ-F2-Damage_Fraction_Histogram.eps"


DCdensity ${RUNNING} if inrange(running_imp,.001,.999)==1 & RHapplicant==1, breakpoint(.51) generate(Xj Yj r0 fhat se_fhat) nograph
gen fhat_low = fhat-1.96*se_fhat
gen fhat_hi  = fhat+1.96*se_fhat
twoway (scatter Yj                 Xj if inrange(Xj,0,1)==1, msize(.7) mcolor(black) mfcolor(none)  xlabel(,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(large)) ytitle("Density", size(medlarge)) xlabel(0(.25)1, labsize(medium)) ylabel(, labsize(medium)) ) /*
*/     (line fhat_low fhat fhat_hi r0 if inrange(r0,0,1)==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(black black black)) /*
*/     (line fhat_low fhat fhat_hi r0 if inrange(r0,0,1)==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(black black black) xline(.51, lcolor(black)) legend(off))
graph export "ZZZ-F2-Damage_Fraction_McCrary.eps", replace
!epstopdf    "ZZZ-F2-Damage_Fraction_McCrary.eps"
rm           "ZZZ-F2-Damage_Fraction_McCrary.eps"
drop Yj Xj r0 fhat se_fhat fhat_low fhat_hi



DCdensity running_imp if inrange(running_imp,.3,.7)==1 & RHapplicant==1, breakpoint(.51) generate(Xj Yj r0 fhat se_fhat) nograph h(.06)
                                         global STARS_McCrary = ""
if 2*(1-normal(abs(r(theta)/r(se))))<.10 global STARS_McCrary = "*"
if 2*(1-normal(abs(r(theta)/r(se))))<.05 global STARS_McCrary = "**"
if 2*(1-normal(abs(r(theta)/r(se))))<.01 global STARS_McCrary = "***"
                                         global STARS_McCrary = "H0: Discontinuity=0  (p=" + string(2*(1-normal(abs(r(theta)/r(se)))),"%10.3f") +"$STARS_McCrary" + ")   "
gen fhat_low = fhat-1.96*se_fhat
gen fhat_hi  = fhat+1.96*se_fhat
twoway (scatter Yj                 Xj if inrange(Xj,.4,.6)==1, msize(.7) mcolor(black) mfcolor(none)  xlabel(,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(large)) ytitle("Density", size(large)) xlabel(.4(.1).6, labsize(large)) ylabel(1(2)6, labsize(large)) text(1.75 .541 "$STARS_McCrary", size(large)) ) /*
*/     (line fhat_low fhat fhat_hi r0 if inrange(r0,.4,.51)==1, lwidth(.1 .75 .1) lpattern(dash solid dash) lcolor(black black black)) /*
*/     (line fhat_low fhat fhat_hi r0 if inrange(r0,.51,.6)==1, lwidth(.1 .75 .1) lpattern(dash solid dash) lcolor(black black black) xline(.51, lcolor(black)) legend(off))
graph export "ZZZ-F2-ZOOM_Damage_Fraction_McCrary.eps", replace
!epstopdf    "ZZZ-F2-ZOOM_Damage_Fraction_McCrary.eps"
rm           "ZZZ-F2-ZOOM_Damage_Fraction_McCrary.eps"
drop Yj Xj r0 fhat se_fhat fhat_low fhat_hi

*POST-APPEALS VERSION
DCdensity running_APP_imp if inrange(running_APP_imp,.3,.7)==1 & RHapplicant==1, breakpoint(.51) generate(Xj Yj r0 fhat se_fhat) nograph h(.06)
                                         global STARS_McCrary = ""
if 2*(1-normal(abs(r(theta)/r(se))))<.10 global STARS_McCrary = "*"
if 2*(1-normal(abs(r(theta)/r(se))))<.05 global STARS_McCrary = "**"
if 2*(1-normal(abs(r(theta)/r(se))))<.01 global STARS_McCrary = "***"
                                         global STARS_McCrary = "H0: Discontinuity=0  (p=" + string(2*(1-normal(abs(r(theta)/r(se)))),"%10.3f") +"$STARS_McCrary" + ")   "
gen fhat_low = fhat-1.96*se_fhat
gen fhat_hi  = fhat+1.96*se_fhat
twoway (scatter Yj                 Xj if inrange(Xj,.4,.6)==1, msize(.7) mcolor(black) mfcolor(none)  xlabel(,labsize(large)) ylabel(,labsize(large)) xtitle("Post-appeal: (Repair Cost) ÷ (Replacement Cost)", size(large)) ytitle("Density", size(large)) xlabel(.4(.1).6, labsize(large)) ylabel(1(2)6, labsize(large)) text(1.75 .541 "$STARS_McCrary", size(large)) ) /*
*/     (line fhat_low fhat fhat_hi r0 if inrange(r0,.4,.51)==1, lwidth(.1 .75 .1) lpattern(dash solid dash) lcolor(black black black)) /*
*/     (line fhat_low fhat fhat_hi r0 if inrange(r0,.51,.6)==1, lwidth(.1 .75 .1) lpattern(dash solid dash) lcolor(black black black) xline(.51, lcolor(black)) legend(off))
graph export "ZZZ-AF2-ZOOM_Damage_Fraction_McCrary.eps", replace
!epstopdf    "ZZZ-AF2-ZOOM_Damage_Fraction_McCrary.eps"
rm           "ZZZ-AF2-ZOOM_Damage_Fraction_McCrary.eps"
drop Yj Xj r0 fhat se_fhat fhat_low fhat_hi


*********************
*** 3. RD Figures ***
*********************
global OUTCOMECONDITION "& NEVATRISK_opt2==0"
global COVARS           ""
global COVARS           "AVG_loo_fitr_pct"
global COVARS           ""

foreach outcome of varlist $DEMOVARS $OUTCOMES $SPILLOUTCOMES {
                                        local condition = "$OUTCOMECONDITION"
if "`outcome'"=="Y5"                    local condition = "$OUTCOMECONDITION"
if "`outcome'"=="AVG_loo_Y5"            local condition = "$OUTCOMECONDITION"

                                        local covars    = ""
if "`outcome'"=="fitr_pct"              local covars    = "$COVARS"
if "`outcome'"=="Y5"                    local covars    = "$COVARS"
if "`outcome'"=="AVG_loo_Y5"            local covars    = "$COVARS"
if "`outcome'"=="AVG_loo_lnSALE_PRICE"  local covars    = "$COVARS"
if "`outcome'"=="AVG_loo_lnSALE_PRICE2" local covars    = "$COVARS"

****************************************************************************
*** BASELINE RD SPECIFICATION -- Make record of statistical significance ***
****************************************************************************
reg `outcome' P2_XX* `covars' if inrange(${RUNNING},${LO},${HI})==1 `condition', robust
                                       global STARS_`outcome' = "Discontinuity = " + string(_b[P2_XXD0],"%10.3f") + "  (" + string(_se[P2_XXD0],"%10.3f") + ")   "
if abs(_b[P2_XXD0]/_se[P2_XXD0])>1.645 global STARS_`outcome' = "Discontinuity = " + string(_b[P2_XXD0],"%10.3f") + "  (" + string(_se[P2_XXD0],"%10.3f") + ")*  "
if abs(_b[P2_XXD0]/_se[P2_XXD0])>1.96  global STARS_`outcome' = "Discontinuity = " + string(_b[P2_XXD0],"%10.3f") + "  (" + string(_se[P2_XXD0],"%10.3f") + ")** "
if abs(_b[P2_XXD0]/_se[P2_XXD0])>2.575 global STARS_`outcome' = "Discontinuity = " + string(_b[P2_XXD0],"%10.3f") + "  (" + string(_se[P2_XXD0],"%10.3f") + ")***"
if "`outcome'" == "fitr" {
                                          global STARS_`outcome' = "Discontinuity = " + string(_b[P2_XXD0],"%10.1f") + "  (" + string(_se[P2_XXD0],"%10.1f") + ")   "
   if abs(_b[P2_XXD0]/_se[P2_XXD0])>1.645 global STARS_`outcome' = "Discontinuity = " + string(_b[P2_XXD0],"%10.1f") + "  (" + string(_se[P2_XXD0],"%10.1f") + ")*  "
   if abs(_b[P2_XXD0]/_se[P2_XXD0])>1.96  global STARS_`outcome' = "Discontinuity = " + string(_b[P2_XXD0],"%10.1f") + "  (" + string(_se[P2_XXD0],"%10.1f") + ")** "
   if abs(_b[P2_XXD0]/_se[P2_XXD0])>2.575 global STARS_`outcome' = "Discontinuity = " + string(_b[P2_XXD0],"%10.1f") + "  (" + string(_se[P2_XXD0],"%10.1f") + ")***"
   }
gen regsample = e(sample)==1
gen aux = AVG_loo_fitr_pct
su AVG_loo_fitr_pct                if regsample==1
replace AVG_loo_fitr_pct = r(mean) if regsample==1
predict HAT_`outcome'              if regsample==1
predict auxSE                      if regsample==1, stdp
gen HAT_`outcome'_hi = HAT_`outcome'+1.96*auxSE
gen HAT_`outcome'_lo = HAT_`outcome'-1.96*auxSE
replace AVG_loo_fitr_pct = aux
drop aux auxSE regsample
qui reg `outcome' DumBin* `covars' if inrange(${RUNNING},${LO},${HI})==1 `condition', robust
gen regsample = e(sample)==1
gen aux = AVG_loo_fitr_pct
su AVG_loo_fitr_pct                if regsample==1
replace AVG_loo_fitr_pct = r(mean) if regsample==1
predict BAR_`outcome'              if regsample==1
replace AVG_loo_fitr_pct = aux
drop aux regsample

********************************************************************
*** ALTERNATIVE RD SPECIFICATIONS (BANDWIDTHS/POLYNOMIAL ORDERS) ***
********************************************************************
reg `outcome' P1_XX* `covars' if inrange(${RUNNING},${LO},${HI})==1 `condition', robust
gen regsample = e(sample)==1
gen aux = AVG_loo_fitr_pct
su AVG_loo_fitr_pct                if regsample==1
replace AVG_loo_fitr_pct = r(mean) if regsample==1
predict HAT_`outcome'_P1           if regsample==1
replace AVG_loo_fitr_pct = aux
drop aux regsample

reg `outcome' P2_XX* `covars' if inrange(${RUNNING},${LO},${HI})==1 `condition', robust
gen regsample = e(sample)==1
gen aux = AVG_loo_fitr_pct
su AVG_loo_fitr_pct                if regsample==1
replace AVG_loo_fitr_pct = r(mean) if regsample==1
predict HAT_`outcome'_P2           if regsample==1
replace AVG_loo_fitr_pct = aux
drop aux regsample

reg `outcome' P3_XX* `covars' if inrange(${RUNNING},${LO},${HI})==1 `condition', robust
gen regsample = e(sample)==1
gen aux = AVG_loo_fitr_pct
su AVG_loo_fitr_pct                if regsample==1
replace AVG_loo_fitr_pct = r(mean) if regsample==1
predict HAT_`outcome'_P3           if regsample==1
replace AVG_loo_fitr_pct = aux
drop aux regsample

reg `outcome' P1_XX* `covars' if inrange(${RUNNING},.41,.61)==1 `condition', robust
gen regsample = e(sample)==1
gen aux = AVG_loo_fitr_pct
su AVG_loo_fitr_pct                if regsample==1
replace AVG_loo_fitr_pct = r(mean) if regsample==1
predict HAT_`outcome'_NP1          if regsample==1
replace AVG_loo_fitr_pct = aux
drop aux regsample

reg `outcome' P2_XX* `covars' if inrange(${RUNNING},.41,.61)==1 `condition', robust
gen regsample = e(sample)==1
gen aux = AVG_loo_fitr_pct
su AVG_loo_fitr_pct                if regsample==1
replace AVG_loo_fitr_pct = r(mean) if regsample==1
predict HAT_`outcome'_NP2          if regsample==1
replace AVG_loo_fitr_pct = aux
drop aux regsample

reg `outcome' P3_XX* `covars' if inrange(${RUNNING},.41,.61)==1 `condition', robust
gen regsample = e(sample)==1
gen aux = AVG_loo_fitr_pct
su AVG_loo_fitr_pct                if regsample==1
replace AVG_loo_fitr_pct = r(mean) if regsample==1
predict HAT_`outcome'_NP3          if regsample==1
replace AVG_loo_fitr_pct = aux
drop aux regsample

}
preserve
collapse HAT_*, by(smallbins)
tempfile smallbin_results
save    `smallbin_results'
restore
preserve
collapse BAR_*, by(bigbins)
tempfile bigbin_results
save    `bigbin_results'
restore

drop HAT_* BAR_*

append using `smallbin_results'
append using   `bigbin_results'

*****************************************************************************************
*** RD Impacts on $ incentive to rebuild and on private rebuilding choice, (FIGURE 1) ***
*****************************************************************************************
foreach outcome of varlist $OUTCOMES {
if "`outcome'"=="fitr"     local ytitle "Incentive to Rebuild ($1000s)"
if "`outcome'"=="fitr_pct" local ytitle "Incentive to Rebuild as % of Home Price"
if "`outcome'"=="Y5"       local ytitle "Home Repaired by Katrina's 5th Anniv."
su BAR_`outcome' if inrange(bigbins,${LO},${HI})==1
local y_lo = floor(r(mean)*10)/10-.2
local y_hi =  ceil(r(mean)*10)/10+.2
if "`outcome'"=="fitr"     local y_lo = 0
if "`outcome'"=="fitr"     local y_hi =  ceil(r(mean)*10)/10+20
local y_lab_loc = r(max)+.05
            local ylabel ""
if r(max)<1 local ylabel "`y_lo'(.1)`y_hi'"
if "`outcome'"=="fitr" local ylabel "`y_lo'(10)`y_hi'"
twoway (scatter BAR_`outcome' bigbins if inrange(bigbins,${LO} ,${CUT}-.001)==1, msize(1.5) mcolor(black) mfcolor(none)  xlabel(,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(medium)) ytitle("`ytitle'", size(medlarge)) xlabel(, labsize(medium)) ylabel(`ylabel', labsize(medium)) xline(.51, lcolor(black)) legend(off) ) /*
*/     (scatter BAR_`outcome' bigbins if inrange(bigbins,${CUT},${HI}      )==1, msize(1.5) mcolor(red  ) mfcolor(none)  text(`y_lab_loc' .6125 "${STARS_`outcome'}") ) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(black black black)) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${CUT},${HI}      )==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(red   red   red  ))
graph export "ZZZ-3-Household_RDs_`outcome'.eps", replace
!epstopdf    "ZZZ-3-Household_RDs_`outcome'.eps"
rm           "ZZZ-3-Household_RDs_`outcome'.eps"
twoway (scatter BAR_`outcome' bigbins if inrange(bigbins,${LO} ,${CUT}-.001)==1, msize(1.5) mcolor(black) mfcolor(none)  xlabel(.3 .4 .5 .6 .7 ,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(medium)) ytitle("`ytitle'", size(medlarge)) xlabel(, labsize(medium)) ylabel(`ylabel', labsize(medium)) xline(.51, lcolor(black)) legend(off) ) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(black black black))
graph export "ZZZ-3-Household_RDs_`outcome'_suspense.eps", replace
!epstopdf    "ZZZ-3-Household_RDs_`outcome'_suspense.eps"
rm           "ZZZ-3-Household_RDs_`outcome'_suspense.eps"

*************************************
*** Alternative Control Functions ***
*************************************
twoway (scatter BAR_`outcome' bigbins if inrange(bigbins,${LO} ,${CUT}-.001)==1, msize(1.5) mcolor(black) mfcolor(none)  xlabel(,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(medium)) ytitle("`ytitle'", size(medlarge)) xlabel(, labsize(medium)) ylabel(`ylabel', labsize(medium)) xline(.51, lcolor(black)) legend(off) ) /*
*/     (scatter BAR_`outcome' bigbins if inrange(bigbins,${CUT},${HI}      )==1, msize(1.5) mcolor(red  ) mfcolor(none) ) /*
*/     (line    HAT_`outcome'_P2 HAT_`outcome'_P3 HAT_`outcome'_NP1 HAT_`outcome'_NP2 HAT_`outcome'_NP3 smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.25 .25 .25 .25 .25) lpattern(solid solid solid solid solid) lcolor(black black black black black)) /*
*/     (line    HAT_`outcome'_P2 HAT_`outcome'_P3 HAT_`outcome'_NP1 HAT_`outcome'_NP2 HAT_`outcome'_NP3 smallbins if inrange(smallbins,${CUT},${HI}      )==1, lwidth(.25 .25 .25 .25 .25) lpattern(solid solid solid solid solid) lcolor(red   red   red   red   red  ))
graph export "ZZZ-A3-Household_RDs_`outcome'.eps", replace
!epstopdf    "ZZZ-A3-Household_RDs_`outcome'.eps"
rm           "ZZZ-A3-Household_RDs_`outcome'.eps"
}




*********************************************************************************************
*** Balance tests -- RD figures for presentations (Some of the outcomes shown in TABLE 3) ***
*********************************************************************************************
foreach outcome of varlist $DEMOVARS {
if "`outcome'"=="pctblack"        local ytitle "Fraction Black (block)"
if "`outcome'"=="AVG_loo_GT51"    local ytitle "Fraction of neighbors with Running Variable >.51"
if "`outcome'"=="lnHOMEVAL05_dol" local ytitle "Log of Pre-Katrina Home Value"
if "`outcome'"=="lnins_dol"       local ytitle "Log of Insurance Payout"
su BAR_`outcome' if inrange(bigbins,${LO},${HI})==1
local y_lo      = floor(r(mean)*10)/10-.2
local y_hi      =  ceil(r(mean)*10)/10+.2
local y_lab_loc = r(min)+.19
            local ylabel ""
if r(max)<1 local ylabel "`y_lo'(.1)`y_hi'"
twoway (scatter BAR_`outcome' bigbins if inrange(bigbins,${LO} ,${CUT}-.001)==1, msize(1.5) mcolor(black) mfcolor(none)  xlabel(,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(medium)) ytitle("`ytitle'", size(large)) xlabel(, labsize(medium)) ylabel(`ylabel', labsize(medium)) xline(.51, lcolor(black)) legend(off)) /*
*/     (scatter BAR_`outcome' bigbins if inrange(bigbins,${CUT},${HI}      )==1, msize(1.5) mcolor(red  ) mfcolor(none)  text(`y_lab_loc' .6125 "${STARS_`outcome'}") ) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(black black black)) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${CUT},${HI}      )==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(red   red   red  ))
graph export "ZZZ-2-Covar_Balance_`outcome'.eps", replace
!epstopdf    "ZZZ-2-Covar_Balance_`outcome'.eps"
rm           "ZZZ-2-Covar_Balance_`outcome'.eps"
twoway (scatter BAR_`outcome' bigbins if inrange(bigbins,${LO} ,${CUT}-.001)==1, msize(1.5) mcolor(black) mfcolor(none)  xlabel(.3 .4 .5 .6 .7 ,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(medium)) ytitle("`ytitle'", size(large)) xlabel(, labsize(medium)) ylabel(`ylabel', labsize(medium)) xline(.51, lcolor(black)) legend(off)) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(black black black))
graph export "ZZZ-2-Covar_Balance_`outcome'_suspense.eps", replace
!epstopdf    "ZZZ-2-Covar_Balance_`outcome'_suspense.eps"
rm           "ZZZ-2-Covar_Balance_`outcome'_suspense.eps"
}



***************************************
*** Spillover RD Figures (FIGURE 4) ***
***************************************
foreach outcome of varlist $SPILLOUTCOMES {
if "`outcome'"=="AVG_loo_Y5"            local ytitle "Frac. of Neighbors Rebuilt by 5th Anniv."
if "`outcome'"=="AVG_loo_lnSALE_PRICE"  local ytitle "Average log Sale Price of Neighbor's Homes"
if "`outcome'"=="AVG_loo_lnSALE_PRICE2" local ytitle "Average log Sale Price of Neighbor's Homes"
su BAR_`outcome' if inrange(bigbins,${LO},${HI})==1
local y_lo = floor(r(mean)*10)/10-.15
local y_hi =  ceil(r(mean)*10)/10+.1
local y_lab_loc = r(min)+.15
            local ylabel ""
if r(max)<1 local ylabel "`y_lo'(.1)`y_hi'"
if substr("`outcome'",1,13)=="AVG_loo_Y5_lt" | substr("`outcome'",1,13)=="AVG_loo_Y5_gt" {
    local ylabel "0(.2)1"
	local ytitle ""
    }
di "`ylabel'"

twoway (scatter BAR_`outcome' bigbins if inrange(bigbins,${LO} ,${CUT}-.001)==1, msize(1.5) mcolor(black) mfcolor(none)  xlabel(,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(medium)) ytitle("`ytitle'", size(medlarge)) xlabel(, labsize(medium)) ylabel(`ylabel', labsize(medium)) xline(.51, lcolor(black)) legend(off) ) /*
*/     (scatter BAR_`outcome' bigbins if inrange(bigbins,${CUT},${HI}      )==1, msize(1.5) mcolor(red  ) mfcolor(none)  text(`y_lab_loc' .6125 "${STARS_`outcome'}") ) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(black black black)) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${CUT},${HI}      )==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(red   red   red  )) 
/*     (line                     HAT_`outcome'                  smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.1 .25 .1) lpattern(     solid     ) lcolor(      black      )) */
/*     (line                     HAT_`outcome'                  smallbins if inrange(smallbins,${CUT},${HI}      )==1, lwidth(.1 .25 .1) lpattern(     solid     ) lcolor(      red        )) */
graph export "ZZZ-4-Spillover_RDs_`outcome'.eps", replace
!epstopdf    "ZZZ-4-Spillover_RDs_`outcome'.eps"
rm           "ZZZ-4-Spillover_RDs_`outcome'.eps"
twoway (scatter BAR_`outcome' bigbins if inrange(bigbins,${LO} ,${CUT}-.001)==1, msize(1.5) mcolor(black) mfcolor(none)  xlabel(.3 .4 .5 .6 .7 ,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(medium)) ytitle("`ytitle'", size(medlarge)) xlabel(, labsize(medium)) ylabel(`ylabel', labsize(medium)) xline(.51, lcolor(black)) legend(off) ) /*
*/     (line    HAT_`outcome'_lo HAT_`outcome' HAT_`outcome'_hi smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.1 .5 .1) lpattern(dash solid dash) lcolor(black black black)) 
graph export "ZZZ-4-Spillover_RDs_`outcome'_suspense.eps", replace
!epstopdf    "ZZZ-4-Spillover_RDs_`outcome'_suspense.eps"
rm           "ZZZ-4-Spillover_RDs_`outcome'_suspense.eps"

twoway (scatter BAR_`outcome' bigbins if inrange(bigbins,${LO} ,${CUT}-.001)==1, msize(1.5) mcolor(black) mfcolor(none)  xlabel(,labsize(large)) ylabel(,labsize(large)) xtitle("(Repair Cost) ÷ (Replacement Cost)", size(medium)) ytitle("`ytitle'", size(medlarge)) xlabel(, labsize(medium)) ylabel(`ylabel', labsize(medium)) xline(.51, lcolor(black)) legend(off) ) /*
*/     (scatter BAR_`outcome' bigbins if inrange(bigbins,${CUT},${HI}      )==1, msize(1.5) mcolor(red  ) mfcolor(none) ) /*
*/     (line    HAT_`outcome'_P2 HAT_`outcome'_P3 HAT_`outcome'_NP1 HAT_`outcome'_NP2 HAT_`outcome'_NP3 smallbins if inrange(smallbins,${LO} ,${CUT}-.001)==1, lwidth(.25 .25 .25 .25 .25) lpattern(solid solid solid solid solid) lcolor(black black black black black)) /*
*/     (line    HAT_`outcome'_P2 HAT_`outcome'_P3 HAT_`outcome'_NP1 HAT_`outcome'_NP2 HAT_`outcome'_NP3 smallbins if inrange(smallbins,${CUT},${HI}      )==1, lwidth(.25 .25 .25 .25 .25) lpattern(solid solid solid solid solid) lcolor(red   red   red   red   red  ))
graph export "ZZZ-A4-Household_RDs_`outcome'.eps", replace
!epstopdf    "ZZZ-A4-Household_RDs_`outcome'.eps"
rm           "ZZZ-A4-Household_RDs_`outcome'.eps"
}




********************************************
*** 4. Create RD Balance Table (TABLE 3) ***
********************************************
global RUNNING       "running_imp"
global CUT            .51
global LO             .33
global HI             .67


*preserve
drop Dum*

cap drop LEFT*
cap drop RIGHT*
gen  LEFT_XX0 = (${RUNNING} < ${CUT})
gen  LEFT_XX1 = (${RUNNING} < ${CUT}) * (${RUNNING} - ${CUT})
gen  LEFT_XX2 = (${RUNNING} < ${CUT}) * (${RUNNING} - ${CUT})^2
gen RIGHT_XX0 = (${RUNNING} > ${CUT})
gen RIGHT_XX1 = (${RUNNING} > ${CUT}) * (${RUNNING} - ${CUT})
gen RIGHT_XX2 = (${RUNNING} > ${CUT}) * (${RUNNING} - ${CUT})^2


cap drop P2_*
gen P2_XX1    =         (${RUNNING} - ${CUT})
gen P2_XX2    =         (${RUNNING} - ${CUT})^2
gen P2_XXD0   =         (${RUNNING}>= ${CUT}) if ${RUNNING}<.
gen P2_XXD1   = P2_XXD0*(${RUNNING} - ${CUT})
gen P2_XXD2   = P2_XXD0*(${RUNNING} - ${CUT})^2



su pctblack pctcoll AVG_loo_Y0 pct_pov_tr flooding riskscore

logit Y5 pctblack pctcoll* pct_pov_tr* riskscore* flooding* flood_COARSE_* if Y0==0
predict Y5_hat

*foreach var of varlist   AVG_loo_running_imp AVG_loo_GT51 AVG_loo_Y0   pctblack pctcoll* pct_pov_tr* riskscore* flooding* flood_COARSE_* {
 foreach var of varlist   AVG_loo_running_imp AVG_loo_GT51 AVG_loo_Y0   pctblack pctcoll  pct_pov_tr  riskscore  flooding  {
   su  `var' if Y0==0, d

   gen `var'_lt10 = `var'<r(p10)
   gen `var'_lt25 = `var'<r(p25)
   gen `var'_lt50 = `var'<r(p50)
   gen `var'_lt75 = `var'<r(p75)
   gen `var'_lt90 = `var'<r(p90)
}

************************
*** Populate TABLE 3 ***
************************
tempname memhold
tempfile results
postfile `memhold'   str30 OUTCOME   LEFT RIGHT DIFF    using "ZZZ_T3-RD_Balance.dta", replace

su                       Y5_hat AVG_loo_running_imp AVG_loo_GT51 AVG_loo_Y0 pctblack pctcoll* pct_pov_tr* riskscore* flooding flood_COARSE_* 
foreach var of varlist   Y5_hat AVG_loo_running_imp AVG_loo_GT51 AVG_loo_Y0 pctblack pctcoll* pct_pov_tr* riskscore* flooding flood_COARSE_* {

   reg `var' LEFT* RIGHT* if inrange(${RUNNING},${LO},${HI})==1 & Y0==0, nocons
   local  B_LEFT  =  _b[LEFT_XX0]
   local  B_RIGHT =  _b[RIGHT_XX0]
   local SE_LEFT  = _se[LEFT_XX0]
   local SE_RIGHT = _se[RIGHT_XX0]
   reg `var' P2_* if inrange(${RUNNING},${LO},${HI})==1
   local  B_DIFF  =  _b[P2_XXD0]
   local SE_DIFF  = _se[P2_XXD0]

   post `memhold' ("`var'   ")    ( `B_LEFT') ( `B_RIGHT') ( `B_DIFF')
   post `memhold' ("`var'_SE")    (`SE_LEFT') (`SE_RIGHT') (`SE_DIFF') 

}

postclose `memhold'


clear

use "ZZZ_T3-RD_Balance.dta"
edit




