clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000

local ouputdir    ""      /* Location where processed data is stored */

set scheme s1mono

****************************************************
*** XX. Set parameters for reduced form analysis ***
****************************************************
global RUNNING       "running_imp"
global CUT            .51
global LO             .33
global HI             .67
global RUNBINS         200
global DISTBINS        100
global DEMOVARS      "pctblack lnHOMEVAL05_dol lnins_dol AVG_loo_GT51"
global OUTCOMES      "fitr_pct fitr_APPEAL_pct Y5"
global SPILLOUTCOMES "AVG_loo_Y5"



*****************************
*** 0. Additional Recodes ***
*****************************
use              "`ouputdir'workfile_simple_paired_neighbors.dta", replace

keep if neigh_QualGeocode>=75 & QualGeocode>=75
keep if neigh_Y0==0

gen   bigbins      = floor((${RUNNING}-${CUT})*  ${RUNBINS})/  ${RUNBINS} + 1/  ${RUNBINS}/2 + ${CUT}
gen   distancebins = floor((distance)*${DISTBINS})/  ${DISTBINS} + 1/  ${DISTBINS}/2

gen P2_XX1    =         (${RUNNING} - ${CUT})
gen P2_XX2    =         (${RUNNING} - ${CUT})^2
gen P2_XXD0   =         (${RUNNING}>= ${CUT}) if ${RUNNING}<.
gen P2_XXD1   = P2_XXD0*(${RUNNING} - ${CUT})
gen P2_XXD2   = P2_XXD0*(${RUNNING} - ${CUT})^2

gen N=1

collapse (sum) N, by(Y5 neigh_Y5 distancebins bigbins j neigh_j)
save tempcollapsed.dta, replace
clear


use tempcollapsed.dta

drop if distancebins>1

ren bigbins running_imp
ren distancebins distance

gen P2_XX1    =         (${RUNNING} - ${CUT})
gen P2_XX2    =         (${RUNNING} - ${CUT})^2
gen P2_XXD0   =         (${RUNNING}>= ${CUT}) if ${RUNNING}<.
gen P2_XXD1   = P2_XXD0*(${RUNNING} - ${CUT})
gen P2_XXD2   = P2_XXD0*(${RUNNING} - ${CUT})^2

gen all=1


*********************************************************************************************************
*** Nonparametric spillover RD estimates, seperate estimate within narrow distance-from-neighbor bins ***
*********************************************************************************************************
reg neigh_Y5 INT_SPL* SPL1-SPL4 [fw=N], cluster(j)
gen FIT_POLY    = _b[INT_SPL0_P2_XXD0]*SPL0 + _b[INT_SPL1_P2_XXD0]*SPL1 + _b[INT_SPL2_P2_XXD0]*SPL2 + _b[INT_SPL3_P2_XXD0]*SPL3 + _b[INT_SPL4_P2_XXD0]*SPL4
gen FIT_POLY_SE = .
levelsof distance, local(aa)
foreach dd of local aa {
   local spl0 = 1
   local spl1 = `dd'
   local spl2 = `dd'^2
   local spl3 = max(0,`dd'-.333)^2
   local spl4 = max(0,`dd'-.666)^2
   lincom INT_SPL0_P2_XXD0*`spl0'  +  INT_SPL1_P2_XXD0*`spl1'  +  INT_SPL2_P2_XXD0*`spl2'  +  INT_SPL3_P2_XXD0*`spl3' + INT_SPL4_P2_XXD0*`spl4'
   replace FIT_POLY_SE = r(se) if abs(distance-`dd')<.0001
   }
preserve
collapse FIT_POLY FIT_POLY_SE, by(distance)
ren distance POLY_distance_grid
save FILEPolinomialFit.dta, replace
restore
foreach var in all {
   cap drop X`var'
   cap drop Y`var'
   cap drop W`var'
   levelsof distance, local(aa)
   gen X`var'=.
   gen Y`var'=.
   gen W`var'=.
   foreach dd of local aa {
      qui reg neigh_Y5 P2_XX* if `var'==1 & abs(distance-`dd')<.00001 [fw=N]
      local ii=`ii'+1
      replace X`var'=`dd' if _n==`ii'
      replace Y`var'=_b[P2_XXD0] if _n==`ii'
      egen aux = sum(N*`var'*(abs(distance-`dd')<.00001))
      replace W`var'=aux if _n==`ii'
      drop aux
      }
   }

preserve
keep Xall Yall
keep if Xall<.
gen Spill2sls = Yall / .049
ren Yall Spill_rd 
ren Xall NonPar_distance_grid
save FILENonPar_2slsByDistance.dta, replace
restore


************************************************************************
*** Spillover RDs with flexible smoothing in distance ("parametric") ***
************************************************************************
reg neigh_Y5 INT_SPL* SPL1-SPL4 [fw=N], cluster(j)
gen FIT_POLY    = _b[INT_SPL0_P2_XXD0]*SPL0 + _b[INT_SPL1_P2_XXD0]*SPL1 + _b[INT_SPL2_P2_XXD0]*SPL2 + _b[INT_SPL3_P2_XXD0]*SPL3 + _b[INT_SPL4_P2_XXD0]*SPL4
gen FIT_POLY_SE = .
levelsof distance, local(aa)
foreach dd of local aa {
   local spl0 = 1
   local spl1 = `dd'
   local spl2 = `dd'^2
   local spl3 = max(0,`dd'-.333)^2
   local spl4 = max(0,`dd'-.666)^2
   lincom INT_SPL0_P2_XXD0*`spl0'  +  INT_SPL1_P2_XXD0*`spl1'  +  INT_SPL2_P2_XXD0*`spl2'  +  INT_SPL3_P2_XXD0*`spl3' + INT_SPL4_P2_XXD0*`spl4'
   replace FIT_POLY_SE = r(se) if abs(distance-`dd')<.0001
   }
preserve
collapse FIT_POLY FIT_POLY_SE, by(distance)
ren distance POLY_distance_grid
save FILEPolinomialFit.dta, replace
restore


*****************************************************************
*** Overlay parametric and nonparametric estimates (FIGURE 3) ***
*****************************************************************
preserve
clear
use FILENonPar_2slsByDistance.dta
append using      FILEPolinomialFit.dta

gen      LOW_rd =      FIT_POLY-1.96*     FIT_POLY_SE
gen       HI_rd =      FIT_POLY+1.96*     FIT_POLY_SE

gen SBlk_LOW_rd = SBlk_FIT_POLY-1.96*SBlk_FIT_POLY_SE
gen  SBlk_HI_rd = SBlk_FIT_POLY+1.96*SBlk_FIT_POLY_SE

gen DBlk_LOW_rd = DBlk_FIT_POLY-1.96*DBlk_FIT_POLY_SE
gen  DBlk_HI_rd = DBlk_FIT_POLY+1.96*DBlk_FIT_POLY_SE

gen FIT_POLY2sls = FIT_POLY / .049


gen     LOW_tc=LOW_rd
replace LOW_tc=r(min)-.05 if LOW_rd < r(min)-.15
gen     HI_tc =HI_rd
replace HI_tc =r(max)+.05 if abs(HI_rd-.99)<.0001

twoway   (scatter Spill_rd NonPar_distance_grid, msize(2.5) mcolor(black) mfcolor(none) msymbol(o) xlabel(0(.25)1) ylabel(-.02(.02).053) xtitle( "Distance from Subsidized Household (miles)" ) ytitle( "{bf: Diff. in Neighbors' Pr(Rebuild) Above vs. Below 51% Damage}", size(small))  yline(0, lwidth(.5)) xline(-.0175, lwidth(.5))  lstyle(foreground) ) /*
*/       (line LOW_rd FIT_POLY HI_rd POLY_distance_grid, lcolor(black black black) lwidth(.1 1 .1) lpattern(dash l dash) legend(off) ), plotregion(style(none))

   graph export "ZZZ-F3-RDSpiloverByDistance.eps", replace
   !epstopdf    "ZZZ-F3-RDSpiloverByDistance.eps"
   rm           "ZZZ-F3-RDSpiloverByDistance.eps"

restore

