clear
addpath('CompEcon','Sims_software');
%
% submit syntax:  
%   cd /project/DNORS_chaofu/1.analysis--spillovers/2.programs/gregory/3a.matlab_model_solution/
%   matlab -nodesktop -nodisplay < A2cf_simulations.m > A2cf_simulations.log &
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%% codes for counterfactual policies %%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1 = Road Home program in place (baseline).      %
% 2 = No Road Home program (counterfactual).      %
% 3 = Road Home program financial incentive,      %
%        g(mu) fixed at no-Road-Home level.       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%tic

ouputdir  ''  % Directory where merged data is stored %


strcat(ouputdir,'workfile_simple_wide_NEW.csv');


Infile          = strcat(ouputdir,'workfile_simple_wide.mat');
RecodedFile     = strcat(ouputdir,'workfile_simple_wide_recoded.mat');
DataMomentsFile = strcat(ouputdir,'DataMoments.mat');
SimOutputFile   = strcat(ouputdir,'SimOutputFile');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% 1. COMPUTE AUXILIARY MODELS FROM REAL DATA %%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% A. DO SOME RECODES %
B1a_RecodeExogVars(Infile,RecodedFile);


% B. CALCULATE AUX. MODELS
load(RecodedFile);
[grid2d_j,grid2d_i] = ndgrid( 1:size(Y0,1) , 1:50 );
drop_4OLS = reshape((Y0==1),size(Y0,1)*size(Y0,2),1) + (households==0) > 0;
j_OLS = reshape( grid2d_j , size(Y0,1)*size(Y0,2) , 1 );
j_OLS(drop_4OLS==1)=[];
drop_4RD = reshape((Y0==1)|(NEVATRISK_opt2==1)|(RUNNING<.33)|(RUNNING>.67),size(Y0,1)*size(Y0,2),1) + (households==0) > 0;
j_RD = reshape( grid2d_j , size(Y0,1)*size(Y0,2) , 1 );
j_RD(drop_4RD==1)=[];
noweights = ones(size(Y0,1),5);
drop_4closeRD =  reshape((Y0==1)|(NEVATRISK_opt2==1)|(RUNNING<.46)|(RUNNING>.56),size(Y0,1)*size(Y0,2),1) + (households==0) > 0;
j_CloseRD = reshape( grid2d_j , size(Y0,1)*size(Y0,2) , 1 );
j_CloseRD(drop_4closeRD==1)=[];

MU5_loo_4RD_gt10 = (MU5_loo_4RD > .1);
MU5_loo_4RD_gt20 = (MU5_loo_4RD > .2);
MU5_loo_4RD_gt30 = (MU5_loo_4RD > .3);
MU5_loo_4RD_gt40 = (MU5_loo_4RD > .4);
MU5_loo_4RD_gt50 = (MU5_loo_4RD > .5);
MU5_loo_4RD_gt60 = (MU5_loo_4RD > .6);
MU5_loo_4RD_gt70 = (MU5_loo_4RD > .7);
MU5_loo_4RD_gt80 = (MU5_loo_4RD > .8);
MU5_loo_4RD_gt90 = (MU5_loo_4RD > .9);

Ys_4RD = [Y5_4RD MU5_loo_4RD MU5_loo_4RD_gt10 MU5_loo_4RD_gt20 MU5_loo_4RD_gt30 MU5_loo_4RD_gt40 MU5_loo_4RD_gt50 MU5_loo_4RD_gt60 MU5_loo_4RD_gt70 MU5_loo_4RD_gt80 MU5_loo_4RD_gt90];

[beta_data_RD,beta_data,Y_bar_data,SE_beta_data_RD,SE_beta_data,SE_Y_bar_data] = B1b_ComputeAuxModels(X_data_rd,X_data,   Ys_4RD,Y_data,   j_RD,j_OLS,   1 );

save(DataMomentsFile,'beta_data_RD','beta_data','Y_bar_data','SE_beta_data_RD','SE_beta_data','SE_Y_bar_data')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% 2. SIMULATE DATA %%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load(Infile);
load(RecodedFile);
load(DataMomentsFile)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% "Winner" Parameterization %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
theta0      = [-1.9543734      -0.71323904      2.977815      -1.2            -0.83311931     -0.32783387     0.016963242     0.21684703      log(.5)       -0.067126579    -1.0864586       -0.73321184   -0.055484661    -1.3056459      -1.2183787         660];
theta_spill = [-0.3897938       1.2884912       1.3043409     -0.87111679     -2.1777051      -1.4408625     -0.67273539      0.18548603     -13.018778     -0.80234128     -0.48499707       0.1624305    -0.31706829     -0.40896963     -0.17994283        678.5026];
theta1      = [-0.044135838     1.5339691       1.9450297     -0.87111679     -2.1777051      -1.4408625     -0.67273539      0.18548603     -13.018778     -0.80234128     -0.48499707       0.1624305    -0.31706829     -0.40896963     -0.17994283        678.5026];

beta = .95;


%%%%%%%%%%%%%%%
% DRAW SHOCKS %
%%%%%%%%%%%%%%%
replications=80;
randn('seed',1234);
e0 =                  randn( size(Y0,1) , size(Y0,2) , replications );
e1 =                  randn( size(Y0,1) , replications );
u2 =                  rand(  size(Y0,1) , size(Y0,2) , replications );
tweek_sigma = exp(.25*randn( size(Y0,1) , replications ));
tweek_rho   =      10*randn( size(Y0,1) , replications ) ;


 parpool(4)
%for cf_policy=[1:3 100:2:200];
%for cf_policy=[1:3          ];
 for cf_policy=[    100:2:200];
    cf_policy

    loadfile = ['V_C_NC_all_pol' num2str(cf_policy) '.mat'];
    load(loadfile)
    loadfile = ['V_C_all_pol' num2str(cf_policy) '.mat'];
    load(loadfile)


    parfor rr=1:replications;
        rr
        [MU_STAR        ,Y_model_4OLS        ,MU5_loo_model_4RD        ,Y5_model_4RD        ,SimOutput   ,Unobservables   ,VC_NC_STAR  ,VC_STAR] = B2b_SimulateChoices(I,theta0,theta_spill,beta,replications,V_C_NC_all,V_C_all,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), Y0,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,NEVATRISK_opt2,RUNNING,cf_policy);

        imp_wgts = B3a_ComputeImpWeights(I,theta0,theta_spill,theta1,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), MU_STAR);

        parsave([SimOutputFile num2str(cf_policy) '_Sims' num2str(rr) '.csv'],SimOutput)
        parsave([SimOutputFile num2str(cf_policy) '_SimWgts' num2str(rr) '.csv'],imp_wgts)
        parsave([SimOutputFile num2str(cf_policy) '_Unobservables' num2str(rr) '.csv'],Unobservables)
        parsave([SimOutputFile num2str(cf_policy) '_VC_NC_STAR' num2str(rr) '.csv'],VC_NC_STAR)
        parsave([SimOutputFile num2str(cf_policy) '_VC_STAR' num2str(rr) '.csv'],VC_STAR)

    end;

end


% Policy 6 (Road Home Financial incentives, No Road Home amenities)
cf_policy = 6
loadfile = ['V_C_NC_all_pol1.mat'];
load(loadfile)
loadfile = ['V_C_all_pol1.mat'];
load(loadfile)
V_C_NC_all1 = V_C_NC_all;
V_C_all1    = V_C_all;
clear V_C_NC_all V_C_all;

loadfile = ['V_C_NC_all_pol3.mat'];
load(loadfile)
loadfile = ['V_C_all_pol3.mat'];
load(loadfile)
V_C_NC_all3 = V_C_NC_all;
V_C_all3    = V_C_all;


parfor rr=1:replications;
    rr
    [MU_STAR_fixed,Y_model_4OLS,MU5_loo_model_4RD,Y5_model_4RD,SimOutput,Unobservables,VC_NC_STAR,VC_STAR] =       B2b_SimulateChoices(I,theta0,theta_spill,beta,replications,V_C_NC_all3,V_C_all3,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), Y0,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,NEVATRISK_opt2,RUNNING,cf_policy);
    [MU_STAR      ,Y_model_4OLS,MU5_loo_model_4RD,Y5_model_4RD,SimOutput,Unobservables,VC_NC_STAR,VC_STAR] = B2b_SimulateChoices_PEnew(I,theta0,theta_spill,beta,replications,V_C_NC_all1,V_C_all1,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), Y0,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,NEVATRISK_opt2,RUNNING,cf_policy,MU_STAR_fixed);
    imp_wgts = B3a_ComputeImpWeights(I,theta0,theta_spill,theta1,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), MU_STAR);

    parsave([SimOutputFile num2str(cf_policy) '_Sims' num2str(rr) '.csv'],SimOutput)
    parsave([SimOutputFile num2str(cf_policy) '_SimWgts' num2str(rr) '.csv'],imp_wgts)
    parsave([SimOutputFile num2str(cf_policy) '_Unobservables' num2str(rr) '.csv'],Unobservables)
    parsave([SimOutputFile num2str(cf_policy) '_VC_NC_STAR' num2str(rr) '.csv'],VC_NC_STAR)
    parsave([SimOutputFile num2str(cf_policy) '_VC_STAR' num2str(rr) '.csv'],VC_STAR)
end;



% Policy 7 (Road Home Financial incentives, Unconditional grant amenities)
cf_policy = 7
loadfile = ['V_C_NC_all_pol1.mat'];
load(loadfile)
loadfile = ['V_C_all_pol1.mat'];
load(loadfile)
V_C_NC_all1 = V_C_NC_all;
V_C_all1    = V_C_all;
clear V_C_NC_all V_C_all;

loadfile = ['V_C_NC_all_pol2.mat'];
load(loadfile)
loadfile = ['V_C_all_pol2.mat'];
load(loadfile)
V_C_NC_all2 = V_C_NC_all;
V_C_all2    = V_C_all;

parfor rr=1:replications;
    rr
    [MU_STAR_fixed,Y_model_4OLS,MU5_loo_model_4RD,Y5_model_4RD,SimOutput,Unobservables,VC_NC_STAR,VC_STAR] =       B2b_SimulateChoices(I,theta0,theta_spill,beta,replications,V_C_NC_all2,V_C_all2,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), Y0,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,NEVATRISK_opt2,RUNNING,cf_policy);
    [MU_STAR      ,Y_model_4OLS,MU5_loo_model_4RD,Y5_model_4RD,SimOutput,Unobservables,VC_NC_STAR,VC_STAR] = B2b_SimulateChoices_PEnew(I,theta0,theta_spill,beta,replications,V_C_NC_all1,V_C_all1,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), Y0,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,NEVATRISK_opt2,RUNNING,cf_policy,MU_STAR_fixed);
    imp_wgts = B3a_ComputeImpWeights(I,theta0,theta_spill,theta1,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), MU_STAR);

    parsave([SimOutputFile num2str(cf_policy) '_Sims' num2str(rr) '.csv'],SimOutput)
    parsave([SimOutputFile num2str(cf_policy) '_SimWgts' num2str(rr) '.csv'],imp_wgts)
    parsave([SimOutputFile num2str(cf_policy) '_Unobservables' num2str(rr) '.csv'],Unobservables)
    parsave([SimOutputFile num2str(cf_policy) '_VC_NC_STAR' num2str(rr) '.csv'],VC_NC_STAR)
    parsave([SimOutputFile num2str(cf_policy) '_VC_STAR' num2str(rr) '.csv'],VC_STAR)
end;






%for cf_policy=[1:2];
 for cf_policy=[4];
    cf_policy

    loadfile = ['V_C_NC_all_pol' num2str(cf_policy) '.mat'];
    load(loadfile)
    loadfile = ['V_C_all_pol' num2str(cf_policy) '.mat'];
    load(loadfile)

    %{
    MU_STAR           = zeros( size(Y0         ,1),size(Y_data,2),replications );
    Y_model_4OLS      = zeros( size(Y_data     ,1),size(Y_data,2),replications );
    MU5_loo_model_4RD = zeros( size(Y5_4closeRD,1),size(Y5_4RD,2),replications );
    Y5_model_4RD      = zeros( size(Y5_4closeRD,1),size(Y5_4RD,2),replications );
    Y_model           = zeros( size(Y0         ,1),size(Y_data,2),replications );
    imp_wgts          = zeros( size(Y0         ,1),5             ,replications );
    %}


    parfor rr=1:replications;
        rr
        [MU_STAR        ,Y_model_4OLS        ,MU5_loo_model_4RD        ,Y5_model_4RD        ,SimOutput   ,Unobservables   ,VC_NC_STAR  ,VC_STAR] =              B2b_SimulateChoices(I,theta0,theta_spill,beta,replications,V_C_NC_all,V_C_all,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), Y0,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,NEVATRISK_opt2,RUNNING,cf_policy);

        imp_wgts = B3a_ComputeImpWeights(I,theta0,theta_spill,theta1,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), MU_STAR);

        parsave([SimOutputFile num2str(cf_policy) '_Sims' num2str(rr) '.csv'],SimOutput)
        parsave([SimOutputFile num2str(cf_policy) '_SimWgts' num2str(rr) '.csv'],imp_wgts)
        parsave([SimOutputFile num2str(cf_policy) '_Unobservables' num2str(rr) '.csv'],Unobservables)
        parsave([SimOutputFile num2str(cf_policy) '_VC_NC_STAR' num2str(rr) '.csv'],VC_NC_STAR)
        parsave([SimOutputFile num2str(cf_policy) '_VC_STAR' num2str(rr) '.csv'],VC_STAR)
    end;

 end



 



%for cf_policy=[1:2];
 for cf_policy=[1:4];
    cf_policy

    loadfile = ['V_C_NC_all_pol' num2str(cf_policy) '.mat'];
    load(loadfile)
    loadfile = ['V_C_all_pol' num2str(cf_policy) '.mat'];
    load(loadfile)

    %{
    MU_STAR           = zeros( size(Y0         ,1),size(Y_data,2),replications );
    Y_model_4OLS      = zeros( size(Y_data     ,1),size(Y_data,2),replications );
    MU5_loo_model_4RD = zeros( size(Y5_4closeRD,1),size(Y5_4RD,2),replications );
    Y5_model_4RD      = zeros( size(Y5_4closeRD,1),size(Y5_4RD,2),replications );
    Y_model           = zeros( size(Y0         ,1),size(Y_data,2),replications );
    imp_wgts          = zeros( size(Y0         ,1),5             ,replications );
    %}


    parfor rr=1:replications;
        rr
        [MU_STAR        ,Y_model_4OLS        ,MU5_loo_model_4RD        ,Y5_model_4RD        ,SimOutput_MAX   ,Unobservables_MAX   ,VC_NC_STAR_MAX  ,VC_STAR_MAX] =              B2b_SimulateChoices(I,theta0,theta_spill,beta,replications,V_C_NC_all,V_C_all,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), Y0,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,NEVATRISK_opt2,RUNNING,cf_policy);
        [MU_STAR        ,Y_model_4OLS        ,MU5_loo_model_4RD        ,Y5_model_4RD        ,SimOutput_MIN   ,Unobservables_MIN   ,VC_NC_STAR_MIN  ,VC_STAR_MIN] = B2b_SimulateChoices_SelectMinEqm(I,theta0,theta_spill,beta,replications,V_C_NC_all,V_C_all,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), Y0,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,NEVATRISK_opt2,RUNNING,cf_policy);

        imp_wgts = B3a_ComputeImpWeights(I,theta0,theta_spill,theta1,majblack,majcoll,floodcat1,floodcat2,floodcat3,floodcat4,floodcat5,floodcat6,riskscore,e0(:,:,rr),e1(:,rr),u2(:,:,rr),tweek_sigma(:,rr),tweek_rho(:,rr), MU_STAR);

        parsave([SimOutputFile '_MinMax_' num2str(cf_policy) '_Sims' num2str(rr) '.csv']         ,[SimOutput_MAX     SimOutput_MIN    ])
        parsave([SimOutputFile '_MinMax_' num2str(cf_policy) '_SimWgts' num2str(rr) '.csv']      ,[imp_wgts                           ])
        parsave([SimOutputFile '_MinMax_' num2str(cf_policy) '_Unobservables' num2str(rr) '.csv'],[Unobservables_MAX Unobservables_MIN])
        parsave([SimOutputFile '_MinMax_' num2str(cf_policy) '_VC_NC_STAR' num2str(rr) '.csv']   ,[VC_NC_STAR_MAX    VC_NC_STAR_MIN   ])
        parsave([SimOutputFile '_MinMax_' num2str(cf_policy) '_VC_STAR' num2str(rr) '.csv']      ,[VC_STAR_MAX       VC_STAR_MIN      ])

    end;

end
