clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000


*
* submit syntax:  
*   cd /project/DNORS_chaofu/1.analysis--spillovers/2.programs/gregory/4.gof_and_policy_sims/
*   stata -b do 0.import_simulation_output.do &
*
*


cap cd       "V:/DNORS_chaofu/1.analysis--spillovers/2.programs/gregory/4.gof_and_policy_sims/"
if _rc==0 {
   local root     "V:/DNORS_chaofu/2.analysis--gregory_jmp/1.data/"
   local dnors    "V:/DNORS_chaofu/0.data--dnors/"
   local ouputdir "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
   local simsdir  "V:/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
}

cap cd "/project/DNORS_chaofu/1.analysis--spillovers/2.programs/gregory/4.gof_and_policy_sims/"
if _rc==0 {
   local root     "/project/DNORS_chaofu/2.analysis--gregory_jmp/1.data/"
   local dnors    "/project/DNORS_chaofu/0.data--dnors/"
   local ouputdir "/project/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
   local simsdir  "/project/DNORS_chaofu/1.analysis--spillovers/1.data/1.building_workfile/"
}


local replications = 80
local policies     = 7

**** 
**** 
**** POLICIES:
**** 
**** cf_policy==1 ; baseline (RH)
**** cf_policy==2 ; noRH
**** cf_policy==3 ; Unconditional_RoadHome

**** cf_policy==6 ; Partial Eqm Road Home (Amenities at level under unconditional grants)
**** cf_policy==7 ; Partial Eqm Road Home (Amenities at level under no grants)

****
* Policy 6 (Road Home Financial incentives, Unconditional grant amenities)
* Policy 7 (Road Home Financial incentives, No Road Home amenities)
****

**** 
* Policy 100-200: Rebuilding penalies 0% (policy 100), 2% (policy 102),... up to 100% (policy 200) 
****



**** 
**** 
**** FILES TO INPUT:
**** 
**** 1) Outcomes                           : SimOutputFile`pp'_Sims`rr'.csv
**** 2) Weights                            : SimOutputFile`pp'_SimWgts`rr'.csv
**** 3) Unobservables                      : SimOutputFile`pp'_Unobservables`rr'.csv
**** 4) Consumption Utility (Unconstrained): SimOutputFile`pp'_vc_nc_STAR`rr'.csv
**** 5) Consumption Utility (Constrained)  : SimOutputFile`pp'_vc_STAR`rr'.csv
**** 


forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      qui insheet j i Y1 Y2 Y3 Y4 Y5 using "`simsdir'SimOutputFile`pp'_Sims`rr'.csv"
	  gen rep = `rr'
      qui saveold                          "`simsdir'SimOutputFile`pp'_Sims`rr'.dta", replace
      clear
   }
}
}

forval pp=1/1 {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      qui insheet wgt1 wgt2 wgt3 wgt4 wgt5 using "`simsdir'SimOutputFile`pp'_SimWgts`rr'.csv"
	 gen j = _n
	 gen rep = `rr'
         forval tt=1/5 {
            su wgt`tt'
            if r(N)==0 {
               ren wgt`tt' aux
               gen wgt`tt' = real(aux)
               drop aux
            }
         }
      qui saveold                                "`simsdir'SimOutputFile`pp'_SimWgts`rr'.dta", replace
      clear
   }
}

forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      qui insheet j i bc eta b using "`simsdir'SimOutputFile`pp'_Unobservables`rr'.csv"
	  gen rep = `rr'
      qui saveold                    "`simsdir'SimOutputFile`pp'_Unobservables`rr'.dta", replace
      clear
   }
}
}


forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      qui insheet j i vc_nc1 vc_nc2 vc_nc3 vc_nc4 vc_nc5 vc_nc6 using "`simsdir'SimOutputFile`pp'_VC_NC_STAR`rr'.csv"
	  gen rep = `rr'
      qui saveold                                                     "`simsdir'SimOutputFile`pp'_vc_nc_STAR`rr'.dta", replace
      clear
   }
}
}

forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      qui insheet j i vc1 vc2 vc3 vc4 vc5 vc6 using "`simsdir'SimOutputFile`pp'_VC_STAR`rr'.csv"
	  gen rep = `rr'
      qui saveold                                   "`simsdir'SimOutputFile`pp'_vc_STAR`rr'.dta", replace
      clear
   }
}
}


forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      append using "`simsdir'SimOutputFile`pp'_Sims`rr'.dta"
   }
   qui saveold     "`simsdir'SimOutputFile`pp'_Sims.dta", replace
   clear
}
}

forval pp=1/1 {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      append using "`simsdir'SimOutputFile`pp'_SimWgts`rr'.dta"
   }
   qui saveold     "`simsdir'SimOutputFile`pp'_SimWgts.dta", replace
   clear
}

forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      append using "`simsdir'SimOutputFile`pp'_Unobservables`rr'.dta"
   }
   qui saveold        "`simsdir'SimOutputFile`pp'_Unobservables.dta", replace
   clear
}
}

forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      append using "`simsdir'SimOutputFile`pp'_vc_nc_STAR`rr'.dta"
   }
   qui saveold        "`simsdir'SimOutputFile`pp'_vc_nc_STAR.dta", replace
   clear
}
}

forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval rr=1/`replications' {
      di "`pp' `rr'"
      append using "`simsdir'SimOutputFile`pp'_vc_STAR`rr'.dta"
   }
   qui saveold        "`simsdir'SimOutputFile`pp'_vc_STAR.dta", replace
   clear
}
}

forval pp = 1/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   clear
   use "`ouputdir'workfile_simple_NEW.dta"
*   keep j i grant1 floodcat* RISKCAT* Y0 Y1 Y2 Y3 Y4 Y5
   joinby j i using "`simsdir'SimOutputFile`pp'_Sims.dta", unmatch(both)
   tab _m
   drop _m
   joinby j i rep using "`simsdir'SimOutputFile`pp'_Unobservables.dta", unmatch(both)
   tab _m
   drop _m
   joinby j i rep using "`simsdir'SimOutputFile`pp'_vc_nc_STAR.dta", unmatch(both)
   tab _m
   drop _m
   joinby j i rep using "`simsdir'SimOutputFile`pp'_vc_STAR.dta", unmatch(both)
   tab _m
   drop _m
   if `pp'==1 {
      joinby j rep using "`simsdir'SimOutputFile`pp'_SimWgts.dta", unmatch(both)
      tab _m
      drop _m
      forval tt=1/5 {
         egen sumwgt`tt' = sum(wgt`tt'), by(i j)
         replace wgt`tt' = wgt`tt' / sumwgt`tt'
         drop sumwgt`tt'
      }
   }
   saveold "`simsdir'SimOutputFile`pp'_Sims_w_Covars.dta", replace
   clear
}
}

use              "`simsdir'SimOutputFile1_Sims_w_Covars.dta"
ren y1     pol1_y1
ren y2     pol1_y2
ren y3     pol1_y3
ren y4     pol1_y4
ren y5     pol1_y5
ren vc_nc1 pol1_vc_nc1
ren vc_nc2 pol1_vc_nc2
ren vc_nc3 pol1_vc_nc3
ren vc_nc4 pol1_vc_nc4
ren vc_nc5 pol1_vc_nc5
ren vc_nc6 pol1_vc_nc6
ren vc1    pol1_vc1
ren vc2    pol1_vc2
ren vc3    pol1_vc3
ren vc4    pol1_vc4
ren vc5    pol1_vc5
ren vc6    pol1_vc6
forval pp = 2/200 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   joinby j i rep using "`simsdir'SimOutputFile`pp'_Sims_w_Covars.dta", unmatched(both)
   tab _m
   drop _m
   ren y1     pol`pp'_y1
   ren y2     pol`pp'_y2
   ren y3     pol`pp'_y3
   ren y4     pol`pp'_y4
   ren y5     pol`pp'_y5
   ren vc_nc1 pol`pp'_vc_nc1
   ren vc_nc2 pol`pp'_vc_nc2
   ren vc_nc3 pol`pp'_vc_nc3
   ren vc_nc4 pol`pp'_vc_nc4
   ren vc_nc5 pol`pp'_vc_nc5
   ren vc_nc6 pol`pp'_vc_nc6
   ren vc1    pol`pp'_vc1
   ren vc2    pol`pp'_vc2
   ren vc3    pol`pp'_vc3
   ren vc4    pol`pp'_vc4
   ren vc5    pol`pp'_vc5
   ren vc6    pol`pp'_vc6
}
}

saveold                 "`simsdir'SimOutputFile_all_Sims_w_Covars.dta", replace




