clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000


local simsdir  ""      /* Location of Simulation Output */


local replications = 80

**** 
**** cf_policy==1 ; baseline (RH)
**** cf_policy==2 ; noRH
**** cf_policy==3 ; Unconditional_RoadHome
**** 

****************************************************************
*** 1. GOF) a. rebuilding rate, aggregate and by flood-depth ***
****************************************************************
use "`simsdir'SimOutputFile_all_Sims_w_Covars.dta"

******************************************************************
*** Tabulate goodness of fit to nontargetted moments (TABLE 5) ***
******************************************************************
cap log close
log using ZZZ-T5_GOF_nontargeted_moments.log, replace
egen id=group(i j)
gen all=1
gen full_ins = ins>=k if ins/k<.
replace full_ins = 1 if k==0
foreach var in PaymentsLeft k ins pct_pov_tr pctcoll pctblack purchase_year {
   qui su `var' if `var'<. [aw=wgt5], d
   local median = r(p50)
   
   di ""
   di ""
   di "`var' below median"
   mean pol1_y5 Y5 if `var'<=`median' & `var'<. [aw=wgt5], cluster(id)

   di ""
   di ""
   di "`var' above median"
   mean pol1_y5 Y5 if `var'>`median' & `var'<. [aw=wgt5], cluster(id)
   di ""
   di ""
   di ""
   di ""
}

foreach var in majcoll majblack LMI_imp full_ins {
   qui su `var' if `var'<. [aw=wgt5], d
   local median = r(p50)
   
   di ""
   di ""
   di "`var' = 0"
   mean pol1_y5 Y5 if `var'==0 [aw=wgt5], cluster(id)

   di ""
   di ""
   di "`var' = 1"
   mean pol1_y5 Y5 if `var'==1 [aw=wgt5], cluster(id)
   di ""
   di ""
   di ""
   di ""
}

mean pol1_y5 Y5 [aw=wgt5], cluster(id)
log close



************************************************************
*** Plot goodness of fit to rebuilding trends (FIGURE 8) ***
************************************************************
gen     floodcat = .
replace floodcat = 1 if floodcat1==1
replace floodcat = 2 if floodcat2==1
replace floodcat = 3 if floodcat3==1
replace floodcat = 4 if floodcat4==1
replace floodcat = 5 if floodcat5==1
replace floodcat = 6 if floodcat6==1
gen     RISKCAT = .
replace RISKCAT = 1 if RISKCAT1==1
replace RISKCAT = 2 if RISKCAT2==1
replace RISKCAT = 3 if RISKCAT3==1
replace RISKCAT = 4 if RISKCAT4==1
replace RISKCAT = 5 if RISKCAT5==1
replace RISKCAT = 6 if RISKCAT6==1
replace RISKCAT = 7 if RISKCAT7==1
foreach  pp in 1 2 3 6 7 {
   forval tt=1/5 {
      di "`pp' `tt'"
      qui replace pol`pp'_y`tt' = pol`pp'_y`tt' * wgt`tt'
   }
}
collapse (mean) Y* (sum) pol*_y*, by(i j floodcat RISKCAT)
gen N=1
preserve
collapse (mean) Y* pol*_y* (sum) N
gen floodcat=99
gen RISKCAT =99
tempfile collapsed_all
save    `collapsed_all'
restore
preserve
collapse (mean) Y* pol*_y* (sum) N, by(floodcat)
tempfile collapsed_floodcats
save    `collapsed_floodcats'
restore
preserve
collapse (mean) Y* pol*_y* (sum) N, by(RISKCAT)
tempfile collapsed_riskcats
save    `collapsed_riskcats'
restore
clear
append using `collapsed_all'
append using `collapsed_floodcats'
append using `collapsed_riskcats'
reshape long Y pol1_y pol2_y pol3_y pol4_y pol5_y, i(floodcat RISKCAT) j(year)
foreach var in pol1_y pol2_y pol3_y pol4_y pol5_y {
   replace `var' = Y if year==0
}
set scheme s1mono
twoway (line pol1_y Y year if floodcat==99, lwidth(1 1) ylabel(0(.25)1, labsize(large)) xlabel(0(1)5, labsize(large)) lcolor(black ltblue) lpattern(l dash) xtitle("Years Since Hurricane Katrina", size(large)) legend(lab(1 "Data") lab(2 "Model Prediction") cols(1) ring(0) pos(10) ) )
graph export "ZZZ-F8_GOF_livable_trend.pdf", replace
foreach ff in 1 2 3 4 5 6 {
   twoway (line pol1_y Y year if floodcat==`ff', lwidth(1 1) ylabel(0(.25)1, labsize(large)) xlabel(0(1)5, labsize(large)) lcolor(black ltblue) lpattern(l dash) xtitle("Years Since Hurricane Katrina", size(large)) legend(lab(1 "Data") lab(2 "Model Prediction") cols(1) ring(0) pos(10) ) )
   graph export "ZZZ-F8_GOF_livable_trend_floodcat`ff'.pdf", replace
}
foreach rr in 1 2 3 4 5 6 7 {
   twoway (line pol1_y Y year if RISKCAT==`rr', lwidth(1 1) ylabel(0(.25)1, labsize(large)) xlabel(0(1)5, labsize(large)) lcolor(black ltblue) lpattern(l dash) xtitle("Years Since Hurricane Katrina", size(large)) legend(lab(1 "Data") lab(2 "Model Prediction") cols(1) ring(0) pos(10) ) )
   graph export "ZZZ-F8_GOF_livable_trend_riskcat`rr'.pdf", replace
}
clear


************************************************************************
*** Plot goodness of fit to rebuilding trends only for damaged homes ***
************************************************************************
use "`simsdir'SimOutputFile_all_Sims_w_Covars.dta"
keep if Y0==0
gen     floodcat = .
replace floodcat = 1 if floodcat1==1
replace floodcat = 2 if floodcat2==1
replace floodcat = 3 if floodcat3==1
replace floodcat = 4 if floodcat4==1
replace floodcat = 5 if floodcat5==1
replace floodcat = 6 if floodcat6==1
gen     RISKCAT = .
replace RISKCAT = 1 if RISKCAT1==1
replace RISKCAT = 2 if RISKCAT2==1
replace RISKCAT = 3 if RISKCAT3==1
replace RISKCAT = 4 if RISKCAT4==1
replace RISKCAT = 5 if RISKCAT5==1
replace RISKCAT = 6 if RISKCAT6==1
replace RISKCAT = 7 if RISKCAT7==1
foreach  pp in 1 2 3 6 7 {
   forval tt=1/5 {
      di "`pp' `tt'"
      qui replace pol`pp'_y`tt' = pol`pp'_y`tt' * wgt`tt'
   }
}
collapse (mean) Y* (sum) pol*_y*, by(i j floodcat RISKCAT)
gen N=1
preserve
collapse (mean) Y* pol*_y* (sum) N
gen floodcat=99
gen RISKCAT =99
tempfile collapsed_all
save    `collapsed_all'
restore
preserve
collapse (mean) Y* pol*_y* (sum) N, by(floodcat)
tempfile collapsed_floodcats
save    `collapsed_floodcats'
restore
preserve
collapse (mean) Y* pol*_y* (sum) N, by(RISKCAT)
tempfile collapsed_riskcats
save    `collapsed_riskcats'
restore
clear
append using `collapsed_all'
append using `collapsed_floodcats'
append using `collapsed_riskcats'
reshape long Y pol1_y pol2_y pol3_y pol4_y pol5_y, i(floodcat RISKCAT) j(year)
foreach var in pol1_y pol2_y pol3_y pol4_y pol5_y {
   replace `var' = Y if year==0
}
set scheme s1mono
twoway (line pol1_y Y year if floodcat==99, lwidth(1 1) ylabel(0(.25)1, labsize(large)) xlabel(0(1)5, labsize(large)) lcolor(black ltblue) lpattern(l dash) xtitle("Years Since Hurricane Katrina", size(large)) legend(lab(1 "Data") lab(2 "Model Prediction") cols(1) ring(0) pos(10) ) )
graph export "ZZZ-AF8_GOF_rebuild_trend.pdf", replace

foreach ff in 1 2 3 4 5 6 {
   twoway (line pol1_y Y year if floodcat==`ff', lwidth(1 1) ylabel(0(.25)1, labsize(large)) xlabel(0(1)5, labsize(large)) lcolor(black ltblue) lpattern(l dash) xtitle("Years Since Hurricane Katrina", size(large)) legend(lab(1 "Data") lab(2 "Model Prediction") cols(1) ring(0) pos(10) ) )
   graph export "ZZZ-AF8_GOF_rebuild_trend_floodcat`ff'.pdf", replace
}
foreach rr in 1 2 3 4 5 6 7 {
   twoway (line pol1_y Y year if RISKCAT==`rr', lwidth(1 1) ylabel(0(.25)1, labsize(large)) xlabel(0(1)5, labsize(large)) lcolor(black ltblue) lpattern(l dash) xtitle("Years Since Hurricane Katrina", size(large)) legend(lab(1 "Data") lab(2 "Model Prediction") cols(1) ring(0) pos(10) ) )
   graph export "ZZZ-AF8_GOF_rebuild_trend_riskcat`rr'.pdf", replace
}
clear


**********************************************************************************************
*** Plot goodness of fit to year 5 rebuilding rate *distribution* across blocks (FIGURE 9) ***
**********************************************************************************************
use "`simsdir'SimOutputFile_all_Sims_w_Covars.dta"
gen     floodcat = .
replace floodcat = 1 if floodcat1==1
replace floodcat = 2 if floodcat2==1
replace floodcat = 3 if floodcat3==1
replace floodcat = 4 if floodcat4==1
replace floodcat = 5 if floodcat5==1
replace floodcat = 6 if floodcat6==1
gen     RISKCAT = .
replace RISKCAT = 1 if RISKCAT1==1
replace RISKCAT = 2 if RISKCAT2==1
replace RISKCAT = 3 if RISKCAT3==1
replace RISKCAT = 4 if RISKCAT4==1
replace RISKCAT = 5 if RISKCAT5==1
replace RISKCAT = 6 if RISKCAT6==1
replace RISKCAT = 7 if RISKCAT7==1
collapse Y* pol*_y* wgt*, by(j rep floodcat RISKCAT)

gen wgt5_round = round(wgt5*1000000)
twoway (histogram pol1_y5 [fw=wgt5_round],  color(ltblue) lwidth(.1) lcolor(gs5  ) start(0) width(.025) frac) /*
*/     (histogram      Y5 [fw=wgt5_round], fcolor(none  ) lwidth(.5) lcolor(black) start(0) width(.025) frac legend(lab(1 "Model Prediction") lab(2 "Data") cols(1) ring(0) pos(10)) xtitle("Repair Rate", size(large)) ytitle("Fraction of Blocks", size(large)) xlabel(,labsize(large)) ylabel(0(.2).8,labsize(large)) ) 
graph export "ZZZ-F9_GOF_rebuild_rate_dist.pdf", replace

foreach ff in 1 2 3 4 5 6 {
   twoway (histogram pol1_y5 if floodcat==`ff' [fw=wgt5_round],  color(ltblue) lwidth(.1) lcolor(gs5  ) start(0) width(.025) frac) /*
   */     (histogram      Y5 if floodcat==`ff' [fw=wgt5_round], fcolor(none  ) lwidth(.5) lcolor(black) start(0) width(.025) frac legend(lab(1 "Model Prediction") lab(2 "Data") cols(1) ring(0) pos(10)) xtitle("Repair Rate", size(large)) ytitle("Fraction of Blocks", size(large)) xlabel(,labsize(large)) ylabel(0(.2).8,labsize(large)) ) 
   graph export "ZZZ-F9_GOF_rebuild_rate_dist_floodcat`ff'.pdf", replace
}
foreach rr in 1 2 3 4 5 6 7 {
   twoway (histogram pol1_y5 if RISKCAT==`rr' [fw=wgt5_round],  color(ltblue) lwidth(.1) lcolor(gs5  ) start(0) width(.025) frac) /*
   */     (histogram      Y5 if RISKCAT==`rr' [fw=wgt5_round], fcolor(none  ) lwidth(.5) lcolor(black) start(0) width(.025) frac legend(lab(1 "Model Prediction") lab(2 "Data") cols(1) ring(0) pos(10)) xtitle("Repair Rate", size(large)) ytitle("Fraction of Blocks", size(large)) xlabel(,labsize(large)) ylabel(0(.2).8,labsize(large)) ) 
   graph export "ZZZ-F9_GOF_rebuild_rate_dist_riskcat`rr'.pdf", replace
}






