clear
clear mata
clear matrix
set mem 200m
set more off
set maxvar 10000


local simsdir  ""      /* Location of Simulation Output */

local replications = 80

**** 
**** cf_policy==1 ; baseline (RH)
**** cf_policy==2 ; noRH
**** cf_policy==3 ; Unconditional_RoadHome
**** 


adopath + /home/j/jmgregory/ado/
adopath






*************************
*** <100% sample runs ***
*************************
*use if rep<=8 using "`simsdir'SimOutputFile_all_Sims_w_Covars.dta"
*save                "`simsdir'SimOutputFile_all_Sims_w_Covars_10pct.dta", replace
*clear
*use if rep<=8 using "`simsdir'SimOutputFile_all_Sims_w_Covars_10pct.dta"

*************************
*** 100 % sample runs ***
*************************
use "`simsdir'SimOutputFile_all_Sims_w_Covars.dta"
*use if uniform()<.0001 using "`simsdir'SimOutputFile_all_Sims_w_Covars.dta"

su majblack majcoll RISKCAT1-RISKCAT7

***************
*** Recodes ***
***************
local beta       = .95
local r          = 1/`beta' - 1

/*
>> >> >> >> >> >>    >> 
>> >> >> >> >> >> 	       >> 
TrueTheta0andSpillNames =      TrueTheta0andSpill =

G_spill             	           0.2642
M_spill             	           0.7839
V_spill             	           3.6853

delta1_0            	          -1.1221
delta2_0            	          -0.7790
delta3_0            	          -0.3065
delta4_0            	           0.0159
delta5_0            	           0.2028

sigmab_0            	           0.4675
sigmaeta_0          	           0.9351

gamma_floodcat1_0   	          -1.0159
gamma_floodcat3_0   	          -0.6856
gamma_floodcat4_0   	          -0.0519
gamma_floodcat5_0   	          -1.2209
gamma_floodcat6_0   	          -1.1393

rho_star_0          	         660.0000
*/

local Byear1     = -1.1221
local Byear2     = -0.7790
local Byear3     = -0.3065
local Byear4     =  0.0159
local Byear5     =  0.2028

local Bfloodcat1 = -1.0159
local Bfloodcat3 = -0.6856
local Bfloodcat4 = -0.0519
local Bfloodcat5 = -1.2209
local Bfloodcat6 = -1.1393

local G          =  0.2642
local M          =  0.7839
local V          =  3.6853

local G_star     =  0.43
local M_star     =  0.82
local V_star     =  6.99


gen Zgamma =   floodcat1 * `Bfloodcat1' /*
*/           + floodcat3 * `Bfloodcat3' /*
*/           + floodcat4 * `Bfloodcat4' /*
*/           + floodcat5 * `Bfloodcat5' /*
*/           + floodcat6 * `Bfloodcat6'


gen     floodcat = .
replace floodcat = 1 if floodcat1==1
replace floodcat = 2 if floodcat2==1
replace floodcat = 3 if floodcat3==1
replace floodcat = 4 if floodcat4==1
replace floodcat = 5 if floodcat5==1
replace floodcat = 6 if floodcat6==1
gen     RISKCAT = .
replace RISKCAT = 1 if RISKCAT1==1
replace RISKCAT = 2 if RISKCAT2==1
replace RISKCAT = 3 if RISKCAT3==1
replace RISKCAT = 4 if RISKCAT4==1
replace RISKCAT = 5 if RISKCAT5==1
replace RISKCAT = 6 if RISKCAT6==1
replace RISKCAT = 7 if RISKCAT7==1

egen mu0 = mean(Y0), by(j rep)
cap drop pol*_mu*
*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   forval tt=1/5 {
      di "p=`pp', t=`tt'"
      egen pol`pp'_mu`tt' = mean(pol`pp'_y`tt'), by(j rep)
   }
}
}
su pol*_mu5

***************************************
** 0. equilibrium home price impacts **
***************************************
*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   cap drop pol`pp'_PRICE
   gen pol`pp'_PRICE = P_HAT_BASE * exp(   0.080 * max(0,min(.2,pol`pp'_mu5-.4))  /*
   */                                    + 0.222 * max(0,min(.2,pol`pp'_mu5-.6))  /*
   */                                    + 0.464 * max(0,min(.2,pol`pp'_mu5-.8)) )
}
}

*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   gen     Dprice`pp' = pol`pp'_PRICE - pol3_PRICE
}
}


***************************************
** 1. equilibrium grant expenditures **
***************************************
gen pol1_GrantExpend = (pol1_y5>Y0)*grant1      +   (pol1_y5==0)*(grant2>pol1_PRICE-k)*(grant2)
gen pol2_GrantExpend = 0
gen pol3_GrantExpend = (Y0==0)*grant1
gen pol4_GrantExpend = (pol4_y5>Y0)*grantsmooth +   (pol4_y5==0)*(grantsmooth>pol4_PRICE-k)*(grantsmooth)

/*
forval pp = 100(2)200 {
   gen pol`pp'_GrantExpend = (pol`pp'_y5>Y0)*grant1   +   (pol`pp'_y5==0)*(1 - (`pp'-100)/100 )*grant1
}
*/
*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4   )==1 | (`pp'>=100 & mod(`pp',2)==0) {
   gen DGrantExpend`pp' = `beta'^3 * ( pol`pp'_GrantExpend - pol3_GrantExpend )
}
}


**********************************************************
** 2. equivalent variations for amenity utility changes **
**********************************************************
foreach var of varlist pol*_vc* {
   su `var'
   if r(N)==0 {
      ren     `var' aux
      gen     `var' = real(aux)
      drop aux
   }
}
*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   cap drop pol`pp'_vc
   gen      pol`pp'_vc = .
   replace  pol`pp'_vc = pol`pp'_vc_nc6 if pol`pp'_y5==0 & bc==0
   replace  pol`pp'_vc = pol`pp'_vc_nc5 if pol`pp'_y5==1 & bc==0
   replace  pol`pp'_vc = pol`pp'_vc_nc4 if pol`pp'_y4==1 & bc==0
   replace  pol`pp'_vc = pol`pp'_vc_nc3 if pol`pp'_y3==1 & bc==0
   replace  pol`pp'_vc = pol`pp'_vc_nc2 if pol`pp'_y2==1 & bc==0
   replace  pol`pp'_vc = pol`pp'_vc_nc1 if pol`pp'_y1==1 & bc==0
   replace  pol`pp'_vc = pol`pp'_vc6    if pol`pp'_y5==0 & bc==1
   replace  pol`pp'_vc = pol`pp'_vc5    if pol`pp'_y5==1 & bc==1
   replace  pol`pp'_vc = pol`pp'_vc4    if pol`pp'_y4==1 & bc==1
   replace  pol`pp'_vc = pol`pp'_vc3    if pol`pp'_y3==1 & bc==1
   replace  pol`pp'_vc = pol`pp'_vc2    if pol`pp'_y2==1 & bc==1
   replace  pol`pp'_vc = pol`pp'_vc1    if pol`pp'_y1==1 & bc==1
   drop     pol`pp'_vc_nc1-pol`pp'_vc_nc6 pol`pp'_vc1-pol`pp'_vc6
   gen      pol`pp'_c_tilde = exp( pol`pp'_vc * (1-`beta') / `beta' / (1-`beta'^8) )
}
}

*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   gen Dvc`pp' = pol`pp'_vc - pol3_vc
}
}


*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   gen DUtil`pp' =   `beta'^1 * ( pol`pp'_y1 * ( `Byear1' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol`pp'_mu1)) - pol3_y1 * ( `Byear1' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol3_mu1)) ) /*
   */              + `beta'^2 * ( pol`pp'_y2 * ( `Byear2' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol`pp'_mu2)) - pol3_y2 * ( `Byear2' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol3_mu2)) ) /*
   */              + `beta'^3 * ( pol`pp'_y3 * ( `Byear3' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol`pp'_mu3)) - pol3_y3 * ( `Byear3' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol3_mu3)) ) /*
   */              + `beta'^4 * ( pol`pp'_y4 * ( `Byear4' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol`pp'_mu4)) - pol3_y4 * ( `Byear4' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol3_mu4)) ) /*
   */              + `beta'^5 * ( pol`pp'_y5 * ( `Byear5' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol`pp'_mu5)) - pol3_y5 * ( `Byear5' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol3_mu5)) ) /*
   */              + `beta'^6 * ( pol`pp'_y5 * ( `Byear5' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol`pp'_mu5)) - pol3_y5 * ( `Byear5' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol3_mu5)) ) /*
   */              + `beta'^7 * ( pol`pp'_y5 * ( `Byear5' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol`pp'_mu5)) - pol3_y5 * ( `Byear5' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol3_mu5)) ) /*
   */              + `beta'^8 * ( pol`pp'_y5 * ( `Byear5' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol`pp'_mu5)) - pol3_y5 * ( `Byear5' + Zgamma + eta + b + `G'*ibeta(`M'*`V',(1-`M')*`V',pol3_mu5)) )
}
}

*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   gen DUtilTot`pp' = DUtil`pp' + Dvc`pp'
}
}


local beta = .95
*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   gen     DU_ev`pp'   = 0
   replace DU_ev`pp'   = pol3_c_tilde * ( exp( (1-`beta')/`beta'/(1-`beta'^8) * DUtil`pp' ) - 1 ) * `beta' * (1-`beta'^8) / (1-`beta')
}
}


local beta = .95
*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4,6,7)==1 | (`pp'>=100 & mod(`pp',2)==0) {
   gen     DUTot_ev`pp'   = 0
   replace DUTot_ev`pp'   = pol3_c_tilde * ( exp( (1-`beta')/`beta'/(1-`beta'^8) * DUtilTot`pp' ) - 1 ) * `beta' * (1-`beta'^8) / (1-`beta')
}
}

*forval pp = 1/200 {
forval pp = 1/4 {
if inlist(`pp',1,2,3,4    )==1 | (`pp'>=100 & mod(`pp',2)==0) {
   cap drop DWelfare`pp'
   gen      DWelfare`pp' = 0
   replace  DWelfare`pp' = DUTot_ev`pp' - DGrantExpend`pp' if pol3_y5==1 | pol`pp'_y5==1
   replace  DWelfare`pp' = Dprice`pp'                      if pol3_y5==0 & pol`pp'_y5==0
}
}

gen aux = round(mu0-.05,.10)+.05
egen mu0_round10 = group( aux )
drop aux

gen aux = round(pol3_mu5-.05,.10)+.05
egen pol3_mu5_round10 = group( aux )
drop aux

**********************
**** SAVE RECODED ****
**********************
save "`simsdir'TEMP.dta", replace
clear




use                 "`simsdir'TEMP.dta"

*********************************************************************************
*** 1. Simmple Rebuilding Rate Impacts - Partial eqm. and full eqm. (TABLE 6) ***
*********************************************************************************
caplog using ZZZ-TAB6_Rebuilding_Impacts.log, replace: tabstat pol3_y5 pol6_y5 pol1_y5 pol2_y5 pol7_y5 pol1_y5 pol4_y5 Y5 [aw=wgt5], stat(mean) by(floodcat)
caplog using ZZZ-TAB6_Rebuilding_Impacts.log, append : tabstat pol3_y5 pol6_y5 pol1_y5 pol2_y5 pol7_y5 pol1_y5 pol4_y5 Y5 [aw=wgt5], stat(mean) by(pol3_mu5_round10)
caplog using ZZZ-TAB6_Rebuilding_Impacts.log, append : tab1 floodcat pol3_mu5_round10 
logout,  use(ZZZ-TAB6_Rebuilding_Impacts.log) save(ZZZ-TAB5_Rebuilding_Impacts.xls) excel replace


*******************************
*** 2. RH Welfare (TABLE 8) ***
*******************************
caplog using ZZZ-TAB8_welfare.log, replace: tabstat DWelfare1 Dprice1 DUTot_ev1 DGrantExpend1                            [aw=wgt5], stat(sum mean) by(floodcat)
caplog using ZZZ-TAB8_welfare.log, append : tabstat DWelfare1 Dprice1 DUTot_ev1 DGrantExpend1 if pol3_y5==0 & pol1_y5==0 [aw=wgt5], stat(sum mean) by(floodcat)
caplog using ZZZ-TAB8_welfare.log, append : tabstat DWelfare1 Dprice1 DUTot_ev1 DGrantExpend1 if pol3_y5   != pol1_y5    [aw=wgt5], stat(sum mean) by(floodcat)
caplog using ZZZ-TAB8_welfare.log, append : tabstat DWelfare1 Dprice1 DUTot_ev1 DGrantExpend1 if pol3_y5==1 & pol1_y5==1 [aw=wgt5], stat(sum mean) by(floodcat)
caplog using ZZZ-TAB8_welfare.log, append : tabstat DWelfare4 Dprice4 DUTot_ev4 DGrantExpend4                            [aw=wgt5], stat(sum mean) by(floodcat)
caplog using ZZZ-TAB8_welfare.log, append : tabstat DWelfare4 Dprice4 DUTot_ev4 DGrantExpend4 if pol3_y5==0 & pol4_y5==0 [aw=wgt5], stat(sum mean) by(floodcat)
caplog using ZZZ-TAB8_welfare.log, append : tabstat DWelfare4 Dprice4 DUTot_ev4 DGrantExpend4 if pol3_y5   != pol4_y5    [aw=wgt5], stat(sum mean) by(floodcat)
caplog using ZZZ-TAB8_welfare.log, append : tabstat DWelfare4 Dprice4 DUTot_ev4 DGrantExpend4 if pol3_y5==1 & pol4_y5==1 [aw=wgt5], stat(sum mean) by(floodcat)
logout,  use(ZZZ-TAB8_welfare.log) save(ZZZ-TAB6_welfare.xls) excel replace


****************************************************
*** 3. Block-Level Policy Calculations (TABLE 9) ***
****************************************************

*Perfect block-level targeting
preserve
collapse (sum) DWelfare* DGrantExpend* [iw=wgt5], by(j rep)
gen DGrantExbest = DGrantExpend100
gen DWelfarebest = DWelfare100
forval pp=100(2)200 {
   replace DGrantExbest = DGrantExpend`pp' if DWelfare`pp'>DWelfarebest
   replace DWelfarebest = DWelfare`pp' if DWelfare`pp'>DWelfarebest
}
caplog using ZZZ-TAB9_OptimalPolCalc_BlockSpecific.log, replace: tabstat DGrantExbest DWelfarebest , stat(sum)
restore

*Flood category targeting
preserve
collapse (sum) DWelfare* DGrantExpend* [iw=wgt5], by(floodcat)
gen DGrantExbest_flood = DGrantExpend100
gen DWelfarebest_flood = DWelfare100
forval pp=100(2)200 {
   replace DGrantExbest_flood = DGrantExpend`pp' if DWelfare`pp'>DWelfarebest_flood
   replace DWelfarebest_flood = DWelfare`pp'     if DWelfare`pp'>DWelfarebest_flood
}
caplog using ZZZ-TAB9_OptimalPolCalc_BlockSpecific.log,  append: tabstat DGrantExbest_flood DWelfarebest_flood , stat(sum)
restore

*Mu0 targeting
preserve
collapse (sum) DWelfare* DGrantExpend* [iw=wgt5], by(mu0_round10)
gen DGrantExbest_Mu0 = DGrantExpend100
gen DWelfarebest_Mu0 = DWelfare100
forval pp=100(2)200 {
   replace DGrantExbest_Mu0 = DGrantExpend`pp' if DWelfare`pp'>DWelfarebest_Mu0
   replace DWelfarebest_Mu0 = DWelfare`pp'     if DWelfare`pp'>DWelfarebest_Mu0
}
caplog using ZZZ-TAB9_OptimalPolCalc_BlockSpecific.log,  append: tabstat DGrantExbest_Mu0 DWelfarebest_Mu0 , stat(sum)
restore

*Flood category x Mu0 targeting
preserve
collapse (sum) DWelfare* DGrantExpend* [iw=wgt5], by(mu0_round10 floodcat)
gen DGrantExbest_Mu0_flood = DGrantExpend100
gen DWelfarebest_Mu0_flood = DWelfare100
forval pp=100(2)200 {
   replace DGrantExbest_Mu0_flood = DGrantExpend`pp' if DWelfare`pp'>DWelfarebest_Mu0_flood
   replace DWelfarebest_Mu0_flood = DWelfare`pp'     if DWelfare`pp'>DWelfarebest_Mu0_flood
}
caplog using ZZZ-TAB9_OptimalPolCalc_BlockSpecific.log,  append: tabstat DGrantExbest_Mu0_flood DWelfarebest_Mu0_flood , stat(sum)
restore

*Demographic targeting
preserve
collapse (sum) DWelfare* DGrantExpend* [iw=wgt5], by(majblack majcoll RISKCAT1-RISKCAT7)
gen DGrantExbest_demo = DGrantExpend100
gen DWelfarebest_demo = DWelfare100
forval pp=100(2)200 {
   replace DGrantExbest_demo = DGrantExpend`pp' if DWelfare`pp'>DWelfarebest_demo
   replace DWelfarebest_demo = DWelfare`pp'     if DWelfare`pp'>DWelfarebest_demo
}
caplog using ZZZ-TAB9_OptimalPolCalc_BlockSpecific.log,  append: tabstat DGrantExbest_demo DWelfarebest_demo , stat(sum)
restore

*Uniform policy
preserve
collapse (sum) DWelfare* DGrantExpend* [iw=wgt5]
gen DGrantExbest_unif = DGrantExpend100
gen DWelfarebest_unif = DWelfare100
forval pp=100(2)200 {
   replace DGrantExbest_unif = DGrantExpend`pp' if DWelfare`pp'>DWelfarebest_unif
   replace DWelfarebest_unif = DWelfare`pp'     if DWelfare`pp'>DWelfarebest_unif
}
caplog using ZZZ-TAB9_OptimalPolCalc_BlockSpecific.log,  append: tabstat DGrantExbest_unif DWelfarebest_unif , stat(sum)
restore


logout,  use(ZZZ-TAB9_OptimalPolCalc_BlockSpecific.log) save(ZZZ-TAB7b_OptimalPolCalc_BlockSpecific.xls) excel replace




*******************************************
*** Create Figure 10 -- heatmap summary ***
*******************************************
use                 "`simsdir'TEMP.dta"

preserve
collapse (sum) DWelfare* DGrantExpend* [iw=wgt5], by(j rep)
gen BestRho      = 0
gen DGrantExbest = DGrantExpend100
gen DWelfarebest = DWelfare100
forval pp=100(2)200 {
   replace BestRho      = `pp' - 100       if DWelfare`pp'>DWelfarebest
   replace DGrantExbest = DGrantExpend`pp' if DWelfare`pp'>DWelfarebest
   replace DWelfarebest = DWelfare`pp'     if DWelfare`pp'>DWelfarebest
}
tempfile PerfectRhos
save    `PerfectRhos'
restore

cap drop mu*
forval tt=0/5 {
   egen mu`tt' = mean(Y`tt'), by(j rep)
}
bysort j rep: keep if _n==1
joinby j rep using `PerfectRhos'

save TempPerfectRhos, replace
clear

use TempPerfectRhos.dta
gen D0=1-mu0

keep if flooding>0
gen one=1
reg      BestRho c.(one D0 flooding)#c.(one D0 flooding) if flooding>0 [w=wgt5], cluster(j)
predict  BestRho_hat
collapse BestRho_hat, by(flooding D0)

keep if uniform()<.05 | flooding>8  /* full sample not needed to create heatmap */

*****************************************************************************************************************************
*** Create heat map illustrating how optimal block level targeting relates to flooding/initial block damage % (Figure 10) ***
*****************************************************************************************************************************

set scheme s1mono
twoway contour BestRho_hat flooding D0, ccut(15 25 35 45 55) ccolor("239 243 255" "198 219 239" "158 202 225" "107 174 214" "49 130 189" "8 81 156") xtitle("Block Damage Fraction", size(large)) ytitle("Block Flood Depth", size(large)) ztitle("Avg. Relocation Penalty (%)", size(large))

graph export "ZZZ-F10_RhoStar-HeatMap.eps", replace
!epstopdf    "ZZZ-F10_RhoStar-HeatMap.eps"
rm           "ZZZ-F10_RhoStar-HeatMap.eps"



